/* selectionbar.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from selectionbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <clutter/clutter.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;
typedef struct _BoxesSelectionbarPrivate BoxesSelectionbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block53Data Block53Data;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

struct _BoxesSelectionbar {
	GObject parent_instance;
	BoxesSelectionbarPrivate * priv;
};

struct _BoxesSelectionbarClass {
	GObjectClass parent_class;
};

struct _BoxesSelectionbarPrivate {
	GtkClutterActor* gtk_actor;
	GtkToolbar* toolbar;
	GtkToggleButton* favorite_btn;
	GtkButton* pause_btn;
	GtkButton* remove_btn;
	GtkButton* properties_btn;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block53Data {
	int _ref_count_;
	BoxesSelectionbar * self;
	BoxesMachine* machine;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;


static gpointer boxes_selectionbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
#define BOXES_SELECTIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarPrivate))
enum  {
	BOXES_SELECTIONBAR_DUMMY_PROPERTY,
	BOXES_SELECTIONBAR_ACTOR
};
#define BOXES_SELECTIONBAR_default_toolbar_width 500
BoxesSelectionbar* boxes_selectionbar_new (void);
BoxesSelectionbar* boxes_selectionbar_construct (GType object_type);
static void __lambda169_ (BoxesSelectionbar* self);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GList* boxes_app_get_selected_items (BoxesApp* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void ___lambda169__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda170_ (BoxesSelectionbar* self);
static Block53Data* block53_data_ref (Block53Data* _data53_);
static void block53_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda171_ (Block53Data* _data53_, GObject* obj, GAsyncResult* _result_);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void _____lambda171__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda170__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda172_ (BoxesSelectionbar* self);
void boxes_app_remove_selected_items (BoxesApp* self);
static void ___lambda172__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda175_ (BoxesSelectionbar* self);
void boxes_app_show_properties (BoxesApp* self);
static void ___lambda175__gtk_button_clicked (GtkButton* _sender, gpointer self);
ClutterActor* boxes_selectionbar_get_actor (BoxesSelectionbar* self);
static void __lambda176_ (BoxesSelectionbar* self);
static void boxes_selectionbar_update_visible (BoxesSelectionbar* self);
static void ___lambda176__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda177_ (BoxesSelectionbar* self);
static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self);
static void boxes_selectionbar_update_properties_btn (BoxesSelectionbar* self);
static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self);
static void ___lambda177__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void boxes_selectionbar_set_visible (BoxesSelectionbar* self, gboolean value);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
static void boxes_selectionbar_finalize (GObject* obj);
static void _vala_boxes_selectionbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_selectionbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 456 "selectionbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 463 "selectionbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_free (self);
#line 472 "selectionbar.c"
}


static void __lambda169_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 486 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 494 "selectionbar.c"
			BoxesCollectionItem* _tmp3_;
			BoxesCollectionItem* item = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 501 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp4_;
				BoxesMachine* _tmp5_;
				BoxesMachine* _tmp6_;
				BoxesMachine* _tmp7_;
				BoxesBoxConfig* _tmp8_;
				GtkToggleButton* _tmp9_;
				gboolean _tmp10_;
				gboolean _tmp11_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp5_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = machine;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 528 "selectionbar.c"
				}
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = _tmp7_->config;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = self->priv->favorite_btn;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = gtk_toggle_button_get_active (_tmp9_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _tmp10_;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_box_config_set_category (_tmp8_, "favorite", _tmp11_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 546 "selectionbar.c"
			}
		}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 551 "selectionbar.c"
	}
}


static void ___lambda169__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda169_ (self);
#line 559 "selectionbar.c"
}


static Block53Data* block53_data_ref (Block53Data* _data53_) {
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data53_->_ref_count_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return _data53_;
#line 568 "selectionbar.c"
}


static void block53_data_unref (void * _userdata_) {
	Block53Data* _data53_;
	_data53_ = (Block53Data*) _userdata_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data53_->_ref_count_)) {
#line 577 "selectionbar.c"
		BoxesSelectionbar * self;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		self = _data53_->self;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data53_->machine);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block53Data, _data53_);
#line 587 "selectionbar.c"
	}
}


static void ____lambda171_ (Block53Data* _data53_, GObject* obj, GAsyncResult* _result_) {
	BoxesSelectionbar * self;
	GError * _inner_error_ = NULL;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = _data53_->self;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (_result_ != NULL);
#line 599 "selectionbar.c"
	{
		BoxesMachine* _tmp0_;
		GAsyncResult* _tmp1_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = _data53_->machine;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp1_ = _result_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		boxes_machine_save_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (_inner_error_ != NULL) {
#line 611 "selectionbar.c"
			goto __catch63_g_error;
		}
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* e = NULL;
		BoxesApp* _tmp2_;
		BoxesNotificationbar* _tmp3_;
		const gchar* _tmp4_ = NULL;
		BoxesMachine* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_;
		GdNotification* _tmp10_ = NULL;
		GdNotification* _tmp11_;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		e = _inner_error_;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_inner_error_ = NULL;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp2_ = boxes_app_app;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = _tmp2_->notificationbar;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = _ ("Pausing '%s' failed");
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = _data53_->machine;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp5_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp7_ = _tmp6_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp8_ = g_strdup_printf (_tmp4_, _tmp7_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp9_ = _tmp8_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp10_ = boxes_notificationbar_display_error (_tmp3_, _tmp9_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp11_ = _tmp10_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_tmp11_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp9_);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_error_free0 (e);
#line 659 "selectionbar.c"
	}
	__finally63:
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (_inner_error_ != NULL) {
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_clear_error (&_inner_error_);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		return;
#line 670 "selectionbar.c"
	}
}


static void _____lambda171__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda171_ (self, source_object, res);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	block53_data_unref (self);
#line 680 "selectionbar.c"
}


static void __lambda170_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkButton* _tmp8_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 695 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 703 "selectionbar.c"
			BoxesCollectionItem* _tmp3_;
			BoxesCollectionItem* item = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 710 "selectionbar.c"
			{
				Block53Data* _data53_;
				BoxesCollectionItem* _tmp4_;
				BoxesMachine* _tmp5_;
				BoxesMachine* _tmp6_;
				BoxesMachine* _tmp7_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data53_ = g_slice_new0 (Block53Data);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data53_->_ref_count_ = 1;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data53_->self = g_object_ref (self);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data53_->machine = _tmp5_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _data53_->machine;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					block53_data_unref (_data53_);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_data53_ = NULL;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 741 "selectionbar.c"
				}
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = _data53_->machine;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_machine_save (_tmp7_, _____lambda171__gasync_ready_callback, block53_data_ref (_data53_));
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				block53_data_unref (_data53_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data53_ = NULL;
#line 753 "selectionbar.c"
			}
		}
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 758 "selectionbar.c"
	}
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = self->priv->pause_btn;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, FALSE);
#line 764 "selectionbar.c"
}


static void ___lambda170__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda170_ (self);
#line 771 "selectionbar.c"
}


static void __lambda172_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_remove_selected_items (_tmp0_);
#line 781 "selectionbar.c"
}


static void ___lambda172__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda172_ (self);
#line 788 "selectionbar.c"
}


static void __lambda175_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_show_properties (_tmp0_);
#line 798 "selectionbar.c"
}


static void ___lambda175__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda175_ (self);
#line 805 "selectionbar.c"
}


static void __lambda176_ (BoxesSelectionbar* self) {
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_visible (self);
#line 812 "selectionbar.c"
}


static void ___lambda176__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda176_ (self);
#line 819 "selectionbar.c"
}


static void __lambda177_ (BoxesSelectionbar* self) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_visible (self);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_favorite_btn (self);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_properties_btn (self);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_pause_btn (self);
#line 832 "selectionbar.c"
}


static void ___lambda177__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda177_ (self);
#line 839 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_construct (GType object_type) {
	BoxesSelectionbar * self = NULL;
	GtkToolbar* _tmp0_;
	GtkToolbar* _tmp1_;
	GtkToolbar* _tmp2_;
	GtkToolbar* _tmp3_;
	GtkToolbar* _tmp4_;
	GtkStyleContext* _tmp5_ = NULL;
	GtkBox* leftbox = NULL;
	GtkBox* _tmp6_;
	GtkToolItem* leftgroup = NULL;
	GtkToolItem* _tmp7_;
	GtkToolbar* _tmp8_;
	GtkSeparatorToolItem* separator = NULL;
	GtkSeparatorToolItem* _tmp9_;
	GtkToolbar* _tmp10_;
	GtkBox* rightbox = NULL;
	GtkBox* _tmp11_;
	GtkToolItem* rightgroup = NULL;
	GtkToolItem* _tmp12_;
	GtkToolbar* _tmp13_;
	GtkToolbar* _tmp14_;
	GtkClutterActor* _tmp15_;
	GtkClutterActor* _tmp16_;
	GtkWidget* _tmp17_ = NULL;
	GtkStyleContext* _tmp18_ = NULL;
	GtkClutterActor* _tmp19_;
	GtkClutterActor* _tmp20_;
	GtkClutterActor* _tmp21_;
	GtkClutterActor* _tmp22_;
	GtkClutterActor* _tmp23_;
	GtkClutterActor* _tmp24_;
	GtkToggleButton* _tmp25_;
	GtkToggleButton* _tmp26_;
	GtkToggleButton* _tmp27_;
	GtkImage* _tmp28_;
	GtkImage* _tmp29_;
	GtkToggleButton* _tmp30_;
	GtkButton* _tmp31_;
	GtkButton* _tmp32_;
	GtkButton* _tmp33_;
	GtkImage* _tmp34_;
	GtkImage* _tmp35_;
	GtkButton* _tmp36_;
	GtkButton* _tmp37_;
	GtkButton* _tmp38_;
	GtkButton* _tmp39_;
	GtkButton* _tmp40_;
	GtkButton* _tmp41_;
	GtkButton* _tmp42_;
	GtkToolbar* _tmp43_;
	ClutterActor* _tmp44_;
	ClutterActor* _tmp45_;
	BoxesApp* _tmp46_;
	BoxesApp* _tmp47_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = (BoxesSelectionbar*) g_object_new (object_type, NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = (GtkToolbar*) gtk_toolbar_new ();
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp0_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->toolbar = _tmp0_;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = self->priv->toolbar;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toolbar_set_show_arrow (_tmp1_, FALSE);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = self->priv->toolbar;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toolbar_set_icon_size (_tmp2_, (gint) GTK_ICON_SIZE_LARGE_TOOLBAR);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = self->priv->toolbar;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp3_, BOXES_SELECTIONBAR_default_toolbar_width, -1);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = self->priv->toolbar;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp5_, "osd");
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp6_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	leftbox = _tmp6_;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = gtk_tool_item_new ();
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp7_);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	leftgroup = _tmp7_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) leftgroup, (GtkWidget*) leftbox);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = self->priv->toolbar;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toolbar_insert (_tmp8_, leftgroup, -1);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = (GtkSeparatorToolItem*) gtk_separator_tool_item_new ();
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp9_);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	separator = _tmp9_;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_tool_item_set_expand ((GtkToolItem*) separator, TRUE);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_separator_tool_item_set_draw (separator, FALSE);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = self->priv->toolbar;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toolbar_insert (_tmp10_, (GtkToolItem*) separator, -1);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp11_);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	rightbox = _tmp11_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = gtk_tool_item_new ();
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp12_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	rightgroup = _tmp12_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) rightgroup, (GtkWidget*) rightbox);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = self->priv->toolbar;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toolbar_insert (_tmp13_, rightgroup, -1);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp14_ = self->priv->toolbar;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp14_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp15_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->gtk_actor = _tmp15_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = self->priv->gtk_actor;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp17_ = gtk_clutter_actor_get_widget (_tmp16_);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp18_ = gtk_widget_get_style_context (_tmp17_);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp18_, "boxes-bg");
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp19_ = self->priv->gtk_actor;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp19_, (guint) 0);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp20_ = self->priv->gtk_actor;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_margin_bottom ((ClutterActor*) _tmp20_, (gfloat) 32);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp21_ = self->priv->gtk_actor;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp21_, CLUTTER_ACTOR_ALIGN_CENTER);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->gtk_actor;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp22_, CLUTTER_ACTOR_ALIGN_END);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = self->priv->gtk_actor;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp23_, TRUE);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = self->priv->gtk_actor;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp24_, TRUE);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = (GtkToggleButton*) gtk_toggle_button_new ();
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp25_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->favorite_btn = _tmp25_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp26_ = self->priv->favorite_btn;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) leftbox, (GtkWidget*) _tmp26_);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp27_ = self->priv->favorite_btn;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp28_ = (GtkImage*) gtk_image_new_from_icon_name ("emblem-favorite-symbolic", GTK_ICON_SIZE_MENU);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp28_);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp29_ = _tmp28_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_button_set_image ((GtkButton*) _tmp27_, (GtkWidget*) _tmp29_);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (_tmp29_);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp30_ = self->priv->favorite_btn;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp30_, "clicked", (GCallback) ___lambda169__gtk_button_clicked, self, 0);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp31_ = (GtkButton*) gtk_button_new ();
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp31_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->pause_btn = _tmp31_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp32_ = self->priv->pause_btn;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) leftbox, (GtkWidget*) _tmp32_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp33_ = self->priv->pause_btn;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp34_ = (GtkImage*) gtk_image_new_from_icon_name ("media-playback-pause-symbolic", GTK_ICON_SIZE_MENU);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp34_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp35_ = _tmp34_;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_button_set_image (_tmp33_, (GtkWidget*) _tmp35_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (_tmp35_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp36_ = self->priv->pause_btn;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp36_, "clicked", (GCallback) ___lambda170__gtk_button_clicked, self, 0);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp37_ = (GtkButton*) gtk_button_new_from_stock (GTK_STOCK_DELETE);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp37_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->remove_btn = _tmp37_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp38_ = self->priv->remove_btn;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) rightbox, (GtkWidget*) _tmp38_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp39_ = self->priv->remove_btn;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp39_, "clicked", (GCallback) ___lambda172__gtk_button_clicked, self, 0);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp40_ = (GtkButton*) gtk_button_new_from_stock (GTK_STOCK_PROPERTIES);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp40_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->properties_btn);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->properties_btn = _tmp40_;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp41_ = self->priv->properties_btn;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) rightbox, (GtkWidget*) _tmp41_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp42_ = self->priv->properties_btn;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp42_, "clicked", (GCallback) ___lambda175__gtk_button_clicked, self, 0);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp43_ = self->priv->toolbar;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp43_);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp44_ = boxes_selectionbar_get_actor (self);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp45_ = _tmp44_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	clutter_actor_set_reactive (_tmp45_, TRUE);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp46_ = boxes_app_app;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp46_, "notify::selection-mode", (GCallback) ___lambda176__g_object_notify, self, 0);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp47_ = boxes_app_app;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp47_, "notify::selected-items", (GCallback) ___lambda177__g_object_notify, self, 0);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (rightgroup);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (rightbox);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (separator);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (leftgroup);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (leftbox);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self;
#line 1136 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_new (void) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return boxes_selectionbar_construct (BOXES_TYPE_SELECTIONBAR);
#line 1143 "selectionbar.c"
}


static void boxes_selectionbar_update_visible (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selection_mode (_tmp0_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (!_tmp2_) {
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		boxes_selectionbar_set_visible (self, FALSE);
#line 1163 "selectionbar.c"
	} else {
		BoxesApp* _tmp3_;
		GList* _tmp4_;
		GList* _tmp5_;
		GList* _tmp6_;
		guint _tmp7_ = 0U;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = boxes_app_app;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = boxes_app_get_selected_items (_tmp3_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = _tmp4_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp6_ = _tmp5_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp7_ = g_list_length (_tmp6_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		boxes_selectionbar_set_visible (self, _tmp7_ > ((guint) 0));
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (_tmp6_);
#line 1184 "selectionbar.c"
	}
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	for (i = 0; i < stack_length; i++) {
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			return TRUE;
#line 1197 "selectionbar.c"
		}
	}
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return FALSE;
#line 1202 "selectionbar.c"
}


static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self) {
	gboolean active = FALSE;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	guint _tmp4_ = 0U;
	gboolean _tmp5_;
	BoxesApp* _tmp6_;
	GList* _tmp7_;
	GList* _tmp8_;
	GtkToggleButton* _tmp22_;
	gboolean _tmp23_;
	GtkToggleButton* _tmp24_;
	gboolean _tmp25_;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	active = FALSE;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ > ((guint) 0);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = boxes_app_app;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = boxes_app_get_selected_items (_tmp6_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = _tmp7_;
#line 1248 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp8_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1256 "selectionbar.c"
			BoxesCollectionItem* _tmp9_;
			BoxesCollectionItem* item = NULL;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp9_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp9_;
#line 1263 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp10_;
				BoxesMachine* _tmp11_;
				BoxesMachine* _tmp12_;
				gboolean is_favorite = FALSE;
				BoxesMachine* _tmp13_;
				BoxesBoxConfig* _tmp14_;
				gchar** _tmp15_;
				gint _tmp15__length1;
				gchar** _tmp16_;
				gint _tmp16__length1;
				gchar** _tmp17_;
				gint _tmp17__length1;
				gboolean _tmp18_;
				gboolean _tmp19_;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = item;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp11_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = machine;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp12_ == NULL) {
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1296 "selectionbar.c"
				}
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = machine;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp13_->config;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = boxes_box_config_get_categories (_tmp14_, &_tmp15__length1);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16_ = _tmp15_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16__length1 = _tmp15__length1;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = _tmp16_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17__length1 = _tmp16__length1;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp18_ = _vala_string_array_contains (_tmp17_, _tmp16__length1, "favorite");
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = (_vala_array_free (_tmp17_, _tmp17__length1, (GDestroyNotify) g_free), NULL);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				is_favorite = _tmp18_;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp19_ = active;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!_tmp19_) {
#line 1322 "selectionbar.c"
					gboolean _tmp20_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = is_favorite;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					active = _tmp20_;
#line 1328 "selectionbar.c"
				} else {
					gboolean _tmp21_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp21_ = is_favorite;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					if (!_tmp21_) {
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						sensitive = FALSE;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (machine);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (item);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						break;
#line 1343 "selectionbar.c"
					}
				}
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1350 "selectionbar.c"
			}
		}
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1355 "selectionbar.c"
	}
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->favorite_btn;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = active;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toggle_button_set_active (_tmp22_, _tmp23_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = self->priv->favorite_btn;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = sensitive;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp24_, _tmp25_);
#line 1369 "selectionbar.c"
}


static void boxes_selectionbar_update_properties_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	guint _tmp4_ = 0U;
	gboolean _tmp5_;
	GtkButton* _tmp6_;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ == ((guint) 1);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = self->priv->properties_btn;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, sensitive);
#line 1404 "selectionbar.c"
}


static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkButton* _tmp15_;
	gboolean _tmp16_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = FALSE;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 1425 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1433 "selectionbar.c"
			BoxesCollectionItem* _tmp3_;
			BoxesCollectionItem* item = NULL;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 1440 "selectionbar.c"
			{
				BoxesCollectionItem* _tmp4_;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_;
				BoxesMachine* _tmp6_;
				gboolean _tmp7_ = FALSE;
				BoxesMachine* _tmp8_;
				gboolean _tmp9_;
				gboolean _tmp10_;
				gboolean _tmp14_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE)) {
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1459 "selectionbar.c"
				}
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = machine;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = boxes_machine_get_can_save (_tmp8_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = _tmp9_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp10_) {
#line 1475 "selectionbar.c"
					BoxesMachine* _tmp11_;
					BoxesMachineMachineState _tmp12_;
					BoxesMachineMachineState _tmp13_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp11_ = machine;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp12_ = boxes_machine_get_state (_tmp11_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp13_ = _tmp12_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp7_ = _tmp13_ != BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 1487 "selectionbar.c"
				} else {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp7_ = FALSE;
#line 1491 "selectionbar.c"
				}
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp7_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp14_) {
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = TRUE;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1505 "selectionbar.c"
				}
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1511 "selectionbar.c"
			}
		}
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1516 "selectionbar.c"
	}
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = self->priv->pause_btn;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = sensitive;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp15_, _tmp16_);
#line 1524 "selectionbar.c"
}


ClutterActor* boxes_selectionbar_get_actor (BoxesSelectionbar* self) {
	ClutterActor* result;
	GtkClutterActor* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	result = (ClutterActor*) _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return result;
#line 1539 "selectionbar.c"
}


static void boxes_selectionbar_set_visible (BoxesSelectionbar* self, gboolean value) {
	gint _tmp0_ = 0;
	gboolean _tmp1_;
	ClutterActor* _tmp2_;
	ClutterActor* _tmp3_;
	gint _tmp4_;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = value;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (_tmp1_) {
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = 255;
#line 1557 "selectionbar.c"
	} else {
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = 0;
#line 1561 "selectionbar.c"
	}
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = boxes_selectionbar_get_actor (self);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = _tmp0_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_fade_actor (_tmp3_, (guint) _tmp4_);
#line 1571 "selectionbar.c"
}


static void boxes_selectionbar_class_init (BoxesSelectionbarClass * klass) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSelectionbarPrivate));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_selectionbar_get_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_selectionbar_set_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_selectionbar_finalize;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SELECTIONBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1588 "selectionbar.c"
}


static void boxes_selectionbar_instance_init (BoxesSelectionbar * self) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv = BOXES_SELECTIONBAR_GET_PRIVATE (self);
#line 1595 "selectionbar.c"
}


static void boxes_selectionbar_finalize (GObject* obj) {
	BoxesSelectionbar * self;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->properties_btn);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (boxes_selectionbar_parent_class)->finalize (obj);
#line 1617 "selectionbar.c"
}


GType boxes_selectionbar_get_type (void) {
	static volatile gsize boxes_selectionbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selectionbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSelectionbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_selectionbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSelectionbar), 0, (GInstanceInitFunc) boxes_selectionbar_instance_init, NULL };
		GType boxes_selectionbar_type_id;
		boxes_selectionbar_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesSelectionbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_selectionbar_type_id__volatile, boxes_selectionbar_type_id);
	}
	return boxes_selectionbar_type_id__volatile;
}


static void _vala_boxes_selectionbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSelectionbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	switch (property_id) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		case BOXES_SELECTIONBAR_ACTOR:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_value_set_object (value, boxes_selectionbar_get_actor (self));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		break;
#line 1644 "selectionbar.c"
		default:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		break;
#line 1650 "selectionbar.c"
	}
}


static void _vala_boxes_selectionbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSelectionbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	switch (property_id) {
#line 1660 "selectionbar.c"
		default:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		break;
#line 1666 "selectionbar.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1674 "selectionbar.c"
		int i;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1682 "selectionbar.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1694 "selectionbar.c"
}



