/* searchbar.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from searchbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;
typedef struct _BoxesSearchbarPrivate BoxesSearchbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _Block52Data Block52Data;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesSearchbar {
	BoxesUI parent_instance;
	BoxesSearchbarPrivate * priv;
};

struct _BoxesSearchbarClass {
	BoxesUIClass parent_class;
};

struct _BoxesSearchbarPrivate {
	GtkClutterActor* gtk_actor;
	GdTaggedEntry* entry;
	guint refilter_delay_id;
	gulong key_handler_id;
	gboolean _visible;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block52Data {
	int _ref_count_;
	BoxesSearchbar * self;
	gboolean preedit_changed;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;


static gpointer boxes_searchbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
#define BOXES_SEARCHBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SEARCHBAR, BoxesSearchbarPrivate))
enum  {
	BOXES_SEARCHBAR_DUMMY_PROPERTY,
	BOXES_SEARCHBAR_ACTOR,
	BOXES_SEARCHBAR_ENABLE_KEY_HANDLER,
	BOXES_SEARCHBAR_VISIBLE,
	BOXES_SEARCHBAR_TEXT
};
#define BOXES_SEARCHBAR_refilter_delay ((guint) 200)
BoxesSearchbar* boxes_searchbar_new (void);
BoxesSearchbar* boxes_searchbar_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_searchbar_setup_searchbar (BoxesSearchbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static gboolean boxes_searchbar_on_app_key_pressed (BoxesSearchbar* self, GtkWidget* widget, GdkEventKey* event);
static gboolean _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void __lambda33_ (BoxesSearchbar* self);
const gchar* boxes_searchbar_get_text (BoxesSearchbar* self);
static gboolean boxes_searchbar_refilter (BoxesSearchbar* self);
static gboolean _boxes_searchbar_refilter_gsource_func (gpointer self);
static void ___lambda33__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda64_ (BoxesSearchbar* self);
void boxes_collection_view_activate (BoxesCollectionView* self);
static void ___lambda64__gtk_entry_activate (GtkEntry* _sender, gpointer self);
void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_searchbar_grab_focus (BoxesSearchbar* self);
static Block52Data* block52_data_ref (Block52Data* _data52_);
static void block52_data_unref (void * _userdata_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void __lambda30_ (Block52Data* _data52_);
static void ___lambda30__gtk_entry_preedit_changed (GtkEntry* _sender, const gchar* p0, gpointer self);
gboolean boxes_searchbar_get_visible (BoxesSearchbar* self);
void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value);
void boxes_searchbar_set_visible (BoxesSearchbar* self, gboolean value);
static void boxes_searchbar_real_ui_state_changed (BoxesUI* base);
void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value);
void boxes_revealer_set_revealed (BoxesRevealer* self, gboolean value);
static void boxes_searchbar_finalize (GObject* obj);
static void _vala_boxes_searchbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_searchbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gboolean _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_searchbar_on_app_key_pressed (self, _sender, event);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 344 "searchbar.c"
}


static gboolean _boxes_searchbar_refilter_gsource_func (gpointer self) {
	gboolean result;
	result = boxes_searchbar_refilter (self);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 353 "searchbar.c"
}


static void __lambda33_ (BoxesSearchbar* self) {
	guint _tmp0_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->refilter_delay_id;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 365 "searchbar.c"
		guint _tmp1_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp1_ = self->priv->refilter_delay_id;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_source_remove (_tmp1_);
#line 371 "searchbar.c"
	}
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_searchbar_get_text (self);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (g_strcmp0 (_tmp3_, "") == 0) {
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_refilter (self);
#line 381 "searchbar.c"
	} else {
		guint _tmp4_ = 0U;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_SEARCHBAR_refilter_delay, _boxes_searchbar_refilter_gsource_func, g_object_ref (self), g_object_unref);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		self->priv->refilter_delay_id = _tmp4_;
#line 388 "searchbar.c"
	}
}


static void ___lambda33__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda33_ (self);
#line 396 "searchbar.c"
}


static void __lambda64_ (BoxesSearchbar* self) {
	BoxesApp* _tmp0_;
	BoxesCollectionView* _tmp1_;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->view;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_view_activate (_tmp1_);
#line 409 "searchbar.c"
}


static void ___lambda64__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda64_ (self);
#line 416 "searchbar.c"
}


BoxesSearchbar* boxes_searchbar_construct (GType object_type) {
	BoxesSearchbar * self = NULL;
	BoxesApp* _tmp0_;
	GtkApplicationWindow* _tmp1_;
	gulong _tmp2_ = 0UL;
	GdTaggedEntry* _tmp3_;
	GdTaggedEntry* _tmp4_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) boxes_ui_construct (object_type);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_searchbar_setup_searchbar (self);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->window;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = g_signal_connect_object ((GtkWidget*) _tmp1_, "key-press-event", (GCallback) _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event, self, 0);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->key_handler_id = _tmp2_;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = self->priv->entry;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::text", (GCallback) ___lambda33__g_object_notify, self, 0);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = self->priv->entry;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_connect_object ((GtkEntry*) _tmp4_, "activate", (GCallback) ___lambda64__gtk_entry_activate, self, 0);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return self;
#line 449 "searchbar.c"
}


BoxesSearchbar* boxes_searchbar_new (void) {
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return boxes_searchbar_construct (BOXES_TYPE_SEARCHBAR);
#line 456 "searchbar.c"
}


static gboolean boxes_searchbar_refilter (BoxesSearchbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_;
	BoxesCollectionFilter* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	BoxesApp* _tmp4_;
	BoxesCollectionView* _tmp5_;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->filter;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_searchbar_get_text (self);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_filter_set_text (_tmp1_, _tmp3_);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = boxes_app_app;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = _tmp4_->view;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_view_refilter (_tmp5_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->refilter_delay_id = (guint) 0;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = FALSE;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 492 "searchbar.c"
}


void boxes_searchbar_grab_focus (BoxesSearchbar* self) {
	GdTaggedEntry* _tmp0_;
	GdkDevice* _tmp1_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = gtk_get_current_event_device ();
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gd_entry_focus_hack ((GtkWidget*) _tmp0_, _tmp1_);
#line 507 "searchbar.c"
}


static Block52Data* block52_data_ref (Block52Data* _data52_) {
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_atomic_int_inc (&_data52_->_ref_count_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return _data52_;
#line 516 "searchbar.c"
}


static void block52_data_unref (void * _userdata_) {
	Block52Data* _data52_;
	_data52_ = (Block52Data*) _userdata_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (g_atomic_int_dec_and_test (&_data52_->_ref_count_)) {
#line 525 "searchbar.c"
		BoxesSearchbar * self;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		self = _data52_->self;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_g_object_unref0 (self);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_slice_free (Block52Data, _data52_);
#line 533 "searchbar.c"
	}
}


static void __lambda30_ (Block52Data* _data52_) {
	BoxesSearchbar * self;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = _data52_->self;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_->preedit_changed = TRUE;
#line 544 "searchbar.c"
}


static void ___lambda30__gtk_entry_preedit_changed (GtkEntry* _sender, const gchar* p0, gpointer self) {
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda30_ (self);
#line 551 "searchbar.c"
}


static gboolean boxes_searchbar_on_app_key_pressed (BoxesSearchbar* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	Block52Data* _data52_;
	gboolean handled = FALSE;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	GdTaggedEntry* _tmp2_;
	gboolean _tmp3_ = FALSE;
	gulong preedit_changed_id = 0UL;
	GdTaggedEntry* _tmp8_;
	gulong _tmp9_ = 0UL;
	gchar* old_text = NULL;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gboolean _tmp13_;
	gboolean _tmp14_;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp20_;
	gboolean res = FALSE;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp25_ = FALSE;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp30_ = FALSE;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	gboolean _tmp38_ = FALSE;
	GdkEventKey _tmp39_;
	guint _tmp40_;
	gboolean _tmp43_;
	gboolean _tmp46_;
	gboolean _tmp49_;
	gboolean _tmp52_;
	gboolean _tmp55_;
	gboolean _tmp58_;
	gboolean _tmp61_;
	gboolean _tmp64_;
	gboolean _tmp67_;
	gboolean _tmp70_;
	gboolean _tmp73_;
	gboolean _tmp76_;
	gboolean _tmp79_;
	gboolean _tmp82_;
	gboolean _tmp85_;
	gboolean _tmp88_;
	gboolean _tmp91_;
	gboolean _tmp94_;
	gchar* new_text = NULL;
	const gchar* _tmp97_;
	const gchar* _tmp98_;
	gchar* _tmp99_;
	GdTaggedEntry* _tmp100_;
	gulong _tmp101_;
	gboolean _tmp102_ = FALSE;
	gboolean _tmp103_ = FALSE;
	gboolean _tmp104_;
	gboolean _tmp107_;
	gboolean _tmp109_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_ = g_slice_new0 (Block52Data);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_->_ref_count_ = 1;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_->self = g_object_ref (self);
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	handled = FALSE;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp1_ != BOXES_UI_STATE_COLLECTION) {
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		result = handled;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		block52_data_unref (_data52_);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_data52_ = NULL;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return result;
#line 654 "searchbar.c"
	}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = self->priv->entry;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = gtk_widget_get_realized ((GtkWidget*) _tmp2_);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (!_tmp3_) {
#line 662 "searchbar.c"
		ClutterActor* _tmp4_;
		ClutterActor* _tmp5_;
		ClutterActor* _tmp6_;
		ClutterActor* _tmp7_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp5_ = _tmp4_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		clutter_actor_show (_tmp5_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp6_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp7_ = _tmp6_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		clutter_actor_hide (_tmp7_);
#line 679 "searchbar.c"
	}
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_->preedit_changed = FALSE;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp8_ = self->priv->entry;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp9_ = g_signal_connect_data ((GtkEntry*) _tmp8_, "preedit-changed", (GCallback) ___lambda30__gtk_entry_preedit_changed, block52_data_ref (_data52_), (GClosureNotify) block52_data_unref, 0);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	preedit_changed_id = _tmp9_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp10_ = boxes_searchbar_get_text (self);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp11_ = _tmp10_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	old_text = _tmp12_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp13_ = boxes_searchbar_get_visible (self);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp14_ = _tmp13_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (!_tmp14_) {
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 705 "searchbar.c"
	}
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp16_ = boxes_searchbar_get_visible (self);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp17_ = _tmp16_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp17_) {
#line 713 "searchbar.c"
		GdkEventKey _tmp18_;
		guint _tmp19_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp18_ = *event;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp19_ = _tmp18_.keyval;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp15_ = _tmp19_ == ((guint) GDK_KEY_Escape);
#line 722 "searchbar.c"
	} else {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp15_ = FALSE;
#line 726 "searchbar.c"
	}
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp20_ = _tmp15_;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp20_) {
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_visible (self, FALSE);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		result = TRUE;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_g_free0 (old_text);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		block52_data_unref (_data52_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_data52_ = NULL;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return result;
#line 746 "searchbar.c"
	}
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	res = FALSE;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp39_ = *event;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp40_ = _tmp39_.keyval;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp40_ != ((guint) GDK_KEY_Tab)) {
#line 756 "searchbar.c"
		GdkEventKey _tmp41_;
		guint _tmp42_;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp41_ = *event;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp42_ = _tmp41_.keyval;
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp38_ = _tmp42_ != ((guint) GDK_KEY_KP_Tab);
#line 765 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp38_ = FALSE;
#line 769 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp43_ = _tmp38_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp43_) {
#line 775 "searchbar.c"
		GdkEventKey _tmp44_;
		guint _tmp45_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp44_ = *event;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp45_ = _tmp44_.keyval;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp37_ = _tmp45_ != ((guint) GDK_KEY_Up);
#line 784 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp37_ = FALSE;
#line 788 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp46_ = _tmp37_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp46_) {
#line 794 "searchbar.c"
		GdkEventKey _tmp47_;
		guint _tmp48_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp47_ = *event;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp48_ = _tmp47_.keyval;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp36_ = _tmp48_ != ((guint) GDK_KEY_KP_Up);
#line 803 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp36_ = FALSE;
#line 807 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp49_ = _tmp36_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp49_) {
#line 813 "searchbar.c"
		GdkEventKey _tmp50_;
		guint _tmp51_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp50_ = *event;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp51_ = _tmp50_.keyval;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp35_ = _tmp51_ != ((guint) GDK_KEY_Down);
#line 822 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp35_ = FALSE;
#line 826 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp52_ = _tmp35_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp52_) {
#line 832 "searchbar.c"
		GdkEventKey _tmp53_;
		guint _tmp54_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp53_ = *event;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp54_ = _tmp53_.keyval;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp34_ = _tmp54_ != ((guint) GDK_KEY_KP_Down);
#line 841 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp34_ = FALSE;
#line 845 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp55_ = _tmp34_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp55_) {
#line 851 "searchbar.c"
		GdkEventKey _tmp56_;
		guint _tmp57_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp56_ = *event;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp57_ = _tmp56_.keyval;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp33_ = _tmp57_ != ((guint) GDK_KEY_Left);
#line 860 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp33_ = FALSE;
#line 864 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp58_ = _tmp33_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp58_) {
#line 870 "searchbar.c"
		GdkEventKey _tmp59_;
		guint _tmp60_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp59_ = *event;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp60_ = _tmp59_.keyval;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp32_ = _tmp60_ != ((guint) GDK_KEY_KP_Left);
#line 879 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp32_ = FALSE;
#line 883 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp61_ = _tmp32_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp61_) {
#line 889 "searchbar.c"
		GdkEventKey _tmp62_;
		guint _tmp63_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp62_ = *event;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp63_ = _tmp62_.keyval;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp31_ = _tmp63_ != ((guint) GDK_KEY_Right);
#line 898 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp31_ = FALSE;
#line 902 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp64_ = _tmp31_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp64_) {
#line 908 "searchbar.c"
		GdkEventKey _tmp65_;
		guint _tmp66_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp65_ = *event;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp66_ = _tmp65_.keyval;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp30_ = _tmp66_ != ((guint) GDK_KEY_KP_Right);
#line 917 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp30_ = FALSE;
#line 921 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp67_ = _tmp30_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp67_) {
#line 927 "searchbar.c"
		GdkEventKey _tmp68_;
		guint _tmp69_;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp68_ = *event;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp69_ = _tmp68_.keyval;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp29_ = _tmp69_ != ((guint) GDK_KEY_Home);
#line 936 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp29_ = FALSE;
#line 940 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp70_ = _tmp29_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp70_) {
#line 946 "searchbar.c"
		GdkEventKey _tmp71_;
		guint _tmp72_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp71_ = *event;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp72_ = _tmp71_.keyval;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp28_ = _tmp72_ != ((guint) GDK_KEY_KP_Home);
#line 955 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp28_ = FALSE;
#line 959 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp73_ = _tmp28_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp73_) {
#line 965 "searchbar.c"
		GdkEventKey _tmp74_;
		guint _tmp75_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp74_ = *event;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp75_ = _tmp74_.keyval;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp27_ = _tmp75_ != ((guint) GDK_KEY_End);
#line 974 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp27_ = FALSE;
#line 978 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp76_ = _tmp27_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp76_) {
#line 984 "searchbar.c"
		GdkEventKey _tmp77_;
		guint _tmp78_;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp77_ = *event;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp78_ = _tmp77_.keyval;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp26_ = _tmp78_ != ((guint) GDK_KEY_KP_End);
#line 993 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp26_ = FALSE;
#line 997 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp79_ = _tmp26_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp79_) {
#line 1003 "searchbar.c"
		GdkEventKey _tmp80_;
		guint _tmp81_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp80_ = *event;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp81_ = _tmp80_.keyval;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp25_ = _tmp81_ != ((guint) GDK_KEY_Page_Up);
#line 1012 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp25_ = FALSE;
#line 1016 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp82_ = _tmp25_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp82_) {
#line 1022 "searchbar.c"
		GdkEventKey _tmp83_;
		guint _tmp84_;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp83_ = *event;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp84_ = _tmp83_.keyval;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp24_ = _tmp84_ != ((guint) GDK_KEY_KP_Page_Up);
#line 1031 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp24_ = FALSE;
#line 1035 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp85_ = _tmp24_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp85_) {
#line 1041 "searchbar.c"
		GdkEventKey _tmp86_;
		guint _tmp87_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp86_ = *event;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp87_ = _tmp86_.keyval;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp23_ = _tmp87_ != ((guint) GDK_KEY_Page_Down);
#line 1050 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp23_ = FALSE;
#line 1054 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp88_ = _tmp23_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp88_) {
#line 1060 "searchbar.c"
		GdkEventKey _tmp89_;
		guint _tmp90_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp89_ = *event;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp90_ = _tmp89_.keyval;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp22_ = _tmp90_ != ((guint) GDK_KEY_KP_Page_Down);
#line 1069 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp22_ = FALSE;
#line 1073 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp91_ = _tmp22_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp91_) {
#line 1079 "searchbar.c"
		GdkEventKey _tmp92_;
		GdkModifierType _tmp93_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp92_ = *event;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp93_ = _tmp92_.state;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp21_ = (_tmp93_ & (GDK_CONTROL_MASK | GDK_MOD1_MASK)) == 0;
#line 1088 "searchbar.c"
	} else {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp21_ = FALSE;
#line 1092 "searchbar.c"
	}
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp94_ = _tmp21_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp94_) {
#line 1098 "searchbar.c"
		GdTaggedEntry* _tmp95_;
		gboolean _tmp96_ = FALSE;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp95_ = self->priv->entry;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp96_ = gtk_widget_event ((GtkWidget*) _tmp95_, (GdkEvent*) (event));
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		res = _tmp96_;
#line 1107 "searchbar.c"
	}
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp97_ = boxes_searchbar_get_text (self);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp98_ = _tmp97_;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp99_ = g_strdup (_tmp98_);
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	new_text = _tmp99_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp100_ = self->priv->entry;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp101_ = preedit_changed_id;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_handler_disconnect ((GObject*) _tmp100_, _tmp101_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp104_ = res;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp104_) {
#line 1127 "searchbar.c"
		const gchar* _tmp105_;
		const gchar* _tmp106_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp105_ = new_text;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp106_ = old_text;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp103_ = g_strcmp0 (_tmp105_, _tmp106_) != 0;
#line 1136 "searchbar.c"
	} else {
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp103_ = FALSE;
#line 1140 "searchbar.c"
	}
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp107_ = _tmp103_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp107_) {
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp102_ = TRUE;
#line 1148 "searchbar.c"
	} else {
		gboolean _tmp108_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp108_ = _data52_->preedit_changed;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp102_ = _tmp108_;
#line 1155 "searchbar.c"
	}
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp109_ = _tmp102_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp109_) {
#line 1161 "searchbar.c"
		gboolean _tmp110_;
		gboolean _tmp111_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		handled = TRUE;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp110_ = boxes_searchbar_get_visible (self);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp111_ = _tmp110_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		if (!_tmp111_) {
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
			boxes_searchbar_set_visible (self, TRUE);
#line 1174 "searchbar.c"
		} else {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
			boxes_searchbar_grab_focus (self);
#line 1178 "searchbar.c"
		}
	}
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = handled;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_free0 (new_text);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_free0 (old_text);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	block52_data_unref (_data52_);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data52_ = NULL;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1193 "searchbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 1200 "searchbar.c"
}


static void boxes_searchbar_setup_searchbar (BoxesSearchbar* self) {
	GtkToolbar* toolbar = NULL;
	GtkToolbar* _tmp0_;
	GtkToolbar* widget = NULL;
	GtkToolbar* _tmp1_;
	GtkStyleContext* _tmp2_ = NULL;
	GtkToolItem* item = NULL;
	GtkToolItem* _tmp3_;
	GdMarginContainer* margin = NULL;
	GdMarginContainer* _tmp4_;
	GtkBox* box = NULL;
	GtkBox* _tmp5_;
	GdTaggedEntry* _tmp6_;
	GdTaggedEntry* _tmp7_;
	GdTaggedEntry* _tmp8_;
	GdTaggedEntry* _tmp9_;
	GtkClutterActor* _tmp10_;
	GtkClutterActor* _tmp11_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = (GtkToolbar*) gtk_toolbar_new ();
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp0_);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	toolbar = _tmp0_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _g_object_ref0 (toolbar);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	widget = _tmp1_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_style_context_add_class (_tmp2_, GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = gtk_tool_item_new ();
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp3_);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	item = _tmp3_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_toolbar_insert (toolbar, item, 0);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_tool_item_set_expand (item, TRUE);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = gd_margin_container_new ();
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp4_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	margin = _tmp4_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) item, (GtkWidget*) margin);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set (margin, "min-margin", 6, NULL);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set (margin, "max-margin", 64, NULL);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp5_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	box = _tmp5_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) margin, (GtkWidget*) box);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp6_ = gd_tagged_entry_new ();
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp6_);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->entry);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->entry = _tmp6_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp7_ = self->priv->entry;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set ((GtkWidget*) _tmp7_, "width-request", 260, NULL);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp8_ = self->priv->entry;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp8_, TRUE);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp9_ = self->priv->entry;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) _tmp9_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_widget_show_all ((GtkWidget*) widget);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp10_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) widget);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp10_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->gtk_actor = _tmp10_;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp11_ = self->priv->gtk_actor;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp11_, "searchbar");
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (box);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (margin);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (item);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (widget);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (toolbar);
#line 1312 "searchbar.c"
}


static void boxes_searchbar_real_ui_state_changed (BoxesUI* base) {
	BoxesSearchbar * self;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) base;
#line 1320 "searchbar.c"
}


static ClutterActor* boxes_searchbar_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesSearchbar* self;
	GtkClutterActor* _tmp0_;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) base;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = (ClutterActor*) _tmp0_;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1336 "searchbar.c"
}


void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value) {
	gboolean _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = value;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_) {
#line 1348 "searchbar.c"
		BoxesApp* _tmp1_;
		GtkApplicationWindow* _tmp2_;
		gulong _tmp3_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp1_ = boxes_app_app;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp2_ = _tmp1_->window;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp3_ = self->priv->key_handler_id;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_signal_handler_unblock (_tmp2_, _tmp3_);
#line 1360 "searchbar.c"
	} else {
		BoxesApp* _tmp4_;
		GtkApplicationWindow* _tmp5_;
		gulong _tmp6_;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = boxes_app_app;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp5_ = _tmp4_->window;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp6_ = self->priv->key_handler_id;
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_signal_handler_block (_tmp5_, _tmp6_);
#line 1373 "searchbar.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "enable-key-handler");
#line 1377 "searchbar.c"
}


gboolean boxes_searchbar_get_visible (BoxesSearchbar* self) {
	gboolean result;
	gboolean _tmp0_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->_visible;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = _tmp0_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1392 "searchbar.c"
}


void boxes_searchbar_set_visible (BoxesSearchbar* self, gboolean value) {
	gboolean _tmp0_;
	gboolean _tmp1_;
	BoxesApp* _tmp2_;
	BoxesRevealer* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->_visible;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = value;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_ == _tmp1_) {
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return;
#line 1414 "searchbar.c"
	}
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_app_app;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_->searchbar_revealer;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = value;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_revealer_set_revealed (_tmp3_, _tmp4_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = value;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp5_) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_grab_focus (self);
#line 1430 "searchbar.c"
	} else {
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 1434 "searchbar.c"
	}
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp6_ = value;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->_visible = _tmp6_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "visible");
#line 1442 "searchbar.c"
}


const gchar* boxes_searchbar_get_text (BoxesSearchbar* self) {
	const gchar* result;
	GdTaggedEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = gtk_entry_get_text ((GtkEntry*) _tmp0_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = _tmp1_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = _tmp2_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1463 "searchbar.c"
}


void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value) {
	GdTaggedEntry* _tmp0_;
	const gchar* _tmp1_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = value;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_entry_set_text ((GtkEntry*) _tmp0_, _tmp1_);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "text");
#line 1480 "searchbar.c"
}


static void boxes_searchbar_class_init (BoxesSearchbarClass * klass) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_searchbar_parent_class = g_type_class_peek_parent (klass);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSearchbarPrivate));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_searchbar_real_ui_state_changed;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_searchbar_real_get_actor;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_searchbar_get_property;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_searchbar_set_property;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_searchbar_finalize;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_ENABLE_KEY_HANDLER, g_param_spec_boolean ("enable-key-handler", "enable-key-handler", "enable-key-handler", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_VISIBLE, g_param_spec_boolean ("visible", "visible", "visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1507 "searchbar.c"
}


static void boxes_searchbar_instance_init (BoxesSearchbar * self) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv = BOXES_SEARCHBAR_GET_PRIVATE (self);
#line 1514 "searchbar.c"
}


static void boxes_searchbar_finalize (GObject* obj) {
	BoxesSearchbar * self;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->entry);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (boxes_searchbar_parent_class)->finalize (obj);
#line 1528 "searchbar.c"
}


GType boxes_searchbar_get_type (void) {
	static volatile gsize boxes_searchbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_searchbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSearchbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_searchbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSearchbar), 0, (GInstanceInitFunc) boxes_searchbar_instance_init, NULL };
		GType boxes_searchbar_type_id;
		boxes_searchbar_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesSearchbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_searchbar_type_id__volatile, boxes_searchbar_type_id);
	}
	return boxes_searchbar_type_id__volatile;
}


static void _vala_boxes_searchbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSearchbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	switch (property_id) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_ACTOR:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_VISIBLE:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_boolean (value, boxes_searchbar_get_visible (self));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_TEXT:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_string (value, boxes_searchbar_get_text (self));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1567 "searchbar.c"
		default:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1573 "searchbar.c"
	}
}


static void _vala_boxes_searchbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSearchbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
	switch (property_id) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_ENABLE_KEY_HANDLER:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_enable_key_handler (self, g_value_get_boolean (value));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_VISIBLE:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_visible (self, g_value_get_boolean (value));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_TEXT:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, g_value_get_string (value));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1601 "searchbar.c"
		default:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1607 "searchbar.c"
	}
}



