/* empty-boxes.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from empty-boxes.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _BoxesEmptyBoxesPrivate BoxesEmptyBoxesPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesEmptyBoxes {
	BoxesUI parent_instance;
	BoxesEmptyBoxesPrivate * priv;
};

struct _BoxesEmptyBoxesClass {
	BoxesUIClass parent_class;
};

struct _BoxesEmptyBoxesPrivate {
	GtkClutterActor* gtk_actor;
	GtkGrid* grid;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef void (*BoxesAppCallReadyFunc) (void* user_data);
typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_empty_boxes_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
#define BOXES_EMPTY_BOXES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesPrivate))
enum  {
	BOXES_EMPTY_BOXES_DUMMY_PROPERTY,
	BOXES_EMPTY_BOXES_ACTOR
};
BoxesEmptyBoxes* boxes_empty_boxes_new (void);
BoxesEmptyBoxes* boxes_empty_boxes_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void boxes_empty_boxes_update_visibility (BoxesEmptyBoxes* self);
static void _boxes_empty_boxes_update_visibility_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_empty_boxes_update_visibility_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void boxes_empty_boxes_real_ui_state_changed (BoxesUI* base);
void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify);
static void __lambda201_ (BoxesEmptyBoxes* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
static void ___lambda201__boxes_app_call_ready_func (gpointer self);
static void boxes_empty_boxes_finalize (GObject* obj);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void _vala_boxes_empty_boxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static void _boxes_empty_boxes_update_visibility_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility (self);
#line 322 "empty-boxes.c"
}


static void _boxes_empty_boxes_update_visibility_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility (self);
#line 329 "empty-boxes.c"
}


BoxesEmptyBoxes* boxes_empty_boxes_construct (GType object_type) {
	BoxesEmptyBoxes * self = NULL;
	GtkGrid* _tmp0_;
	GtkGrid* _tmp1_;
	GtkGrid* _tmp2_;
	GtkGrid* _tmp3_;
	GtkGrid* _tmp4_;
	GtkGrid* _tmp5_;
	GtkGrid* _tmp6_;
	GtkGrid* _tmp7_;
	GtkGrid* _tmp8_;
	GtkStyleContext* _tmp9_ = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp10_;
	GtkStyleContext* _tmp11_ = NULL;
	GtkGrid* _tmp12_;
	GtkGrid* labels_grid = NULL;
	GtkGrid* _tmp13_;
	GtkGrid* _tmp14_;
	GtkLabel* label = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GtkLabel* _tmp20_;
	GtkLabel* _tmp21_;
	GtkLabel* _tmp22_;
	GtkLabel* _tmp23_;
	GtkLabel* _tmp24_;
	GtkLabel* _tmp25_;
	const gchar* _tmp26_ = NULL;
	GtkLabel* _tmp27_;
	GtkLabel* _tmp28_;
	GtkStyleContext* _tmp29_ = NULL;
	GtkLabel* _tmp30_;
	GtkLabel* _tmp31_;
	GtkLabel* _tmp32_;
	GtkLabel* _tmp33_;
	GtkLabel* _tmp34_;
	GtkLabel* _tmp35_;
	GtkGrid* _tmp36_;
	GtkClutterActor* _tmp37_;
	GtkClutterActor* _tmp38_;
	GtkWidget* _tmp39_ = NULL;
	GtkStyleContext* _tmp40_ = NULL;
	GtkClutterActor* _tmp41_;
	GtkClutterActor* _tmp42_;
	GtkClutterActor* _tmp43_;
	GtkClutterActor* _tmp44_;
	GtkClutterActor* _tmp45_;
	GtkGrid* _tmp46_;
	BoxesApp* _tmp47_;
	BoxesCollection* _tmp48_;
	BoxesApp* _tmp49_;
	BoxesCollection* _tmp50_;
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) boxes_ui_construct (object_type);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp0_);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->grid);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv->grid = _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp1_ = self->priv->grid;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp1_, GTK_ORIENTATION_HORIZONTAL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp2_ = self->priv->grid;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_grid_set_column_spacing (_tmp2_, 12);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp3_ = self->priv->grid;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp3_, TRUE);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp4_ = self->priv->grid;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp4_, TRUE);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp5_ = self->priv->grid;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_CENTER);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp6_ = self->priv->grid;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_CENTER);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp7_ = self->priv->grid;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_grid_set_row_homogeneous (_tmp7_, TRUE);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp8_ = self->priv->grid;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_style_context_add_class (_tmp9_, "dim-label");
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp10_ = (GtkImage*) gtk_image_new_from_icon_name ("application-x-appliance-symbolic", GTK_ICON_SIZE_DIALOG);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp10_);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	image = _tmp10_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) image);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_style_context_add_class (_tmp11_, "boxes-empty-image");
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_image_set_pixel_size (image, 96);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp12_ = self->priv->grid;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_container_add ((GtkContainer*) _tmp12_, (GtkWidget*) image);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp13_ = (GtkGrid*) gtk_grid_new ();
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp13_);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	labels_grid = _tmp13_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) labels_grid, GTK_ORIENTATION_VERTICAL);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp14_ = self->priv->grid;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_container_add ((GtkContainer*) _tmp14_, (GtkWidget*) labels_grid);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp15_ = _ ("No boxes found");
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp16_ = g_strconcat ("<b><span size=\"large\">", _tmp15_, NULL);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp17_ = _tmp16_;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp18_ = g_strconcat (_tmp17_, "</span></b>", NULL);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp19_ = _tmp18_;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp20_ = (GtkLabel*) gtk_label_new (_tmp19_);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp20_);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp21_ = _tmp20_;
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_free0 (_tmp19_);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_free0 (_tmp17_);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	label = _tmp21_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp22_ = label;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_label_set_use_markup (_tmp22_, TRUE);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp23_ = label;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp23_, GTK_ALIGN_START);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp24_ = label;
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp24_, TRUE);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp25_ = label;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_container_add ((GtkContainer*) labels_grid, (GtkWidget*) _tmp25_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp26_ = _ ("Create one using the button on the top left.");
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp27_ = (GtkLabel*) gtk_label_new (_tmp26_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp27_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (label);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	label = _tmp27_;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp28_ = label;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) _tmp28_);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_style_context_add_class (_tmp29_, "boxes-empty-details-label");
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp30_ = label;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp30_, GTK_ALIGN_START);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp31_ = label;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp31_, TRUE);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp32_ = label;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_set ((GtkMisc*) _tmp32_, "xalign", (gfloat) 0, NULL);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp33_ = label;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_label_set_max_width_chars (_tmp33_, 24);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp34_ = label;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_set (_tmp34_, "wrap", TRUE, NULL);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp35_ = label;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_container_add ((GtkContainer*) labels_grid, (GtkWidget*) _tmp35_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp36_ = self->priv->grid;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp37_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp36_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_ref_sink (_tmp37_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv->gtk_actor = _tmp37_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp38_ = self->priv->gtk_actor;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp39_ = gtk_clutter_actor_get_widget (_tmp38_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp40_ = gtk_widget_get_style_context (_tmp39_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_style_context_add_class (_tmp40_, "boxes-bg");
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp41_ = self->priv->gtk_actor;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp41_, (guint) 255);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp42_ = self->priv->gtk_actor;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp42_, CLUTTER_ACTOR_ALIGN_FILL);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp43_ = self->priv->gtk_actor;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp43_, CLUTTER_ACTOR_ALIGN_FILL);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp44_ = self->priv->gtk_actor;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp44_, TRUE);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp45_ = self->priv->gtk_actor;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp45_, TRUE);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp46_ = self->priv->grid;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp46_);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp47_ = boxes_app_app;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp48_ = _tmp47_->collection;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_signal_connect_object (_tmp48_, "item-added", (GCallback) _boxes_empty_boxes_update_visibility_boxes_collection_item_added, self, 0);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp49_ = boxes_app_app;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp50_ = _tmp49_->collection;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_signal_connect_object (_tmp50_, "item-removed", (GCallback) _boxes_empty_boxes_update_visibility_boxes_collection_item_removed, self, 0);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (label);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (labels_grid);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (image);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return self;
#line 601 "empty-boxes.c"
}


BoxesEmptyBoxes* boxes_empty_boxes_new (void) {
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return boxes_empty_boxes_construct (BOXES_TYPE_EMPTY_BOXES);
#line 608 "empty-boxes.c"
}


static void boxes_empty_boxes_real_ui_state_changed (BoxesUI* base) {
	BoxesEmptyBoxes * self;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_update_visibility (self);
#line 618 "empty-boxes.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 633 "empty-boxes.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 645 "empty-boxes.c"
}


static void __lambda201_ (BoxesEmptyBoxes* self) {
	gboolean _tmp0_ = FALSE;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	gboolean visible = FALSE;
	gboolean _tmp8_;
	gboolean _tmp9_;
	GtkClutterActor* _tmp10_;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp2_ = _tmp1_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 665 "empty-boxes.c"
		BoxesApp* _tmp3_;
		BoxesCollection* _tmp4_;
		GPtrArray* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp3_ = boxes_app_app;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp4_ = _tmp3_->collection;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp5_ = _tmp4_->items;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp6_ = g_ptr_array_get_length (_tmp5_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp7_ = _tmp6_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp0_ = _tmp7_ == 0;
#line 683 "empty-boxes.c"
	} else {
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp0_ = FALSE;
#line 687 "empty-boxes.c"
	}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp8_ = _tmp0_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	visible = _tmp8_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp9_ = visible;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp10_ = self->priv->gtk_actor;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_get ((ClutterActor*) _tmp10_, "visible", &_tmp11_, NULL);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp12_ = _tmp11_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	if (_tmp9_ != _tmp12_) {
#line 703 "empty-boxes.c"
		gint _tmp13_ = 0;
		gboolean _tmp14_;
		GtkClutterActor* _tmp15_;
		gint _tmp16_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp14_ = visible;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		if (_tmp14_) {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
			_tmp13_ = 255;
#line 714 "empty-boxes.c"
		} else {
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
			_tmp13_ = 0;
#line 718 "empty-boxes.c"
		}
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp15_ = self->priv->gtk_actor;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		_tmp16_ = _tmp13_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		boxes_fade_actor ((ClutterActor*) _tmp15_, (guint) _tmp16_);
#line 726 "empty-boxes.c"
	}
}


static void ___lambda201__boxes_app_call_ready_func (gpointer self) {
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	__lambda201_ (self);
#line 734 "empty-boxes.c"
}


static void boxes_empty_boxes_update_visibility (BoxesEmptyBoxes* self) {
	BoxesApp* _tmp0_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_return_if_fail (self != NULL);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = boxes_app_app;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_app_call_when_ready (_tmp0_, ___lambda201__boxes_app_call_ready_func, g_object_ref (self), g_object_unref);
#line 746 "empty-boxes.c"
}


static ClutterActor* boxes_empty_boxes_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesEmptyBoxes* self;
	GtkClutterActor* _tmp0_;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = (BoxesEmptyBoxes*) base;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	result = (ClutterActor*) _tmp0_;
#line 4 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	return result;
#line 762 "empty-boxes.c"
}


static void boxes_empty_boxes_class_init (BoxesEmptyBoxesClass * klass) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	boxes_empty_boxes_parent_class = g_type_class_peek_parent (klass);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_type_class_add_private (klass, sizeof (BoxesEmptyBoxesPrivate));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_empty_boxes_real_ui_state_changed;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_empty_boxes_real_get_actor;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_empty_boxes_get_property;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_empty_boxes_finalize;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EMPTY_BOXES_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 781 "empty-boxes.c"
}


static void boxes_empty_boxes_instance_init (BoxesEmptyBoxes * self) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self->priv = BOXES_EMPTY_BOXES_GET_PRIVATE (self);
#line 788 "empty-boxes.c"
}


static void boxes_empty_boxes_finalize (GObject* obj) {
	BoxesEmptyBoxes * self;
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	_g_object_unref0 (self->priv->grid);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	G_OBJECT_CLASS (boxes_empty_boxes_parent_class)->finalize (obj);
#line 802 "empty-boxes.c"
}


GType boxes_empty_boxes_get_type (void) {
	static volatile gsize boxes_empty_boxes_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_empty_boxes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesEmptyBoxesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_empty_boxes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesEmptyBoxes), 0, (GInstanceInitFunc) boxes_empty_boxes_instance_init, NULL };
		GType boxes_empty_boxes_type_id;
		boxes_empty_boxes_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesEmptyBoxes", &g_define_type_info, 0);
		g_once_init_leave (&boxes_empty_boxes_type_id__volatile, boxes_empty_boxes_type_id);
	}
	return boxes_empty_boxes_type_id__volatile;
}


static void _vala_boxes_empty_boxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesEmptyBoxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
	switch (property_id) {
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		case BOXES_EMPTY_BOXES_ACTOR:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 829 "empty-boxes.c"
		default:
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/extra-data/checkout/gnome/gnome-boxes/src/empty-boxes.vala"
		break;
#line 835 "empty-boxes.c"
	}
}



