/* clutter-widget.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from clutter-widget.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;
typedef struct _BoxesClutterWidgetPrivate BoxesClutterWidgetPrivate;

struct _BoxesClutterWidget {
	GtkClutterEmbed parent_instance;
	BoxesClutterWidgetPrivate * priv;
};

struct _BoxesClutterWidgetClass {
	GtkClutterEmbedClass parent_class;
};


static gpointer boxes_clutter_widget_parent_class = NULL;

GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_CLUTTER_WIDGET_DUMMY_PROPERTY
};
BoxesClutterWidget* boxes_clutter_widget_new (void);
BoxesClutterWidget* boxes_clutter_widget_construct (GType object_type);
static gboolean boxes_clutter_widget_real_key_press_event (GtkWidget* base, GdkEventKey* event);
static gboolean boxes_clutter_widget_real_key_release_event (GtkWidget* base, GdkEventKey* event);


BoxesClutterWidget* boxes_clutter_widget_construct (GType object_type) {
	BoxesClutterWidget * self = NULL;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	self = (BoxesClutterWidget*) g_object_new (object_type, NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	gtk_widget_set_can_focus ((GtkWidget*) self, FALSE);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	g_object_set ((GObject*) self, "use-layout-size", TRUE, NULL);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	return self;
#line 57 "clutter-widget.c"
}


BoxesClutterWidget* boxes_clutter_widget_new (void) {
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	return boxes_clutter_widget_construct (BOXES_TYPE_CLUTTER_WIDGET);
#line 64 "clutter-widget.c"
}


static gboolean boxes_clutter_widget_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	BoxesClutterWidget * self;
	gboolean result = FALSE;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	self = (BoxesClutterWidget*) base;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	result = FALSE;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	return result;
#line 79 "clutter-widget.c"
}


static gboolean boxes_clutter_widget_real_key_release_event (GtkWidget* base, GdkEventKey* event) {
	BoxesClutterWidget * self;
	gboolean result = FALSE;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	self = (BoxesClutterWidget*) base;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	result = FALSE;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	return result;
#line 94 "clutter-widget.c"
}


static void boxes_clutter_widget_class_init (BoxesClutterWidgetClass * klass) {
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	boxes_clutter_widget_parent_class = g_type_class_peek_parent (klass);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	GTK_WIDGET_CLASS (klass)->key_press_event = boxes_clutter_widget_real_key_press_event;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/clutter-widget.vala"
	GTK_WIDGET_CLASS (klass)->key_release_event = boxes_clutter_widget_real_key_release_event;
#line 105 "clutter-widget.c"
}


static void boxes_clutter_widget_instance_init (BoxesClutterWidget * self) {
}


GType boxes_clutter_widget_get_type (void) {
	static volatile gsize boxes_clutter_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_clutter_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesClutterWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_clutter_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesClutterWidget), 0, (GInstanceInitFunc) boxes_clutter_widget_instance_init, NULL };
		GType boxes_clutter_widget_type_id;
		boxes_clutter_widget_type_id = g_type_register_static (gtk_clutter_embed_get_type (), "BoxesClutterWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_clutter_widget_type_id__volatile, boxes_clutter_widget_type_id);
	}
	return boxes_clutter_widget_type_id__volatile;
}



