/* machine.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <cairo.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gstdio.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesMachineSaveData BoxesMachineSaveData;
typedef struct _BoxesMachineSaveRealData BoxesMachineSaveRealData;
typedef struct _BoxesMachineTakeScreenshotData BoxesMachineTakeScreenshotData;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;
typedef struct _BoxesMachineUpdateScreenshotData BoxesMachineUpdateScreenshotData;
#define _cairo_pattern_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_pattern_destroy (var), NULL)))
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
typedef struct _BoxesMachineActorPrivate BoxesMachineActorPrivate;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;
typedef struct _Block39Data Block39Data;
typedef struct _Block40Data Block40Data;
typedef struct _Block41Data Block41Data;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesMachinePrivate {
	BoxesMachineActor* machine_actor;
	GdkPixbuf* _pixbuf;
	gchar* _info;
	gchar* _status;
	gboolean _can_save;
	gulong show_id;
	gulong hide_id;
	guint show_timeout_id;
	gulong disconnected_id;
	gulong need_password_id;
	gulong need_username_id;
	gulong ui_state_id;
	gulong got_error_id;
	guint screenshot_id;
	gboolean updating_screenshot;
	GCancellable* _connecting_cancellable;
	GdkPixbuf* orig_pixbuf;
	BoxesMachineMachineState _state;
	BoxesDisplay* _display;
	gint screenshot_counter;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesMachineSaveData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* info;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	GError * _inner_error_;
};

struct _BoxesMachineSaveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
};

struct _BoxesMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	GdkPixbuf* result;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	GdkPixbuf* _tmp2_;
	BoxesDisplay* _tmp3_;
	BoxesDisplay* _tmp4_;
	GdkPixbuf* _tmp5_;
	GError * _inner_error_;
};

struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesMachineUpdateScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	gboolean force_save;
	gboolean first_check;
	gboolean _tmp0_;
	GdkPixbuf* large_screenshot;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp2_;
	gboolean _tmp3_;
	GdkPixbuf* _tmp4_;
	GdkPixbuf* _tmp5_;
	GError* _error_;
	GdkPixbuf* _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp8_;
	gint _tmp9_;
	GdkPixbuf* _tmp10_;
	gboolean _tmp11_;
	GError * _inner_error_;
};

struct _BoxesMachineActor {
	BoxesUI parent_instance;
	BoxesMachineActorPrivate * priv;
	ClutterActor* _actor;
};

struct _BoxesMachineActorClass {
	BoxesUIClass parent_class;
};

struct _BoxesMachineActorPrivate {
	GtkClutterTexture* screenshot;
	GtkClutterActor* gtk_vbox;
	ClutterActor* thumbnail;
	GtkClutterTexture* thumbnail_screenshot;
	GtkLabel* label;
	GtkBox* vbox;
	GtkEntry* password_entry;
	BoxesMachine* machine;
	gulong track_screenshot_id;
};

struct _BoxesProperties {
	BoxesUI parent_instance;
	BoxesPropertiesPrivate * priv;
	GtkWidget* screenshot_placeholder;
};

struct _BoxesPropertiesClass {
	BoxesUIClass parent_class;
};

struct _Block39Data {
	int _ref_count_;
	BoxesMachineActor * self;
	BoxesMachine* machine;
};

typedef void (*BoxesActorFunc) (ClutterActor* actor, void* user_data);
struct _Block40Data {
	int _ref_count_;
	BoxesMachineActor * self;
	BoxesActorFunc update_screenshot_alloc;
	gpointer update_screenshot_alloc_target;
	GDestroyNotify update_screenshot_alloc_target_destroy_notify;
};

struct _Block41Data {
	int _ref_count_;
	BoxesMachineActor * self;
	gulong completed_id;
};


static gpointer boxes_machine_parent_class = NULL;
static cairo_surface_t* boxes_machine_grid_surface;
static cairo_surface_t* boxes_machine_grid_surface = NULL;
static GdkPixbuf* boxes_machine_default_fallback;
static GdkPixbuf* boxes_machine_default_fallback = NULL;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface* boxes_machine_boxes_iproperties_provider_parent_iface = NULL;
static gpointer boxes_machine_actor_parent_class = NULL;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE, BoxesMachinePrivate))
enum  {
	BOXES_MACHINE_DUMMY_PROPERTY,
	BOXES_MACHINE_ACTOR,
	BOXES_MACHINE_PIXBUF,
	BOXES_MACHINE_INFO,
	BOXES_MACHINE_STATUS,
	BOXES_MACHINE_CAN_SAVE,
	BOXES_MACHINE_CONNECTING_CANCELLABLE,
	BOXES_MACHINE_STATE,
	BOXES_MACHINE_DISPLAY
};
#define BOXES_MACHINE_SCREENSHOT_WIDTH 180
#define BOXES_MACHINE_SCREENSHOT_HEIGHT 134
void boxes_machine_show_display (BoxesMachine* self);
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static gboolean ___lambda12_ (BoxesMachine* self);
static gboolean ____lambda12__gsource_func (gpointer self);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
void boxes_machine_actor_update_thumbnail (BoxesMachineActor* self, GtkWidget* display_widget, gboolean zoom);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
BoxesCollectionItem* boxes_collection_item_construct (GType object_type);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
void boxes_machine_set_connecting_cancellable (BoxesMachine* self, GCancellable* value);
static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force);
void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value);
BoxesMachineActor* boxes_machine_actor_new (BoxesMachine* machine);
BoxesMachineActor* boxes_machine_actor_construct (GType object_type, BoxesMachine* machine);
static void __lambda168_ (BoxesMachine* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void ___lambda168__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
static gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self, GError** error);
static void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save);
static void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_);
static gboolean ___lambda96_ (BoxesMachine* self);
static gboolean ____lambda96__gsource_func (gpointer self);
static void boxes_machine_save_data_free (gpointer _data);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_machine_save_co (BoxesMachineSaveData* _data_);
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);
void boxes_machine_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_machine_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_machine_real_save_real_data_free (gpointer _data);
static void boxes_machine_real_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_machine_real_save_real_co (BoxesMachineSaveRealData* _data_);
static void boxes_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_machine_is_connected (BoxesMachine* self);
void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
void boxes_machine_disconnect_display (BoxesMachine* self);
static void boxes_machine_real_disconnect_display (BoxesMachine* self);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
gboolean boxes_display_should_keep_alive (BoxesDisplay* self);
void boxes_display_disconnect_it (BoxesDisplay* self);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid);
gchar* boxes_uuid_generate (void);
gboolean boxes_machine_is_running (BoxesMachine* self);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void boxes_machine_save_pixbuf_as_screenshot (BoxesMachine* self, GdkPixbuf* pixbuf);
static gint boxes_machine_pixbuf_energy (BoxesMachine* self, GdkPixbuf* pixbuf);
static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height);
void boxes_machine_actor_set_screenshot (BoxesMachineActor* self, GdkPixbuf* pixbuf);
static GdkPixbuf* boxes_machine_draw_stopped_vm (gint width, gint height);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
static void boxes_machine_update_screenshot_data_free (gpointer _data);
static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_);
static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_real_ui_state_changed (BoxesUI* base);
static gint boxes_machine_real_compare (BoxesCollectionItem* base, BoxesCollectionItem* other);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
const gchar* boxes_machine_get_status (BoxesMachine* self);
void boxes_machine_set_status (BoxesMachine* self, const gchar* value);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
void boxes_machine_set_can_save (BoxesMachine* self, gboolean value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
const gchar* boxes_machine_machine_state_to_string (BoxesMachineMachineState self);
static void _boxes_machine_display___lambda11_ (BoxesMachine* self, gint id);
static void __boxes_machine_display___lambda11__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda160_ (BoxesMachine* self, gint id);
static void __boxes_machine_display___lambda160__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda161_ (BoxesMachine* self, const gchar* message);
static void __boxes_machine_display___lambda161__boxes_display_got_error (BoxesDisplay* _sender, const gchar* message, gpointer self);
static void _boxes_machine_display___lambda162_ (BoxesMachine* self);
static void __boxes_machine_display___lambda162__boxes_display_disconnected (BoxesDisplay* _sender, gpointer self);
static void _boxes_machine_display___lambda163_ (BoxesMachine* self);
void boxes_machine_actor_set_password_needed (BoxesMachineActor* self, gboolean needed);
gboolean boxes_display_get_need_password (BoxesDisplay* self);
static void __boxes_machine_display___lambda163__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_machine_display___lambda164_ (BoxesMachine* self);
void boxes_machine_actor_set_username_needed (BoxesMachineActor* self, gboolean needed);
gboolean boxes_display_get_need_username (BoxesDisplay* self);
static void __boxes_machine_display___lambda164__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gchar* boxes_machine_actor_get_password (BoxesMachineActor* self);
void boxes_display_set_password (BoxesDisplay* self, const gchar* value);
static void boxes_machine_finalize (GObject* obj);
static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_MACHINE_ACTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorPrivate))
enum  {
	BOXES_MACHINE_ACTOR_DUMMY_PROPERTY,
	BOXES_MACHINE_ACTOR_ACTOR
};
static Block39Data* block39_data_ref (Block39Data* _data39_);
static void block39_data_unref (void * _userdata_);
BoxesUI* boxes_ui_construct (GType object_type);
static gboolean __lambda165_ (Block39Data* _data39_, GdkEventKey* event);
static gboolean ___lambda165__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static GtkWidget* boxes_machine_actor_steal_display_widget_from_thumbnail (BoxesMachineActor* self);
void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
void boxes_actor_remove (ClutterActor* actor);
static Block40Data* block40_data_ref (Block40Data* _data40_);
static void block40_data_unref (void * _userdata_);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void ____lambda155_ (BoxesMachineActor* self);
static void _____lambda155__clutter_click_action_clicked (ClutterClickAction* _sender, ClutterActor* actor, gpointer self);
static void _____lambda156_ (BoxesMachineActor* self);
void boxes_app_connect_to (BoxesApp* self, BoxesMachine* machine, gfloat x, gfloat y, BoxesMachineConnectFlags flags);
static void ______lambda156__clutter_click_action_clicked (ClutterClickAction* _sender, ClutterActor* actor, gpointer self);
static void ___lambda157_ (BoxesMachineActor* self, ClutterActor* thumbnail);
static void ____lambda157__boxes_actor_func (ClutterActor* actor, gpointer self);
static void ___lambda158_ (Block40Data* _data40_);
static gboolean __lambda159_ (Block40Data* _data40_);
static gboolean ___lambda159__gsource_func (gpointer self);
static void ____lambda158__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static void boxes_machine_actor_real_ui_state_changed (BoxesUI* base);
void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height);
static void _____lambda166_ (BoxesMachineActor* self);
static void ______lambda166__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self);
void boxes_display_page_show (BoxesDisplayPage* self);
static Block41Data* block41_data_ref (Block41Data* _data41_);
static void block41_data_unref (void * _userdata_);
void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height);
static void ____lambda167_ (Block41Data* _data41_);
static void _____lambda167__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self);
static void boxes_machine_actor_finalize (GObject* obj);
static void _vala_boxes_machine_actor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


GType boxes_machine_machine_state_get_type (void) {
	static volatile gsize boxes_machine_machine_state_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_machine_state_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_MACHINE_MACHINE_STATE_UNKNOWN, "BOXES_MACHINE_MACHINE_STATE_UNKNOWN", "unknown"}, {BOXES_MACHINE_MACHINE_STATE_STOPPED, "BOXES_MACHINE_MACHINE_STATE_STOPPED", "stopped"}, {BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED, "BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED", "force-stopped"}, {BOXES_MACHINE_MACHINE_STATE_RUNNING, "BOXES_MACHINE_MACHINE_STATE_RUNNING", "running"}, {BOXES_MACHINE_MACHINE_STATE_PAUSED, "BOXES_MACHINE_MACHINE_STATE_PAUSED", "paused"}, {BOXES_MACHINE_MACHINE_STATE_SAVED, "BOXES_MACHINE_MACHINE_STATE_SAVED", "saved"}, {BOXES_MACHINE_MACHINE_STATE_SLEEPING, "BOXES_MACHINE_MACHINE_STATE_SLEEPING", "sleeping"}, {0, NULL, NULL}};
		GType boxes_machine_machine_state_type_id;
		boxes_machine_machine_state_type_id = g_enum_register_static ("BoxesMachineMachineState", values);
		g_once_init_leave (&boxes_machine_machine_state_type_id__volatile, boxes_machine_machine_state_type_id);
	}
	return boxes_machine_machine_state_type_id__volatile;
}


GType boxes_machine_connect_flags_get_type (void) {
	static volatile gsize boxes_machine_connect_flags_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_connect_flags_type_id__volatile)) {
		static const GFlagsValue values[] = {{BOXES_MACHINE_CONNECT_FLAGS_NONE, "BOXES_MACHINE_CONNECT_FLAGS_NONE", "none"}, {BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE, "BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE", "ignore-saved-state"}, {0, NULL, NULL}};
		GType boxes_machine_connect_flags_type_id;
		boxes_machine_connect_flags_type_id = g_flags_register_static ("BoxesMachineConnectFlags", values);
		g_once_init_leave (&boxes_machine_connect_flags_type_id__volatile, boxes_machine_connect_flags_type_id);
	}
	return boxes_machine_connect_flags_type_id__volatile;
}


static gboolean ___lambda12_ (BoxesMachine* self) {
	gboolean result = FALSE;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->show_timeout_id = (guint) 0;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_show_display (self);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 799 "machine.c"
}


static gboolean ____lambda12__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda12_ (self);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 808 "machine.c"
}


void boxes_machine_show_display (BoxesMachine* self) {
	GtkWidget* widget = NULL;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	GtkWidget* _tmp2_ = NULL;
	BoxesApp* _tmp3_;
	BoxesUIState _tmp4_;
	BoxesUIState _tmp5_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_display_get_display (_tmp1_, 0);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (widget);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	widget = _tmp2_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_app_app;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp3_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_tmp5_) {
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_CREDS:
#line 842 "machine.c"
		{
			BoxesApp* _tmp6_;
			BoxesApp* _tmp7_;
			guint _tmp8_;
			guint _tmp9_ = 0U;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp6_ = boxes_app_app;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_ui_set_ui_state ((BoxesUI*) _tmp6_, BOXES_UI_STATE_DISPLAY);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp7_ = boxes_app_app;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = _tmp7_->duration;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp8_, ____lambda12__gsource_func, g_object_ref (self), g_object_unref);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			self->priv->show_timeout_id = _tmp9_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 862 "machine.c"
		}
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 866 "machine.c"
		{
			BoxesApp* _tmp10_;
			BoxesDisplayPage* _tmp11_;
			BoxesDisplay* _tmp12_;
			BoxesDisplay* _tmp13_;
			GtkWidget* _tmp14_;
			GtkWidget* _tmp15_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = boxes_app_app;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = _tmp10_->display_page;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = boxes_machine_get_display (self);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = _tmp12_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp14_ = widget;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_page_show_display (_tmp11_, _tmp13_, _tmp14_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp15_ = widget;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_widget_grab_focus (_tmp15_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 892 "machine.c"
		}
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 896 "machine.c"
		{
			BoxesMachineActor* _tmp16_;
			GtkWidget* _tmp17_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = self->priv->machine_actor;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp17_ = widget;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_actor_update_thumbnail (_tmp16_, _tmp17_, FALSE);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 908 "machine.c"
		}
		default:
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 913 "machine.c"
	}
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (widget);
#line 917 "machine.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 924 "machine.c"
}


static void __lambda168_ (BoxesMachine* self) {
	BoxesApp* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_ == BOXES_UI_STATE_DISPLAY) {
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, FALSE);
#line 942 "machine.c"
	} else {
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, TRUE);
#line 946 "machine.c"
	}
}


static void ___lambda168__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	__lambda168_ (self);
#line 954 "machine.c"
}


BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name) {
	BoxesMachine * self = NULL;
	const gchar* _tmp0_;
	BoxesCollectionSource* _tmp1_;
	BoxesCollectionSource* _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
	GdkPixbuf* _tmp5_ = NULL;
	GdkPixbuf* _tmp6_;
	BoxesMachineActor* _tmp7_;
	BoxesApp* _tmp8_;
	gulong _tmp9_ = 0UL;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) boxes_collection_item_construct (object_type);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = name;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) self, _tmp0_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = source;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->source = _tmp2_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_cancellable_new ();
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_connecting_cancellable (self, _tmp4_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp4_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_machine_draw_fallback_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT, FALSE);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp5_;
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_pixbuf (self, _tmp6_);
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp6_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = boxes_machine_actor_new (self);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine_actor);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->machine_actor = _tmp7_;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_app_app;
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = g_signal_connect_object ((GObject*) _tmp8_, "notify::ui-state", (GCallback) ___lambda168__g_object_notify, self, 0);
#line 188 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->ui_state_id = _tmp9_;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return self;
#line 1018 "machine.c"
}


void boxes_machine_load_screenshot (BoxesMachine* self) {
	GError * _inner_error_ = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 1026 "machine.c"
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GdkPixbuf* screenshot = NULL;
		gchar* _tmp2_;
		GdkPixbuf* _tmp3_;
		GdkPixbuf* _tmp4_;
		GdkPixbuf* _tmp5_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp1_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 1041 "machine.c"
			goto __catch43_g_error;
		}
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp0_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = gdk_pixbuf_new_from_file (_tmp2_, &_inner_error_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp3_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp2_);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		screenshot = _tmp4_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 1056 "machine.c"
			goto __catch43_g_error;
		}
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = screenshot;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (self, _tmp5_, FALSE);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (screenshot);
#line 1065 "machine.c"
	}
	goto __finally43;
	__catch43_g_error:
	{
		GError* _error_ = NULL;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 1077 "machine.c"
	}
	__finally43:
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1088 "machine.c"
	}
}


static gboolean ___lambda96_ (BoxesMachine* self) {
	gboolean result = FALSE;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot (self, FALSE, FALSE, NULL, NULL);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = TRUE;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1101 "machine.c"
}


static gboolean ____lambda96__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda96_ (self);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1110 "machine.c"
}


void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable) {
	gboolean _tmp0_;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = enable;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 1122 "machine.c"
		guint _tmp1_;
		gint interval = 0;
		BoxesApp* _tmp2_;
		GSettings* _tmp3_;
		gint _tmp4_ = 0;
		gint _tmp5_;
		guint _tmp6_ = 0U;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->screenshot_id;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp1_ != ((guint) 0)) {
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 1136 "machine.c"
		}
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_update_screenshot (self, FALSE, TRUE, NULL, NULL);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_app;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->settings;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = g_settings_get_int (_tmp3_, "screenshot-interval");
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		interval = _tmp4_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = interval;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp5_, ____lambda96__gsource_func, g_object_ref (self), g_object_unref);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = _tmp6_;
#line 1154 "machine.c"
	} else {
		guint _tmp7_;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->screenshot_id;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp7_ != ((guint) 0)) {
#line 1161 "machine.c"
			guint _tmp8_;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = self->priv->screenshot_id;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_source_remove (_tmp8_);
#line 1167 "machine.c"
		}
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = (guint) 0;
#line 1171 "machine.c"
	}
}


static gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self, GError** error) {
	gchar* result = NULL;
	BoxesBoxConfig* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	BoxesBoxConfig* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_;
	GError * _inner_error_ = NULL;
#line 223 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->config;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_box_config_get_uuid (_tmp0_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_ == NULL;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp3_);
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_) {
#line 1206 "machine.c"
		GError* _tmp5_;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "no uuid, cannot build screenshot filename");
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = _tmp5_;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_propagate_error (error, _inner_error_);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return NULL;
#line 1218 "machine.c"
		} else {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return NULL;
#line 1226 "machine.c"
		}
	}
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = self->config;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = boxes_box_config_get_uuid (_tmp6_);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = _tmp7_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_get_screenshot_filename (_tmp9_);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = _tmp10_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp9_);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp11_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1247 "machine.c"
}


static void boxes_machine_save_data_free (gpointer _data) {
	BoxesMachineSaveData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineSaveData, _data_);
#line 1258 "machine.c"
}


void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineSaveData* _data_;
	BoxesMachine* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineSaveData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_save);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_save_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_co (_data_);
#line 1277 "machine.c"
}


void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesMachineSaveData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1287 "machine.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1291 "machine.c"
}


static void boxes_machine_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineSaveData* _data_;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_co (_data_);
#line 1305 "machine.c"
}


static gboolean boxes_machine_save_co (BoxesMachineSaveData* _data_) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1314 "machine.c"
		goto _state_0;
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 1318 "machine.c"
		goto _state_1;
		default:
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1323 "machine.c"
	}
	_state_0:
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = boxes_machine_get_state (_data_->self);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp1_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_debug ("machine.vala:232: Not saving '%s' since its already in saved state.", _data_->_tmp3_);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1342 "machine.c"
		} else {
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1346 "machine.c"
		}
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1352 "machine.c"
	}
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = _data_->self->priv->_info;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = g_strdup (_data_->_tmp4_);
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->info = _data_->_tmp5_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp7_ = _data_->info;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp7_ != NULL) {
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = _data_->info;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp9_ = g_strconcat (_data_->_tmp8_, "\n", NULL);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = _data_->_tmp9_;
#line 1372 "machine.c"
	} else {
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = g_strdup ("");
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = _data_->_tmp10_;
#line 1380 "machine.c"
	}
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp11_ = _data_->_tmp6_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_info (_data_->self, _data_->_tmp11_);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp12_ = _data_->self->priv->_info;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp13_ = NULL;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp13_ = _ ("Saving...");
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp14_ = g_strconcat (_data_->_tmp12_, _data_->_tmp13_, NULL);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_info (_data_->self, _data_->_tmp15_);
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->_tmp15_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_state_ = 1;
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_real (_data_->self, boxes_machine_save_ready, _data_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1406 "machine.c"
	_state_1:
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_real_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_error_free (_data_->_inner_error_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->info);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1424 "machine.c"
		} else {
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1428 "machine.c"
		}
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 240 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1434 "machine.c"
	}
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp16_ = _data_->info;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_info (_data_->self, _data_->_tmp16_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->_tmp6_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->info);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1448 "machine.c"
	} else {
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1452 "machine.c"
	}
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1458 "machine.c"
}


static void boxes_machine_real_save_real_data_free (gpointer _data) {
	BoxesMachineSaveRealData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineSaveRealData, _data_);
#line 1469 "machine.c"
}


static void boxes_machine_real_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineSaveRealData* _data_;
	BoxesMachine* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineSaveRealData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_real_save_real);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_real_save_real_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_real_save_real_co (_data_);
#line 1488 "machine.c"
}


static void boxes_machine_real_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesMachineSaveRealData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1498 "machine.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1502 "machine.c"
}


static gboolean boxes_machine_real_save_real_co (BoxesMachineSaveRealData* _data_) {
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1511 "machine.c"
		goto _state_0;
		default:
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1516 "machine.c"
	}
	_state_0:
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1523 "machine.c"
	} else {
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1527 "machine.c"
	}
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1533 "machine.c"
}


void boxes_machine_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->save_real (self, _callback_, _user_data_);
#line 1540 "machine.c"
}


void boxes_machine_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->save_real_finish (self, _res_, error);
#line 1547 "machine.c"
}


static void boxes_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineTakeScreenshotData, _data_);
#line 1560 "machine.c"
}


static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineTakeScreenshotData* _data_;
	BoxesMachine* _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineTakeScreenshotData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_real_take_screenshot);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_real_take_screenshot_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_real_take_screenshot_co (_data_);
#line 1579 "machine.c"
}


static GdkPixbuf* boxes_machine_real_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesMachineTakeScreenshotData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return NULL;
#line 1590 "machine.c"
	}
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _data_->result;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->result = NULL;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1600 "machine.c"
}


static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_) {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1609 "machine.c"
		goto _state_0;
		default:
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1614 "machine.c"
	}
	_state_0:
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = boxes_machine_get_display (_data_->self);
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 255 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp1_ == NULL) {
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->result = NULL;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1629 "machine.c"
		} else {
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1633 "machine.c"
		}
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1639 "machine.c"
	}
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp3_ = boxes_machine_get_display (_data_->self);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = NULL;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = boxes_display_get_pixbuf (_data_->_tmp4_, 0, &_data_->_inner_error_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp2_ = _data_->_tmp5_;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_error_free (_data_->_inner_error_);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1661 "machine.c"
		} else {
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1665 "machine.c"
		}
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1671 "machine.c"
	}
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->result = _data_->_tmp2_;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1679 "machine.c"
	} else {
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1683 "machine.c"
	}
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1693 "machine.c"
	} else {
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1697 "machine.c"
	}
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1703 "machine.c"
}


void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->take_screenshot (self, _callback_, _user_data_);
#line 1710 "machine.c"
}


GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->take_screenshot_finish (self, _res_, error);
#line 1717 "machine.c"
}


static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_get_properties'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return NULL;
#line 1726 "machine.c"
}


GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_properties (self, page, flags);
#line 1735 "machine.c"
}


gboolean boxes_machine_is_connected (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	BoxesDisplay* _tmp3_;
	gboolean _tmp4_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_ == NULL) {
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		result = FALSE;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 1758 "machine.c"
	}
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_machine_get_display (self);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_->connected;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp4_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1770 "machine.c"
}


void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->connect_display (self, flags, _callback_, _user_data_);
#line 1777 "machine.c"
}


void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->connect_display_finish (self, _res_, error);
#line 1784 "machine.c"
}


static void boxes_machine_real_disconnect_display (BoxesMachine* self) {
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	gboolean _tmp2_ = FALSE;
	BoxesMachineMachineState _tmp3_;
	BoxesMachineMachineState _tmp4_;
	gboolean _tmp7_;
	BoxesApp* _tmp15_;
	BoxesDisplayPage* _tmp16_;
	GtkWidget* _tmp17_ = NULL;
	GtkWidget* _tmp18_;
	BoxesDisplay* _tmp19_;
	BoxesDisplay* _tmp20_;
	gboolean _tmp21_ = FALSE;
	GError * _inner_error_ = NULL;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_ == NULL) {
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1811 "machine.c"
	}
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_get_state (self);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 1819 "machine.c"
		BoxesMachineMachineState _tmp5_;
		BoxesMachineMachineState _tmp6_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_machine_get_state (self);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp6_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 1828 "machine.c"
	} else {
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = FALSE;
#line 1832 "machine.c"
	}
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = _tmp2_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp7_) {
#line 1838 "machine.c"
		{
			GdkPixbuf* pixbuf = NULL;
			BoxesDisplay* _tmp8_;
			BoxesDisplay* _tmp9_;
			GdkPixbuf* _tmp10_ = NULL;
			GdkPixbuf* _tmp11_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = boxes_machine_get_display (self);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = _tmp8_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = boxes_display_get_pixbuf (_tmp9_, 0, &_inner_error_);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			pixbuf = _tmp10_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_inner_error_ != NULL) {
#line 1855 "machine.c"
				goto __catch44_g_error;
			}
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = pixbuf;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp11_ != NULL) {
#line 1862 "machine.c"
				GdkPixbuf* _tmp12_;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp12_ = pixbuf;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				boxes_machine_set_screenshot (self, _tmp12_, TRUE);
#line 1868 "machine.c"
			}
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 1872 "machine.c"
		}
		goto __finally44;
		__catch44_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp13_;
			const gchar* _tmp14_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_error_ = _inner_error_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_inner_error_ = NULL;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = _error_;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp14_ = _tmp13_->message;
#line 282 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_warning ("machine.vala:282: %s", _tmp14_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_error_free0 (_error_);
#line 1892 "machine.c"
		}
		__finally44:
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 1903 "machine.c"
		}
	}
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = boxes_app_app;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_->display_page;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = boxes_display_page_remove_display (_tmp16_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = _tmp17_;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp18_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = boxes_machine_get_display (self);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = boxes_display_should_keep_alive (_tmp20_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp21_) {
#line 1924 "machine.c"
		BoxesDisplay* _tmp22_;
		BoxesDisplay* _tmp23_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = boxes_machine_get_display (self);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = _tmp22_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_disconnect_it (_tmp23_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (self, NULL);
#line 1935 "machine.c"
	} else {
		BoxesDisplay* _tmp24_;
		BoxesDisplay* _tmp25_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = boxes_machine_get_display (self);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = _tmp24_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_set_enable_audio (_tmp25_, FALSE);
#line 1945 "machine.c"
	}
}


void boxes_machine_disconnect_display (BoxesMachine* self) {
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->disconnect_display (self);
#line 1955 "machine.c"
}


void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid) {
	BoxesBoxConfig* _tmp0_;
	gchar* group = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	BoxesCollectionSource* _tmp8_;
	const gchar* _tmp9_;
	BoxesBoxConfig* _tmp10_;
	BoxesBoxConfig* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp21_ = FALSE;
	const gchar* _tmp22_;
	gboolean _tmp28_;
	BoxesBoxConfig* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gboolean _tmp35_;
	BoxesBoxConfig* _tmp39_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->config;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (_tmp0_ == NULL);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup ("display");
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	group = _tmp1_;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = uuid;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_ != NULL) {
#line 1997 "machine.c"
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = group;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = uuid;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = g_strconcat (" ", _tmp4_, NULL);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = g_strconcat (_tmp3_, _tmp6_, NULL);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (group);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		group = _tmp7_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp6_);
#line 2019 "machine.c"
	}
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = self->source;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = group;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_box_config_new_with_group (_tmp8_, _tmp9_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->config);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->config = _tmp10_;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = self->config;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = boxes_box_config_get_last_seen_name (_tmp11_);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = _tmp13_;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = g_strcmp0 (_tmp14_, _tmp16_) != 0;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp14_);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp17_) {
#line 2049 "machine.c"
		BoxesBoxConfig* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = self->config;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = _tmp19_;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_last_seen_name (_tmp18_, _tmp20_);
#line 2061 "machine.c"
	}
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = uuid;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp22_ != NULL) {
#line 2067 "machine.c"
		BoxesBoxConfig* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		const gchar* _tmp27_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = self->config;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = boxes_box_config_get_uuid (_tmp23_);
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = _tmp24_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = _tmp25_;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = uuid;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = g_strcmp0 (_tmp26_, _tmp27_) != 0;
#line 308 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp26_);
#line 2087 "machine.c"
	} else {
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = FALSE;
#line 2091 "machine.c"
	}
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp28_ = _tmp21_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp28_) {
#line 2097 "machine.c"
		BoxesBoxConfig* _tmp29_;
		const gchar* _tmp30_;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = self->config;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = uuid;
#line 309 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_uuid (_tmp29_, _tmp30_);
#line 2106 "machine.c"
	}
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp31_ = self->config;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp32_ = boxes_box_config_get_uuid (_tmp31_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp33_ = _tmp32_;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp34_ = _tmp33_;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp35_ = _tmp34_ == NULL;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp34_);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp35_) {
#line 2122 "machine.c"
		BoxesBoxConfig* _tmp36_;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = self->config;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp37_ = boxes_uuid_generate ();
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp38_ = _tmp37_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_uuid (_tmp36_, _tmp38_);
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp38_);
#line 2136 "machine.c"
	}
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp39_ = self->config;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_iconfig_save ((BoxesIConfig*) _tmp39_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (group);
#line 2144 "machine.c"
}


gboolean boxes_machine_is_running (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_state (self);
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2162 "machine.c"
}


gboolean boxes_machine_is_on (BoxesMachine* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	BoxesMachineMachineState _tmp2_;
	BoxesMachineMachineState _tmp3_;
	gboolean _tmp6_;
	gboolean _tmp9_;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_machine_get_state (self);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp3_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = TRUE;
#line 2184 "machine.c"
	} else {
		BoxesMachineMachineState _tmp4_;
		BoxesMachineMachineState _tmp5_;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_machine_get_state (self);
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp5_ == BOXES_MACHINE_MACHINE_STATE_PAUSED;
#line 2194 "machine.c"
	}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp1_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = TRUE;
#line 2202 "machine.c"
	} else {
		BoxesMachineMachineState _tmp7_;
		BoxesMachineMachineState _tmp8_;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_machine_get_state (self);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp8_ == BOXES_MACHINE_MACHINE_STATE_SLEEPING;
#line 2212 "machine.c"
	}
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp0_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp9_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2220 "machine.c"
}


static void boxes_machine_save_pixbuf_as_screenshot (BoxesMachine* self, GdkPixbuf* pixbuf) {
	GError * _inner_error_ = NULL;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 2228 "machine.c"
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_;
		gchar* _tmp3_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp1_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 2240 "machine.c"
			goto __catch45_g_error;
		}
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = pixbuf;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp0_;
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_pixbuf_save (_tmp2_, _tmp3_, "png", &_inner_error_, NULL);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp3_);
#line 329 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 2253 "machine.c"
			goto __catch45_g_error;
		}
	}
	goto __finally45;
	__catch45_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _error_;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_->message;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:331: %s", _tmp5_);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 2275 "machine.c"
	}
	__finally45:
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 2286 "machine.c"
	}
}


static gint boxes_machine_pixbuf_energy (BoxesMachine* self, GdkPixbuf* pixbuf) {
	gint result = 0;
	guint8* pixels = NULL;
	GdkPixbuf* _tmp0_;
	guint8* _tmp1_ = NULL;
	gint pixels_length1;
	gint _pixels_size_;
	gint w = 0;
	GdkPixbuf* _tmp2_;
	gint _tmp3_ = 0;
	gint h = 0;
	GdkPixbuf* _tmp4_;
	gint _tmp5_ = 0;
	gint rowstride = 0;
	GdkPixbuf* _tmp6_;
	gint _tmp7_ = 0;
	gint n_channels = 0;
	GdkPixbuf* _tmp8_;
	gint _tmp9_ = 0;
	gint energy = 0;
	gint row_start = 0;
	gint _tmp42_;
	gint _tmp43_;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (pixbuf != NULL, 0);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = pixbuf;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = gdk_pixbuf_get_pixels (_tmp0_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	pixels = _tmp1_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	pixels_length1 = -1;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_pixels_size_ = pixels_length1;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = pixbuf;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = gdk_pixbuf_get_width (_tmp2_);
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	w = _tmp3_;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = pixbuf;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = gdk_pixbuf_get_height (_tmp4_);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	h = _tmp5_;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = pixbuf;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = gdk_pixbuf_get_rowstride (_tmp6_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	rowstride = _tmp7_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = pixbuf;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = gdk_pixbuf_get_n_channels (_tmp8_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	n_channels = _tmp9_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	energy = 0;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	row_start = 0;
#line 2356 "machine.c"
	{
		gint y = 0;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		y = 0;
#line 2361 "machine.c"
		{
			gboolean _tmp10_ = FALSE;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = TRUE;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			while (TRUE) {
#line 2368 "machine.c"
				gboolean _tmp11_;
				gint _tmp13_;
				gint _tmp14_;
				gint row_energy = 0;
				gint i = 0;
				gint _tmp15_;
				gint _tmp37_;
				gint _tmp38_;
				gint _tmp39_;
				gint _tmp40_;
				gint _tmp41_;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp11_ = _tmp10_;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				if (!_tmp11_) {
#line 2384 "machine.c"
					gint _tmp12_;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp12_ = y;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					y = _tmp12_ + 1;
#line 2390 "machine.c"
				}
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp10_ = FALSE;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp13_ = y;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp14_ = h;
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				if (!(_tmp13_ < _tmp14_)) {
#line 346 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					break;
#line 2402 "machine.c"
				}
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				row_energy = 0;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp15_ = row_start;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				i = _tmp15_;
#line 2410 "machine.c"
				{
					gint x = 0;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					x = 0;
#line 2415 "machine.c"
					{
						gboolean _tmp16_ = FALSE;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
						_tmp16_ = TRUE;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
						while (TRUE) {
#line 2422 "machine.c"
							gboolean _tmp17_;
							gint _tmp19_;
							gint _tmp20_;
							gint max = 0;
							guint8* _tmp21_;
							gint _tmp21__length1;
							gint _tmp22_;
							guint8 _tmp23_;
							guint8* _tmp24_;
							gint _tmp24__length1;
							gint _tmp25_;
							guint8 _tmp26_;
							gint _tmp27_ = 0;
							guint8* _tmp28_;
							gint _tmp28__length1;
							gint _tmp29_;
							guint8 _tmp30_;
							gint _tmp31_ = 0;
							gint _tmp32_;
							gint _tmp33_;
							gint _tmp34_;
							gint _tmp35_;
							gint _tmp36_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp17_ = _tmp16_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							if (!_tmp17_) {
#line 2450 "machine.c"
								gint _tmp18_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
								_tmp18_ = x;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
								x = _tmp18_ + 1;
#line 2456 "machine.c"
							}
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp16_ = FALSE;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp19_ = x;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp20_ = w;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							if (!(_tmp19_ < _tmp20_)) {
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
								break;
#line 2468 "machine.c"
							}
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp21_ = pixels;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp21__length1 = pixels_length1;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp22_ = i;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp23_ = _tmp21_[_tmp22_ + 0];
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp24_ = pixels;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp24__length1 = pixels_length1;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp25_ = i;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp26_ = _tmp24_[_tmp25_ + 1];
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp27_ = MAX ((gint) _tmp23_, (gint) _tmp26_);
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp28_ = pixels;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp28__length1 = pixels_length1;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp29_ = i;
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp30_ = _tmp28_[_tmp29_ + 2];
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp31_ = MAX (_tmp27_, (gint) _tmp30_);
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							max = _tmp31_;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp32_ = row_energy;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp33_ = max;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp34_ = max;
#line 351 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							row_energy = _tmp32_ + (_tmp33_ * _tmp34_);
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp35_ = i;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp36_ = n_channels;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
							i = _tmp35_ + _tmp36_;
#line 2514 "machine.c"
						}
					}
				}
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp37_ = energy;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp38_ = row_energy;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp39_ = w;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				energy = _tmp37_ + (_tmp38_ / _tmp39_);
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp40_ = row_start;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp41_ = rowstride;
#line 355 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				row_start = _tmp40_ + _tmp41_;
#line 2532 "machine.c"
			}
		}
	}
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp42_ = energy;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp43_ = h;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp42_ / _tmp43_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2544 "machine.c"
}


static void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save) {
	GdkPixbuf* _tmp0_;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = large_screenshot;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 2556 "machine.c"
		gint pw = 0;
		GdkPixbuf* _tmp1_;
		gint _tmp2_ = 0;
		gint ph = 0;
		GdkPixbuf* _tmp3_;
		gint _tmp4_ = 0;
		gdouble s = 0.0;
		gint _tmp5_;
		gint _tmp6_;
		gdouble _tmp7_ = 0.0;
		gint w = 0;
		gint _tmp8_;
		gdouble _tmp9_;
		gint h = 0;
		gint _tmp10_;
		gdouble _tmp11_;
		GdkPixbuf* small_screenshot = NULL;
		GdkPixbuf* _tmp12_;
		gboolean _tmp13_;
		gboolean _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GdkPixbuf* _tmp17_;
		GdkPixbuf* _tmp18_;
		GdkPixbuf* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		gdouble _tmp22_;
		gdouble _tmp23_;
		GdkPixbuf* _tmp24_;
		gint _tmp25_ = 0;
		GdkPixbuf* _tmp26_;
		GdkPixbuf* _tmp27_;
		GdkPixbuf* _tmp28_;
		GdkPixbuf* _tmp29_ = NULL;
		GdkPixbuf* _tmp30_;
		BoxesMachineActor* _tmp31_;
		GdkPixbuf* _tmp32_;
		gboolean _tmp33_;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = large_screenshot;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = gdk_pixbuf_get_width (_tmp1_);
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		pw = _tmp2_;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = large_screenshot;
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = gdk_pixbuf_get_height (_tmp3_);
#line 363 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		ph = _tmp4_;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = pw;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = ph;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = MIN (((gdouble) BOXES_MACHINE_SCREENSHOT_WIDTH) / _tmp5_, ((gdouble) BOXES_MACHINE_SCREENSHOT_HEIGHT) / _tmp6_);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		s = _tmp7_;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = pw;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = s;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		w = (gint) (_tmp8_ * _tmp9_);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = ph;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = s;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		h = (gint) (_tmp10_ * _tmp11_);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = large_screenshot;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = gdk_pixbuf_get_has_alpha (_tmp12_);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = _tmp13_;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = w;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = h;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = gdk_pixbuf_new (GDK_COLORSPACE_RGB, _tmp14_, 8, _tmp15_, _tmp16_);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		small_screenshot = _tmp17_;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = large_screenshot;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = small_screenshot;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = w;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = h;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = s;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = s;
#line 369 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_pixbuf_scale (_tmp18_, _tmp19_, 0, 0, _tmp20_, _tmp21_, (gdouble) 0, (gdouble) 0, _tmp22_, _tmp23_, GDK_INTERP_HYPER);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = small_screenshot;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = boxes_machine_pixbuf_energy (self, _tmp24_);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp25_ < 50) {
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (small_screenshot);
#line 380 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 2666 "machine.c"
		}
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = small_screenshot;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = _g_object_ref0 (_tmp26_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->orig_pixbuf);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->orig_pixbuf = _tmp27_;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = small_screenshot;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = boxes_machine_draw_vm (self, _tmp28_, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = _tmp29_;
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, _tmp30_);
#line 383 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp30_);
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = self->priv->machine_actor;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = large_screenshot;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_actor_set_screenshot (_tmp31_, _tmp32_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = save;
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp33_) {
#line 2696 "machine.c"
			GdkPixbuf* _tmp34_;
#line 386 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp34_ = small_screenshot;
#line 386 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_save_pixbuf_as_screenshot (self, _tmp34_);
#line 2702 "machine.c"
		}
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (small_screenshot);
#line 2706 "machine.c"
	} else {
		GdkPixbuf* _tmp35_ = NULL;
		GdkPixbuf* _tmp36_;
		BoxesMachineActor* _tmp37_;
		GdkPixbuf* _tmp38_;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->orig_pixbuf);
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->orig_pixbuf = NULL;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = boxes_machine_draw_stopped_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = _tmp35_;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, _tmp36_);
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp36_);
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp37_ = self->priv->machine_actor;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp38_ = self->priv->_pixbuf;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_actor_set_screenshot (_tmp37_, _tmp38_);
#line 2730 "machine.c"
	}
}


static void boxes_machine_update_screenshot_data_free (gpointer _data) {
	BoxesMachineUpdateScreenshotData* _data_;
	_data_ = _data;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineUpdateScreenshotData, _data_);
#line 2742 "machine.c"
}


static void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
	BoxesMachine* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineUpdateScreenshotData);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_update_screenshot);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_update_screenshot_data_free);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = force_save;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->force_save = _tmp1_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = first_check;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->first_check = _tmp2_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 2771 "machine.c"
}


static void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2779 "machine.c"
}


static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 2793 "machine.c"
}


static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_) {
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 2802 "machine.c"
		goto _state_0;
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 2806 "machine.c"
		goto _state_1;
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case 2:
#line 2810 "machine.c"
		goto _state_2;
		default:
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 2815 "machine.c"
	}
	_state_0:
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = _data_->self->priv->updating_screenshot;
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp0_) {
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2826 "machine.c"
		} else {
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2830 "machine.c"
		}
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 2836 "machine.c"
	}
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = TRUE;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->large_screenshot = NULL;
#line 2842 "machine.c"
	{
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 2850 "machine.c"
		_state_1:
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = NULL;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = _data_->_tmp2_;
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 2860 "machine.c"
			goto __catch46_g_error;
		}
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 404 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->large_screenshot = _data_->_tmp1_;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->first_check;
#line 408 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_tmp3_) {
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_state_ = 2;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return FALSE;
#line 2877 "machine.c"
			_state_2:
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp5_ = NULL;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp5_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp4_ = _data_->_tmp5_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_data_->_inner_error_ != NULL) {
#line 2887 "machine.c"
				goto __catch46_g_error;
			}
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_data_->large_screenshot);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->large_screenshot = _data_->_tmp4_;
#line 2894 "machine.c"
		}
	}
	goto __finally46;
	__catch46_g_error:
	{
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_error_);
#line 2906 "machine.c"
	}
	__finally46:
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 2919 "machine.c"
	}
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp6_ = _data_->large_screenshot;
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp6_ != NULL) {
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = _data_->force_save;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_tmp8_) {
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp7_ = TRUE;
#line 2931 "machine.c"
		} else {
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp9_ = _data_->self->priv->screenshot_counter;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->self->priv->screenshot_counter = _data_->_tmp9_ + 1;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp7_ = (_data_->_tmp9_ % 12) == 0;
#line 2939 "machine.c"
		}
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = _data_->large_screenshot;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp11_ = _data_->_tmp7_;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (_data_->self, _data_->_tmp10_, _data_->_tmp11_);
#line 2947 "machine.c"
	}
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = FALSE;
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->large_screenshot);
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2957 "machine.c"
	} else {
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2961 "machine.c"
	}
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 396 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 2967 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height) {
	GdkPixbuf* result = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp0_;
	gint _tmp1_;
	cairo_surface_t* _tmp2_;
	cairo_t* context = NULL;
	cairo_surface_t* _tmp3_;
	cairo_t* _tmp4_;
	gint pw = 0;
	GdkPixbuf* _tmp5_;
	gint _tmp6_ = 0;
	gint ph = 0;
	GdkPixbuf* _tmp7_;
	gint _tmp8_ = 0;
	gint x = 0;
	gint _tmp9_;
	gint _tmp10_;
	gint y = 0;
	gint _tmp11_;
	gint _tmp12_;
	cairo_t* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	cairo_t* _tmp18_;
	cairo_t* _tmp19_;
	GdkPixbuf* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	cairo_t* _tmp23_;
	cairo_t* _tmp24_;
	gboolean _tmp25_ = FALSE;
	cairo_surface_t* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
	GdkPixbuf* _tmp40_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = width;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = height;
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp0_, _tmp1_);
#line 420 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp2_;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = surface;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = cairo_create (_tmp3_);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	context = _tmp4_;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = pixbuf;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = gdk_pixbuf_get_width (_tmp5_);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	pw = _tmp6_;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = pixbuf;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = gdk_pixbuf_get_height (_tmp7_);
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	ph = _tmp8_;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = width;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = pw;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	x = (_tmp9_ - _tmp10_) / 2;
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = height;
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = ph;
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	y = (_tmp11_ - _tmp12_) / 2;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = context;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = x;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = y;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = pw;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = ph;
#line 428 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp13_, (gdouble) _tmp14_, (gdouble) _tmp15_, (gdouble) _tmp16_, (gdouble) _tmp17_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = context;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_clip (_tmp18_);
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = context;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = pixbuf;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = x;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = y;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gdk_cairo_set_source_pixbuf (_tmp19_, _tmp20_, (gdouble) _tmp21_, (gdouble) _tmp22_);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = context;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp23_, CAIRO_OPERATOR_SOURCE);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = context;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp24_);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = boxes_machine_is_running (self);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp25_) {
#line 3089 "machine.c"
		cairo_t* _tmp26_;
		cairo_t* _tmp27_;
		cairo_t* _tmp28_;
		cairo_t* _tmp29_;
		cairo_pattern_t* grid = NULL;
		cairo_surface_t* _tmp30_;
		cairo_pattern_t* _tmp31_;
		cairo_pattern_t* _tmp32_;
		cairo_t* _tmp33_;
		cairo_t* _tmp34_;
		cairo_t* _tmp35_;
		cairo_pattern_t* _tmp36_;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = context;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp26_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = context;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp27_, CAIRO_OPERATOR_HSL_SATURATION);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = context;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_paint (_tmp28_);
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = context;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_scale (_tmp29_, 2.0, 2.0);
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = boxes_machine_grid_surface;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = cairo_pattern_create_for_surface (_tmp30_);
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		grid = _tmp31_;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = grid;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_pattern_set_extend (_tmp32_, CAIRO_EXTEND_REPEAT);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = context;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp33_, 0.2, 0.2, 0.2, (gdouble) 1);
#line 444 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = context;
#line 444 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp34_, CAIRO_OPERATOR_ADD);
#line 445 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = context;
#line 445 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = grid;
#line 445 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_mask (_tmp35_, _tmp36_);
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_pattern_destroy0 (grid);
#line 3144 "machine.c"
	}
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp37_ = surface;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp38_ = width;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp39_ = height;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp40_ = gdk_pixbuf_get_from_surface (_tmp37_, 0, 0, _tmp38_, _tmp39_);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp40_;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (context);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3162 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_stopped_vm (gint width, gint height) {
	GdkPixbuf* result = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp0_;
	gint _tmp1_;
	cairo_surface_t* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	GdkPixbuf* _tmp5_ = NULL;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = width;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = height;
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_RGB24, _tmp0_, _tmp1_);
#line 453 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp2_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = width;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = height;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = gdk_pixbuf_get_from_surface (surface, 0, 0, _tmp3_, _tmp4_);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp5_;
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 454 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3195 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* pixbuf = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint _tmp2_;
	gboolean _tmp4_;
	gboolean _tmp6_;
	GdkPixbuf* _tmp43_;
	cairo_surface_t* surface = NULL;
	gint _tmp44_;
	gint _tmp45_;
	cairo_surface_t* _tmp46_;
	cairo_surface_t* _tmp47_;
	gint _tmp48_;
	gint _tmp49_;
	GdkPixbuf* _tmp50_ = NULL;
	GError * _inner_error_ = NULL;
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	pixbuf = NULL;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = width;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_ == BOXES_MACHINE_SCREENSHOT_WIDTH) {
#line 3223 "machine.c"
		gint _tmp3_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = height;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp3_ == BOXES_MACHINE_SCREENSHOT_HEIGHT;
#line 3229 "machine.c"
	} else {
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = FALSE;
#line 3233 "machine.c"
	}
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp1_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_) {
#line 3239 "machine.c"
		gboolean _tmp5_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = force;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = !_tmp5_;
#line 3245 "machine.c"
	} else {
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = FALSE;
#line 3249 "machine.c"
	}
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp0_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 3255 "machine.c"
		GdkPixbuf* _tmp7_;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_machine_default_fallback;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp7_ != NULL) {
#line 3261 "machine.c"
			GdkPixbuf* _tmp8_;
			GdkPixbuf* _tmp9_;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = boxes_machine_default_fallback;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = _g_object_ref0 (_tmp8_);
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			result = _tmp9_;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return result;
#line 3274 "machine.c"
		} else {
			gint _tmp10_;
			gint _tmp11_;
			GdkPixbuf* _tmp12_ = NULL;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = width;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = height;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = boxes_machine_draw_fallback_vm (_tmp10_, _tmp11_, TRUE);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (boxes_machine_default_fallback);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_default_fallback = _tmp12_;
#line 3289 "machine.c"
		}
	}
	{
		cairo_surface_t* surface = NULL;
		gint _tmp13_;
		gint _tmp14_;
		cairo_surface_t* _tmp15_;
		cairo_t* context = NULL;
		cairo_surface_t* _tmp16_;
		cairo_t* _tmp17_;
		gint size = 0;
		gint _tmp18_;
		GtkIconInfo* icon_info = NULL;
		GtkIconTheme* _tmp19_ = NULL;
		gint _tmp20_;
		GtkIconInfo* _tmp21_ = NULL;
		GdkPixbuf* _tmp22_ = NULL;
		GtkIconInfo* _tmp23_;
		GdkPixbuf* _tmp24_ = NULL;
		cairo_t* _tmp25_;
		GdkPixbuf* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		cairo_t* _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		cairo_t* _tmp38_;
		cairo_surface_t* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		GdkPixbuf* _tmp42_ = NULL;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = width;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = height;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp13_, _tmp14_);
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		surface = _tmp15_;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = surface;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = cairo_create (_tmp16_);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		context = _tmp17_;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = height;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		size = (gint) (_tmp18_ * 0.6);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = gtk_icon_theme_get_default ();
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = size;
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = gtk_icon_theme_lookup_icon (_tmp19_, "computer-symbolic", _tmp20_, GTK_ICON_LOOKUP_GENERIC_FALLBACK);
#line 474 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		icon_info = _tmp21_;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = icon_info;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = gtk_icon_info_load_icon (_tmp23_, &_inner_error_);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = _tmp24_;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_gtk_icon_info_free0 (icon_info);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_cairo_destroy0 (context);
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_cairo_surface_destroy0 (surface);
#line 3367 "machine.c"
			goto __catch47_g_error;
		}
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = context;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = _tmp22_;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = width;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = size;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = height;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = size;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_cairo_set_source_pixbuf (_tmp25_, _tmp26_, (gdouble) ((_tmp27_ - _tmp28_) / 2), (gdouble) ((_tmp29_ - _tmp30_) / 2));
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp26_);
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = context;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = width;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = size;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = height;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = size;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = size;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp37_ = size;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_rectangle (_tmp31_, (gdouble) ((_tmp32_ - _tmp33_) / 2), (gdouble) ((_tmp34_ - _tmp35_) / 2), (gdouble) _tmp36_, (gdouble) _tmp37_);
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp38_ = context;
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_fill (_tmp38_);
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp39_ = surface;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp40_ = width;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp41_ = height;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp42_ = gdk_pixbuf_get_from_surface (_tmp39_, 0, 0, _tmp40_, _tmp41_);
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		pixbuf = _tmp42_;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_gtk_icon_info_free0 (icon_info);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_destroy0 (context);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_surface_destroy0 (surface);
#line 3424 "machine.c"
	}
	goto __finally47;
	__catch47_g_error:
	{
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 3433 "machine.c"
	}
	__finally47:
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return NULL;
#line 3446 "machine.c"
	}
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp43_ = pixbuf;
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp43_ != NULL) {
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		result = pixbuf;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 3456 "machine.c"
	}
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp44_ = width;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp45_ = height;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp46_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp44_, _tmp45_);
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp46_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp47_ = surface;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp48_ = width;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp49_ = height;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp50_ = gdk_pixbuf_get_from_surface (_tmp47_, 0, 0, _tmp48_, _tmp49_);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp50_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (pixbuf);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3482 "machine.c"
}


static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user) {
	gulong _tmp0_;
	BoxesBoxConfig* _tmp3_;
	GError * _inner_error_ = NULL;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->deleted = TRUE;
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_screenshot_enable (self, FALSE);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->ui_state_id;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 3498 "machine.c"
		BoxesApp* _tmp1_;
		gulong _tmp2_;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->ui_state_id;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->ui_state_id = (gulong) 0;
#line 3509 "machine.c"
	}
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = self->config;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_box_config_delete (_tmp3_);
#line 3515 "machine.c"
	{
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp5_;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 3528 "machine.c"
				goto __catch48_boxes_error;
			}
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 3537 "machine.c"
		}
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp4_;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_unlink (_tmp6_);
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp6_);
#line 3545 "machine.c"
	}
	goto __finally48;
	__catch48_boxes_error:
	{
		GError* e = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		e = _inner_error_;
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = e;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_->message;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_debug ("machine.vala:505: Could not delete screenshot: %s", _tmp8_);
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (e);
#line 3565 "machine.c"
	}
	__finally48:
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 3576 "machine.c"
	}
}


void boxes_machine_delete (BoxesMachine* self, gboolean by_user) {
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->delete (self, by_user);
#line 3586 "machine.c"
}


static void boxes_machine_real_ui_state_changed (BoxesUI* base) {
	BoxesMachine * self;
	BoxesMachineActor* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	BoxesUIState _tmp5_;
	BoxesUIState _tmp6_;
	gboolean _tmp9_;
	gboolean _tmp12_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->machine_actor;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, _tmp2_);
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp5_;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_ != BOXES_UI_STATE_DISPLAY) {
#line 3617 "machine.c"
		BoxesUIState _tmp7_;
		BoxesUIState _tmp8_;
#line 513 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 513 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_;
#line 513 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp8_ != BOXES_UI_STATE_PROPERTIES;
#line 3626 "machine.c"
	} else {
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = FALSE;
#line 3630 "machine.c"
	}
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp4_;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp9_) {
#line 3636 "machine.c"
		BoxesUIState _tmp10_;
		BoxesUIState _tmp11_;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = _tmp10_;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp11_ != BOXES_UI_STATE_CREDS;
#line 3645 "machine.c"
	} else {
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = FALSE;
#line 3649 "machine.c"
	}
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = _tmp3_;
#line 512 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp12_) {
#line 3655 "machine.c"
		BoxesMachineActor* _tmp13_;
#line 516 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = self->priv->machine_actor;
#line 516 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_actor_update_thumbnail (_tmp13_, NULL, FALSE);
#line 517 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_disconnect_display (self);
#line 3663 "machine.c"
	}
}


static gint boxes_machine_real_compare (BoxesCollectionItem* base, BoxesCollectionItem* other) {
	BoxesMachine * self;
	gint result = 0;
	BoxesCollectionItem* _tmp0_;
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 521 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (other != NULL, 0);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = other;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE)) {
#line 3680 "machine.c"
		BoxesBoxConfig* _tmp1_;
		BoxesCollectionItem* _tmp2_;
		BoxesBoxConfig* _tmp3_;
		gint _tmp4_ = 0;
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->config;
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = other;
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL)->config;
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_box_config_compare (_tmp1_, _tmp3_);
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		result = _tmp4_;
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 3697 "machine.c"
	} else {
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		result = -1;
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 3703 "machine.c"
	}
}


static ClutterActor* boxes_machine_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesMachine* self;
	BoxesMachineActor* _tmp0_;
	ClutterActor* _tmp1_;
	ClutterActor* _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->machine_actor;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_actor ((BoxesUI*) _tmp0_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3726 "machine.c"
}


GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self) {
	GdkPixbuf* result;
	GdkPixbuf* _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_pixbuf;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3741 "machine.c"
}


void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value) {
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_pixbuf = _tmp1_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "pixbuf");
#line 3760 "machine.c"
}


const gchar* boxes_machine_get_info (BoxesMachine* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_info;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3775 "machine.c"
}


void boxes_machine_set_info (BoxesMachine* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_info);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_info = _tmp1_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "info");
#line 3794 "machine.c"
}


const gchar* boxes_machine_get_status (BoxesMachine* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_status;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3809 "machine.c"
}


void boxes_machine_set_status (BoxesMachine* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_status);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_status = _tmp1_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "status");
#line 3828 "machine.c"
}


gboolean boxes_machine_get_can_save (BoxesMachine* self) {
	gboolean result;
	gboolean _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_can_save;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3843 "machine.c"
}


void boxes_machine_set_can_save (BoxesMachine* self, gboolean value) {
	gboolean _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_can_save = _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "can-save");
#line 3857 "machine.c"
}


GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self) {
	GCancellable* result;
	GCancellable* _tmp0_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_connecting_cancellable;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3872 "machine.c"
}


void boxes_machine_set_connecting_cancellable (BoxesMachine* self, GCancellable* value) {
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_connecting_cancellable);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_connecting_cancellable = _tmp1_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "connecting-cancellable");
#line 3891 "machine.c"
}


BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self) {
	BoxesMachineMachineState result;
	BoxesMachineMachineState _tmp0_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_state;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3906 "machine.c"
}


void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value) {
	BoxesMachineMachineState _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	BoxesMachineMachineState _tmp3_;
	BoxesMachineMachineState _tmp4_;
	GEnumValue* _tmp5_;
	gboolean _tmp6_ = FALSE;
	BoxesMachineMachineState _tmp7_;
	gboolean _tmp9_;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	BoxesDisplay* _tmp18_;
	BoxesDisplay* _tmp19_;
	gboolean _tmp21_;
	gboolean _tmp24_;
	gboolean _tmp26_;
	gboolean _tmp28_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_state = _tmp0_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_get_state (self);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = g_enum_get_value (g_type_class_ref (BOXES_MACHINE_TYPE_MACHINE_STATE), _tmp4_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:60: State of '%s' changed to %s", _tmp2_, (_tmp5_ != NULL) ? _tmp5_->value_name : NULL);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = value;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp7_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = TRUE;
#line 3954 "machine.c"
	} else {
		BoxesMachineMachineState _tmp8_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = value;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp8_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 3961 "machine.c"
	}
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp6_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp9_) {
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (self, NULL, FALSE);
#line 3969 "machine.c"
	} else {
		GdkPixbuf* _tmp10_;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = self->priv->orig_pixbuf;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp10_ != NULL) {
#line 3976 "machine.c"
			GdkPixbuf* _tmp11_;
			GdkPixbuf* _tmp12_ = NULL;
			GdkPixbuf* _tmp13_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = self->priv->orig_pixbuf;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = boxes_machine_draw_vm (self, _tmp11_, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = _tmp12_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_set_pixbuf (self, _tmp13_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp13_);
#line 3990 "machine.c"
		}
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = boxes_machine_get_display (self);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = _tmp18_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp19_ != NULL) {
#line 3999 "machine.c"
		gboolean _tmp20_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = self->stay_on_display;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = !_tmp20_;
#line 4005 "machine.c"
	} else {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = FALSE;
#line 4009 "machine.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = _tmp17_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp21_) {
#line 4015 "machine.c"
		BoxesApp* _tmp22_;
		BoxesCollectionItem* _tmp23_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = boxes_app_app;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = _tmp22_->current_item;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = _tmp23_ == G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 4024 "machine.c"
	} else {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = FALSE;
#line 4028 "machine.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = _tmp16_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp24_) {
#line 4034 "machine.c"
		BoxesMachineMachineState _tmp25_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = value;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = _tmp25_ != BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 4040 "machine.c"
	} else {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = FALSE;
#line 4044 "machine.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp26_ = _tmp15_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp26_) {
#line 4050 "machine.c"
		BoxesMachineMachineState _tmp27_;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = value;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = _tmp27_ != BOXES_MACHINE_MACHINE_STATE_UNKNOWN;
#line 4056 "machine.c"
	} else {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = FALSE;
#line 4060 "machine.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp28_ = _tmp14_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp28_) {
#line 4066 "machine.c"
		BoxesApp* _tmp29_;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = boxes_app_app;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_ui_set_ui_state ((BoxesUI*) _tmp29_, BOXES_UI_STATE_COLLECTION);
#line 4072 "machine.c"
	}
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "state");
#line 4076 "machine.c"
}


BoxesDisplay* boxes_machine_get_display (BoxesMachine* self) {
	BoxesDisplay* result;
	BoxesDisplay* _tmp0_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4091 "machine.c"
}


static void _boxes_machine_display___lambda11_ (BoxesMachine* self, gint id) {
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_show_display (self);
#line 4098 "machine.c"
}


static void __boxes_machine_display___lambda11__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda11_ (self, display_id);
#line 4105 "machine.c"
}


static void _boxes_machine_display___lambda160_ (BoxesMachine* self, gint id) {
	BoxesApp* _tmp0_;
	BoxesDisplayPage* _tmp1_;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->display_page;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_display_page_remove_display (_tmp1_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp3_);
#line 4124 "machine.c"
}


static void __boxes_machine_display___lambda160__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda160_ (self, display_id);
#line 4131 "machine.c"
}


static void _boxes_machine_display___lambda161_ (BoxesMachine* self, const gchar* message) {
	const gchar* _tmp0_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (message != NULL);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = message;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_emit_by_name (self, "got-error", _tmp0_);
#line 4143 "machine.c"
}


static void __boxes_machine_display___lambda161__boxes_display_got_error (BoxesDisplay* _sender, const gchar* message, gpointer self) {
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda161_ (self, message);
#line 4150 "machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1274 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1275 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	result = self;
#line 1275 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 4162 "machine.c"
}


static void _boxes_machine_display___lambda162_ (BoxesMachine* self) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_;
	gboolean _tmp9_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = string_to_string (_tmp1_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strconcat ("display ", _tmp2_, " disconnected", NULL);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_message ("machine.vala:147: %s", _tmp4_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp4_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = self->stay_on_display;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp6_) {
#line 4193 "machine.c"
		BoxesApp* _tmp7_;
		BoxesCollectionItem* _tmp8_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_app_app;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_->current_item;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp8_ == G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 4202 "machine.c"
	} else {
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = FALSE;
#line 4206 "machine.c"
	}
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp5_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp9_) {
#line 4212 "machine.c"
		BoxesApp* _tmp10_;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = boxes_app_app;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_ui_set_ui_state ((BoxesUI*) _tmp10_, BOXES_UI_STATE_COLLECTION);
#line 4218 "machine.c"
	}
}


static void __boxes_machine_display___lambda162__boxes_display_disconnected (BoxesDisplay* _sender, gpointer self) {
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda162_ (self);
#line 4226 "machine.c"
}


static void _boxes_machine_display___lambda163_ (BoxesMachine* self) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
	BoxesMachineActor* _tmp5_;
	BoxesDisplay* _tmp6_;
	BoxesDisplay* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _ ("Enter password for %s");
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_status (self, _tmp4_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp4_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = self->priv->machine_actor;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = boxes_machine_get_display (self);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = _tmp6_;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_display_get_need_password (_tmp7_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_password_needed (_tmp5_, _tmp9_);
#line 4267 "machine.c"
}


static void __boxes_machine_display___lambda163__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda163_ (self);
#line 4274 "machine.c"
}


static void _boxes_machine_display___lambda164_ (BoxesMachine* self) {
	BoxesMachineActor* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->machine_actor;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_get_display (self);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_display_get_need_username (_tmp2_);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_username_needed (_tmp0_, _tmp4_);
#line 4296 "machine.c"
}


static void __boxes_machine_display___lambda164__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda164_ (self);
#line 4303 "machine.c"
}


void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value) {
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp15_;
	BoxesDisplay* _tmp16_;
	BoxesDisplay* _tmp17_;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_;
	BoxesDisplay* _tmp23_;
	gulong _tmp24_ = 0UL;
	BoxesDisplay* _tmp25_;
	gulong _tmp26_ = 0UL;
	BoxesDisplay* _tmp27_;
	gulong _tmp28_ = 0UL;
	BoxesDisplay* _tmp29_;
	gulong _tmp30_ = 0UL;
	BoxesDisplay* _tmp31_;
	gulong _tmp32_ = 0UL;
	BoxesDisplay* _tmp33_;
	gulong _tmp34_ = 0UL;
	BoxesDisplay* _tmp35_;
	BoxesMachineActor* _tmp36_;
	gchar* _tmp37_ = NULL;
	gchar* _tmp38_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 4339 "machine.c"
		BoxesDisplay* _tmp1_;
		gulong _tmp2_;
		guint _tmp3_;
		BoxesDisplay* _tmp5_;
		gulong _tmp6_;
		BoxesDisplay* _tmp7_;
		gulong _tmp8_;
		BoxesDisplay* _tmp9_;
		gulong _tmp10_;
		BoxesDisplay* _tmp11_;
		gulong _tmp12_;
		BoxesDisplay* _tmp13_;
		gulong _tmp14_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->_display;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->show_id;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->show_id = (gulong) 0;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = self->priv->show_timeout_id;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp3_ != ((guint) 0)) {
#line 4365 "machine.c"
			guint _tmp4_;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp4_ = self->priv->show_timeout_id;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_source_remove (_tmp4_);
#line 4371 "machine.c"
		}
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->show_timeout_id = (guint) 0;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = self->priv->_display;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->hide_id;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->hide_id = (gulong) 0;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->_display;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = self->priv->disconnected_id;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp7_, _tmp8_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->disconnected_id = (gulong) 0;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = self->priv->_display;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = self->priv->need_password_id;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp9_, _tmp10_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->need_password_id = (gulong) 0;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = self->priv->_display;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = self->priv->need_username_id;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->need_username_id = (gulong) 0;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = self->priv->_display;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = self->priv->got_error_id;
#line 125 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp13_, _tmp14_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->got_error_id = (gulong) 0;
#line 4415 "machine.c"
	}
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = value;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_display = _tmp16_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = self->priv->_display;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp17_ == NULL) {
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 4431 "machine.c"
	}
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = _ ("Connecting to %s");
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = g_strdup_printf (_tmp18_, _tmp20_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = _tmp21_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_status (self, _tmp22_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp22_);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = self->priv->_display;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = g_signal_connect_object (_tmp23_, "show", (GCallback) __boxes_machine_display___lambda11__boxes_display_show, self, 0);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->show_id = _tmp24_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = self->priv->_display;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp26_ = g_signal_connect_object (_tmp25_, "hide", (GCallback) __boxes_machine_display___lambda160__boxes_display_hide, self, 0);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->hide_id = _tmp26_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp27_ = self->priv->_display;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp28_ = g_signal_connect_object (_tmp27_, "got-error", (GCallback) __boxes_machine_display___lambda161__boxes_display_got_error, self, 0);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->got_error_id = _tmp28_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp29_ = self->priv->_display;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp30_ = g_signal_connect_object (_tmp29_, "disconnected", (GCallback) __boxes_machine_display___lambda162__boxes_display_disconnected, self, 0);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->disconnected_id = _tmp30_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp31_ = self->priv->_display;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp32_ = g_signal_connect_object ((GObject*) _tmp31_, "notify::need-password", (GCallback) __boxes_machine_display___lambda163__g_object_notify, self, 0);
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->need_password_id = _tmp32_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp33_ = self->priv->_display;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp34_ = g_signal_connect_object ((GObject*) _tmp33_, "notify::need-username", (GCallback) __boxes_machine_display___lambda164__g_object_notify, self, 0);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->need_username_id = _tmp34_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp35_ = self->priv->_display;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp36_ = self->priv->machine_actor;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp37_ = boxes_machine_actor_get_password (_tmp36_);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp38_ = _tmp37_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_display_set_password (_tmp35_, _tmp38_);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp38_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "display");
#line 4497 "machine.c"
}


static void boxes_machine_class_init (BoxesMachineClass * klass) {
	cairo_surface_t* _tmp0_;
	cairo_t* cr = NULL;
	cairo_surface_t* _tmp1_;
	cairo_t* _tmp2_;
	cairo_t* _tmp3_;
	cairo_t* _tmp4_;
	cairo_t* _tmp5_;
	cairo_t* _tmp6_;
	cairo_t* _tmp7_;
	cairo_t* _tmp8_;
	cairo_t* _tmp9_;
	cairo_t* _tmp10_;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_parent_class = g_type_class_peek_parent (klass);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachinePrivate));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->save_real = boxes_machine_real_save_real;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->save_real_finish = boxes_machine_real_save_real_finish;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot = boxes_machine_real_take_screenshot;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot_finish = boxes_machine_real_take_screenshot_finish;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_properties = boxes_machine_real_get_properties;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->disconnect_display = boxes_machine_real_disconnect_display;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->delete = boxes_machine_real_delete;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_machine_real_ui_state_changed;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_COLLECTION_ITEM_CLASS (klass)->compare = boxes_machine_real_compare;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_machine_real_get_actor;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_get_property;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_machine_set_property;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_finalize;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_PIXBUF, g_param_spec_object ("pixbuf", "pixbuf", "pixbuf", GDK_TYPE_PIXBUF, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_INFO, g_param_spec_string ("info", "info", "info", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_STATUS, g_param_spec_string ("status", "status", "status", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_CAN_SAVE, g_param_spec_boolean ("can-save", "can-save", "can-save", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_CONNECTING_CANCELLABLE, g_param_spec_object ("connecting-cancellable", "connecting-cancellable", "connecting-cancellable", g_cancellable_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_STATE, g_param_spec_enum ("state", "state", "state", BOXES_MACHINE_TYPE_MACHINE_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_DISPLAY, g_param_spec_object ("display", "display", "display", BOXES_TYPE_DISPLAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_new ("got_error", BOXES_TYPE_MACHINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = cairo_image_surface_create (CAIRO_FORMAT_A8, 2, 2);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (boxes_machine_grid_surface);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_grid_surface = _tmp0_;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_grid_surface;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_create (_tmp1_);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cr = _tmp2_;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = cr;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp3_, (gdouble) 0, (gdouble) 0, (gdouble) 0, (gdouble) 0);
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = cr;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp4_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = cr;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp5_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = cr;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp6_, CAIRO_OPERATOR_SOURCE);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = cr;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp7_, (gdouble) 0, (gdouble) 0, (gdouble) 1, (gdouble) 1);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = cr;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp8_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = cr;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp9_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = cr;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp10_);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (cr);
#line 4608 "machine.c"
}


static void boxes_machine_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_machine_get_properties;
#line 4617 "machine.c"
}


static void boxes_machine_instance_init (BoxesMachine * self) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv = BOXES_MACHINE_GET_PRIVATE (self);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_can_save = FALSE;
#line 4626 "machine.c"
}


static void boxes_machine_finalize (GObject* obj) {
	BoxesMachine * self;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE, BoxesMachine);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine_actor);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->config);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_info);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_status);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_connecting_cancellable);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->orig_pixbuf);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (boxes_machine_parent_class)->finalize (obj);
#line 4654 "machine.c"
}


GType boxes_machine_get_type (void) {
	static volatile gsize boxes_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachine), 0, (GInstanceInitFunc) boxes_machine_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_machine_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_machine_type_id;
		boxes_machine_type_id = g_type_register_static (BOXES_TYPE_COLLECTION_ITEM, "BoxesMachine", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_machine_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_machine_type_id__volatile, boxes_machine_type_id);
	}
	return boxes_machine_type_id__volatile;
}


static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_ACTOR:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_pixbuf (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_INFO:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_string (value, boxes_machine_get_info (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATUS:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_string (value, boxes_machine_get_status (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CAN_SAVE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_can_save (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CONNECTING_CANCELLABLE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_connecting_cancellable (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_enum (value, boxes_machine_get_state (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_display (self));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 4725 "machine.c"
		default:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 4731 "machine.c"
	}
}


static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, g_value_get_object (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_INFO:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_info (self, g_value_get_string (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATUS:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_status (self, g_value_get_string (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CAN_SAVE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_can_save (self, g_value_get_boolean (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CONNECTING_CANCELLABLE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_connecting_cancellable (self, g_value_get_object (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_state (self, g_value_get_enum (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (self, g_value_get_object (value));
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 4783 "machine.c"
		default:
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 4789 "machine.c"
	}
}


static Block39Data* block39_data_ref (Block39Data* _data39_) {
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data39_->_ref_count_);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return _data39_;
#line 4799 "machine.c"
}


static void block39_data_unref (void * _userdata_) {
	Block39Data* _data39_;
	_data39_ = (Block39Data*) _userdata_;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data39_->_ref_count_)) {
#line 4808 "machine.c"
		BoxesMachineActor * self;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self = _data39_->self;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data39_->machine);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_slice_free (Block39Data, _data39_);
#line 4818 "machine.c"
	}
}


static gboolean __lambda165_ (Block39Data* _data39_, GdkEventKey* event) {
	BoxesMachineActor * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GdkEventKey _tmp2_;
	guint _tmp3_;
	gboolean _tmp6_;
	gboolean _tmp9_;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = _data39_->self;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = *event;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_.keyval;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp3_ == ((guint) GDK_KEY_KP_Enter)) {
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = TRUE;
#line 4844 "machine.c"
	} else {
		GdkEventKey _tmp4_;
		guint _tmp5_;
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = *event;
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_.keyval;
#line 584 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp5_ == ((guint) GDK_KEY_ISO_Enter);
#line 4854 "machine.c"
	}
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp1_;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = TRUE;
#line 4862 "machine.c"
	} else {
		GdkEventKey _tmp7_;
		guint _tmp8_;
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = *event;
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_.keyval;
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp8_ == ((guint) GDK_KEY_Return);
#line 4872 "machine.c"
	}
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp0_;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp9_) {
#line 4878 "machine.c"
		BoxesMachine* _tmp10_;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = _data39_->machine;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_connect_display (_tmp10_, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL);
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		result = TRUE;
#line 588 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 4888 "machine.c"
	}
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4894 "machine.c"
}


static gboolean ___lambda165__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = __lambda165_ (self, event);
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4903 "machine.c"
}


BoxesMachineActor* boxes_machine_actor_construct (GType object_type, BoxesMachine* machine) {
	BoxesMachineActor * self = NULL;
	Block39Data* _data39_;
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachine* _tmp3_;
	ClutterBoxLayout* layout = NULL;
	ClutterBoxLayout* _tmp4_;
	ClutterActor* _tmp5_;
	ClutterActor* _tmp6_;
	GtkClutterTexture* _tmp7_;
	GtkClutterTexture* _tmp8_;
	BoxesMachine* _tmp9_;
	GdkPixbuf* _tmp10_;
	GdkPixbuf* _tmp11_;
	ClutterActor* _tmp12_;
	ClutterActor* _tmp13_;
	GtkClutterTexture* _tmp14_;
	ClutterActor* _tmp15_;
	GtkClutterTexture* _tmp16_;
	GtkBox* _tmp17_;
	GtkBox* _tmp18_;
	GtkClutterActor* _tmp19_;
	GtkClutterActor* _tmp20_;
	GtkClutterActor* _tmp21_;
	GtkWidget* _tmp22_ = NULL;
	GtkStyleContext* _tmp23_ = NULL;
	BoxesMachine* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	GtkLabel* _tmp27_;
	GtkLabel* _tmp28_;
	GtkStyleContext* _tmp29_ = NULL;
	BoxesMachine* _tmp30_;
	GtkLabel* _tmp31_;
	GtkBox* _tmp32_;
	GtkLabel* _tmp33_;
	GtkBox* _tmp34_;
	GtkEntry* _tmp35_;
	GtkEntry* _tmp36_;
	GtkEntry* _tmp37_;
	const gchar* _tmp38_ = NULL;
	GtkEntry* _tmp39_;
	GtkBox* _tmp40_;
	GtkEntry* _tmp41_;
	GtkBox* _tmp42_;
	GtkEntry* _tmp43_;
	ClutterActor* _tmp44_;
	GtkClutterActor* _tmp45_;
	ClutterActor* _tmp46_;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data39_ = g_slice_new0 (Block39Data);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data39_->_ref_count_ = 1;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = machine;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data39_->machine);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data39_->machine = _tmp1_;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) boxes_ui_construct (object_type);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data39_->self = g_object_ref (self);
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _data39_->machine;
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine);
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->machine = _tmp3_;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = (ClutterBoxLayout*) clutter_box_layout_new ();
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp4_);
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	layout = _tmp4_;
#line 552 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_box_layout_set_orientation (layout, CLUTTER_ORIENTATION_VERTICAL);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_box_layout_set_spacing (layout, (guint) 10);
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = clutter_actor_new ();
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp5_);
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->_actor);
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->_actor = _tmp5_;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = self->_actor;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_layout_manager (_tmp6_, (ClutterLayoutManager*) layout);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = (GtkClutterTexture*) gtk_clutter_texture_new ();
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp7_);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->screenshot);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->screenshot = _tmp7_;
#line 558 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = self->priv->screenshot;
#line 558 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp8_, "screenshot");
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _data39_->machine;
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_machine_get_pixbuf (_tmp9_);
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = _tmp10_;
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_screenshot (self, _tmp11_);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = self->_actor;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = self->_actor;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp13_, "natural-width", (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, NULL);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp12_, "min-width", (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, NULL);
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = self->priv->screenshot;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_texture_set_keep_aspect_ratio ((ClutterTexture*) _tmp14_, TRUE);
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = self->_actor;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = self->priv->screenshot;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_container_add ((ClutterContainer*) _tmp15_, (ClutterActor*) _tmp16_, NULL);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp17_);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->vbox);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->vbox = _tmp17_;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = self->priv->vbox;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp18_);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp19_);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->gtk_vbox);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->gtk_vbox = _tmp19_;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = self->priv->gtk_vbox;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_height ((ClutterActor*) _tmp20_, (gfloat) 80);
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = self->priv->gtk_vbox;
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = gtk_clutter_actor_get_widget (_tmp21_);
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = gtk_widget_get_style_context (_tmp22_);
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_style_context_add_class (_tmp23_, "boxes-bg");
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = _data39_->machine;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp24_);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp26_ = _tmp25_;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp27_ = (GtkLabel*) gtk_label_new (_tmp26_);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp27_);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->label);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->label = _tmp27_;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp28_ = self->priv->label;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) _tmp28_);
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_style_context_add_class (_tmp29_, "boxes-machine-name-label");
#line 575 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp30_ = _data39_->machine;
#line 575 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp31_ = self->priv->label;
#line 575 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp30_, "name", (GObject*) _tmp31_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp32_ = self->priv->vbox;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp33_ = self->priv->label;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_container_add ((GtkContainer*) _tmp32_, (GtkWidget*) _tmp33_);
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp34_ = self->priv->vbox;
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp34_, GTK_ALIGN_START);
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp35_ = (GtkEntry*) gtk_entry_new ();
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp35_);
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->password_entry = _tmp35_;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp36_ = self->priv->password_entry;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_entry_set_visibility (_tmp36_, FALSE);
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp37_ = self->priv->password_entry;
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp38_ = _ ("Password");
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_entry_set_placeholder_text (_tmp37_, _tmp38_);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_password_needed (self, FALSE);
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp39_ = self->priv->password_entry;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_connect_data ((GtkWidget*) _tmp39_, "key-press-event", (GCallback) ___lambda165__gtk_widget_key_press_event, block39_data_ref (_data39_), (GClosureNotify) block39_data_unref, 0);
#line 593 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp40_ = self->priv->vbox;
#line 593 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp41_ = self->priv->password_entry;
#line 593 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_container_add ((GtkContainer*) _tmp40_, (GtkWidget*) _tmp41_);
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp42_ = self->priv->vbox;
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp42_);
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp43_ = self->priv->password_entry;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_hide ((GtkWidget*) _tmp43_);
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp44_ = self->_actor;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp45_ = self->priv->gtk_vbox;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_container_add ((ClutterContainer*) _tmp44_, (ClutterActor*) _tmp45_, NULL);
#line 599 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp46_ = self->_actor;
#line 599 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_reactive (_tmp46_, TRUE);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (layout);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	block39_data_unref (_data39_);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_data39_ = NULL;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return self;
#line 5166 "machine.c"
}


BoxesMachineActor* boxes_machine_actor_new (BoxesMachine* machine) {
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return boxes_machine_actor_construct (BOXES_TYPE_MACHINE_ACTOR, machine);
#line 5173 "machine.c"
}


void boxes_machine_actor_set_screenshot (BoxesMachineActor* self, GdkPixbuf* pixbuf) {
	GError * _inner_error_ = NULL;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (pixbuf != NULL);
#line 5183 "machine.c"
	{
		GtkClutterTexture* _tmp0_;
		GdkPixbuf* _tmp1_;
		GtkClutterTexture* _tmp2_;
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = self->priv->screenshot;
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = pixbuf;
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		gtk_clutter_texture_set_from_pixbuf (_tmp0_, _tmp1_, &_inner_error_);
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 5196 "machine.c"
			goto __catch49_g_error;
		}
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->thumbnail_screenshot;
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp2_ != NULL) {
#line 5203 "machine.c"
			GtkClutterTexture* _tmp3_;
			GdkPixbuf* _tmp4_;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp3_ = self->priv->thumbnail_screenshot;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp4_ = pixbuf;
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_clutter_texture_set_from_pixbuf (_tmp3_, _tmp4_, &_inner_error_);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_inner_error_ != NULL) {
#line 5214 "machine.c"
				goto __catch49_g_error;
			}
		}
	}
	goto __finally49;
	__catch49_g_error:
	{
		GError* err = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		err = _inner_error_;
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = err;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_->message;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:608: %s", _tmp6_);
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (err);
#line 5237 "machine.c"
	}
	__finally49:
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 5248 "machine.c"
	}
}


void boxes_machine_actor_set_password_needed (BoxesMachineActor* self, gboolean needed) {
	ClutterActor* _tmp0_;
	GtkEntry* _tmp1_;
	gboolean _tmp2_;
	GtkEntry* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->_actor;
#line 613 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_queue_relayout (_tmp0_);
#line 614 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = self->priv->password_entry;
#line 614 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = needed;
#line 614 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, _tmp2_);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = self->priv->password_entry;
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = needed;
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp3_, _tmp4_);
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = needed;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp5_) {
#line 5282 "machine.c"
		GtkEntry* _tmp6_;
		BoxesMachine* _tmp7_;
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->password_entry;
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 618 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->machine;
#line 618 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (_tmp7_, NULL);
#line 5293 "machine.c"
	}
}


void boxes_machine_actor_set_username_needed (BoxesMachineActor* self, gboolean needed) {
	gboolean _tmp0_;
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:623: FIXME: Do something about fetching username when req" \
"uired?");
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = needed;
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 5308 "machine.c"
		BoxesMachine* _tmp1_;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->machine;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (_tmp1_, NULL);
#line 5314 "machine.c"
	}
}


gchar* boxes_machine_actor_get_password (BoxesMachineActor* self) {
	gchar* result = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->password_entry;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp3_;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5339 "machine.c"
}


static GtkWidget* boxes_machine_actor_steal_display_widget_from_thumbnail (BoxesMachineActor* self) {
	GtkWidget* result = NULL;
	GtkWidget* widget = NULL;
	ClutterActor* _tmp0_;
	ClutterActor* _tmp5_;
	GtkWidget* _tmp6_;
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 633 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	widget = NULL;
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->thumbnail;
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_clutter_actor_get_type ())) {
#line 5357 "machine.c"
		ClutterActor* _tmp1_;
		GtkWidget* _tmp2_ = NULL;
		GtkWidget* _tmp3_;
		ClutterActor* _tmp4_;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->thumbnail;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_get (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_clutter_actor_get_type ()) ? ((GtkClutterActor*) _tmp1_) : NULL, "contents", &_tmp2_, NULL);
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (widget);
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		widget = _tmp3_;
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->thumbnail;
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_clutter_actor_get_type ()) ? ((GtkClutterActor*) _tmp4_) : NULL, "contents", NULL, NULL);
#line 5376 "machine.c"
	}
#line 638 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = self->priv->thumbnail;
#line 638 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_destroy (_tmp5_);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->thumbnail);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->thumbnail = NULL;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->thumbnail_screenshot);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->thumbnail_screenshot = NULL;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = widget;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_ != NULL) {
#line 5394 "machine.c"
		BoxesMachine* _tmp7_;
		BoxesDisplay* _tmp8_;
		BoxesDisplay* _tmp9_;
		GtkWidget* _tmp10_;
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->machine;
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = boxes_machine_get_display (_tmp7_);
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = _tmp8_;
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = widget;
#line 643 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_set_enable_inputs (_tmp9_, _tmp10_, TRUE);
#line 5409 "machine.c"
	}
#line 645 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = widget;
#line 645 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5415 "machine.c"
}


static Block40Data* block40_data_ref (Block40Data* _data40_) {
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data40_->_ref_count_);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return _data40_;
#line 5424 "machine.c"
}


static void block40_data_unref (void * _userdata_) {
	Block40Data* _data40_;
	_data40_ = (Block40Data*) _userdata_;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data40_->_ref_count_)) {
#line 5433 "machine.c"
		BoxesMachineActor * self;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self = _data40_->self;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		(_data40_->update_screenshot_alloc_target_destroy_notify == NULL) ? NULL : (_data40_->update_screenshot_alloc_target_destroy_notify (_data40_->update_screenshot_alloc_target), NULL);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc = NULL;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc_target = NULL;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc_target_destroy_notify = NULL;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_slice_free (Block40Data, _data40_);
#line 5449 "machine.c"
	}
}


static void ____lambda155_ (BoxesMachineActor* self) {
	BoxesApp* _tmp0_;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_DISPLAY);
#line 5460 "machine.c"
}


static void _____lambda155__clutter_click_action_clicked (ClutterClickAction* _sender, ClutterActor* actor, gpointer self) {
#line 700 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	____lambda155_ (self);
#line 5467 "machine.c"
}


static void _____lambda156_ (BoxesMachineActor* self) {
	BoxesApp* _tmp0_;
	BoxesMachine* _tmp1_;
	ClutterActor* _tmp2_;
	ClutterActorBox* _tmp3_ = NULL;
	ClutterActorBox* _tmp4_;
	gfloat _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActorBox* _tmp7_ = NULL;
	ClutterActorBox* _tmp8_;
	gfloat _tmp9_;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = self->priv->machine;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = self->priv->thumbnail;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_get (_tmp2_, "allocation", &_tmp3_, NULL);
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = (*_tmp4_).x1;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = self->priv->thumbnail;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_get (_tmp6_, "allocation", &_tmp7_, NULL);
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = _tmp7_;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = (*_tmp8_).y1;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_app_connect_to (_tmp0_, _tmp1_, _tmp5_, _tmp9_, BOXES_MACHINE_CONNECT_FLAGS_NONE);
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_update_thumbnail (self, NULL, FALSE);
#line 5506 "machine.c"
}


static void ______lambda156__clutter_click_action_clicked (ClutterClickAction* _sender, ClutterActor* actor, gpointer self) {
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_____lambda156_ (self);
#line 5513 "machine.c"
}


static void ___lambda157_ (BoxesMachineActor* self, ClutterActor* thumbnail) {
	GtkAllocation alloc = {0};
	BoxesApp* _tmp0_;
	BoxesProperties* _tmp1_;
	GtkWidget* _tmp2_;
	GtkAllocation _tmp3_ = {0};
	BoxesApp* _tmp4_;
	BoxesTopbar* _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActor* _tmp7_;
	guint d = 0U;
	ClutterActor* _tmp8_;
	guint _tmp9_ = 0U;
	ClutterActor* _tmp10_;
	ClutterActor* _tmp11_;
	GtkAllocation _tmp12_;
	gint _tmp13_;
	ClutterActor* _tmp14_;
	GtkAllocation _tmp15_;
	gint _tmp16_;
	ClutterActor* _tmp17_;
	ClutterActor* _tmp18_;
	GtkAllocation _tmp19_;
	gint _tmp20_;
	ClutterActor* _tmp21_;
	ClutterActor* _tmp22_;
	GtkAllocation _tmp23_;
	gint _tmp24_;
	ClutterActor* _tmp25_;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (thumbnail != NULL);
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->properties;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_->screenshot_placeholder;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_widget_get_allocation (_tmp2_, &_tmp3_);
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	alloc = _tmp3_;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_app_app;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_->topbar;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = boxes_ui_get_actor ((BoxesUI*) _tmp5_);
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = _tmp6_;
#line 716 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_show (_tmp7_);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = thumbnail;
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = clutter_actor_get_easing_duration (_tmp8_);
#line 725 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	d = _tmp9_;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = thumbnail;
#line 726 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_easing_duration (_tmp10_, (guint) 0);
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = thumbnail;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = alloc;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_.x;
#line 727 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp11_, "fixed-x", (gfloat) _tmp13_, NULL);
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = thumbnail;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = alloc;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_.y;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp14_, "fixed-y", (gfloat) _tmp16_, NULL);
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = thumbnail;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = thumbnail;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = alloc;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_.width;
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp18_, "natural-width", (gfloat) _tmp20_, NULL);
#line 729 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp17_, "min-width", (gfloat) _tmp20_, NULL);
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = thumbnail;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = thumbnail;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = alloc;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = _tmp23_.height;
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp22_, "natural-height", (gfloat) _tmp24_, NULL);
#line 730 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_set (_tmp21_, "min-height", (gfloat) _tmp24_, NULL);
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = thumbnail;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_easing_duration (_tmp25_, d);
#line 5622 "machine.c"
}


static void ____lambda157__boxes_actor_func (ClutterActor* actor, gpointer self) {
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	___lambda157_ (self, actor);
#line 5629 "machine.c"
}


static gboolean __lambda159_ (Block40Data* _data40_) {
	BoxesMachineActor * self;
	gboolean result = FALSE;
	BoxesActorFunc _tmp0_;
	void* _tmp0__target;
	ClutterActor* _tmp1_;
#line 737 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = _data40_->self;
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _data40_->update_screenshot_alloc;
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0__target = _data40_->update_screenshot_alloc_target;
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = self->priv->thumbnail;
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ (_tmp1_, _tmp0__target);
#line 739 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 739 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5653 "machine.c"
}


static gboolean ___lambda159__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda159_ (self);
#line 737 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5662 "machine.c"
}


static void ___lambda158_ (Block40Data* _data40_) {
	BoxesMachineActor * self;
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = _data40_->self;
#line 737 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda159__gsource_func, block40_data_ref (_data40_), block40_data_unref);
#line 5672 "machine.c"
}


static void ____lambda158__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	___lambda158_ (self);
#line 5679 "machine.c"
}


void boxes_machine_actor_update_thumbnail (BoxesMachineActor* self, GtkWidget* display_widget, gboolean zoom) {
	gulong _tmp0_;
	ClutterActor* _tmp5_;
	BoxesUIState _tmp8_;
	BoxesUIState _tmp9_;
	GError * _inner_error_ = NULL;
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->track_screenshot_id;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 5695 "machine.c"
		BoxesApp* _tmp1_;
		BoxesProperties* _tmp2_;
		GtkWidget* _tmp3_;
		gulong _tmp4_;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp1_->properties;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->screenshot_placeholder;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->track_screenshot_id;
#line 650 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 5710 "machine.c"
	}
#line 651 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->track_screenshot_id = (gulong) 0;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = self->priv->thumbnail;
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp5_ != NULL) {
#line 5718 "machine.c"
		ClutterActor* _tmp6_;
		ClutterActor* _tmp7_;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->thumbnail;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_actor_remove (_tmp6_);
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->thumbnail;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_destroy (_tmp7_);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->thumbnail);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->thumbnail = NULL;
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->thumbnail_screenshot);
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->thumbnail_screenshot = NULL;
#line 5737 "machine.c"
	}
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp9_ == BOXES_UI_STATE_PROPERTIES) {
#line 5745 "machine.c"
		Block40Data* _data40_;
		GtkWidget* _tmp10_;
		ClutterActor* _tmp40_;
		ClutterActor* _tmp41_;
		ClutterActor* _tmp42_;
		BoxesApp* _tmp43_;
		ClutterActor* _tmp44_;
		ClutterActor* _tmp45_;
		ClutterClickAction* click = NULL;
		ClutterClickAction* _tmp46_;
		ClutterActor* _tmp47_;
		ClutterClickAction* _tmp48_;
		GtkWidget* _tmp49_;
		BoxesApp* _tmp58_;
		BoxesProperties* _tmp59_;
		GtkWidget* _tmp60_;
		gulong _tmp61_ = 0UL;
		gboolean _tmp62_;
		BoxesActorFunc _tmp64_;
		void* _tmp64__target;
		ClutterActor* _tmp65_;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_ = g_slice_new0 (Block40Data);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->_ref_count_ = 1;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->self = g_object_ref (self);
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = display_widget;
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp10_ != NULL) {
#line 5777 "machine.c"
			GtkWidget* _tmp11_;
			GtkClutterActor* _tmp12_;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = display_widget;
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents (_tmp11_);
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_object_ref_sink (_tmp12_);
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (self->priv->thumbnail);
#line 662 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			self->priv->thumbnail = (ClutterActor*) _tmp12_;
#line 5790 "machine.c"
		} else {
			GtkClutterTexture* _tmp13_;
			GtkClutterTexture* _tmp14_;
			GdkPixbuf* pixbuf = NULL;
			BoxesUIState _tmp15_;
			BoxesUIState _tmp16_;
			GtkClutterTexture* _tmp38_;
			ClutterActor* _tmp39_;
#line 664 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = (GtkClutterTexture*) gtk_clutter_texture_new ();
#line 664 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_object_ref_sink (_tmp13_);
#line 664 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (self->priv->thumbnail_screenshot);
#line 664 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			self->priv->thumbnail_screenshot = _tmp13_;
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp14_ = self->priv->thumbnail_screenshot;
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_reactive ((ClutterActor*) _tmp14_, TRUE);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			pixbuf = NULL;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp15_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = _tmp15_;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp16_ == BOXES_UI_STATE_WIZARD) {
#line 5819 "machine.c"
				GtkIconTheme* theme = NULL;
				BoxesApp* _tmp17_;
				GtkApplicationWindow* _tmp18_;
				GdkScreen* _tmp19_ = NULL;
				GtkIconTheme* _tmp20_ = NULL;
				GtkIconTheme* _tmp21_;
				GdkPixbuf* _tmp22_;
				GdkPixbuf* _tmp23_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp17_ = boxes_app_app;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp18_ = _tmp17_->window;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp19_ = gtk_window_get_screen ((GtkWindow*) _tmp18_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp20_ = gtk_icon_theme_get_for_screen (_tmp19_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp21_ = _g_object_ref0 (_tmp20_);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				theme = _tmp21_;
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp22_ = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (pixbuf);
#line 670 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				pixbuf = _tmp22_;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp23_ = pixbuf;
#line 672 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				gdk_pixbuf_fill (_tmp23_, (guint32) 0x00000000);
#line 5850 "machine.c"
				{
					GdkPixbuf* icon = NULL;
					GtkIconTheme* _tmp24_;
					GdkPixbuf* _tmp25_ = NULL;
					GdkPixbuf* _tmp26_;
					GdkPixbuf* _tmp27_;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp24_ = theme;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp25_ = gtk_icon_theme_load_icon (_tmp24_, "media-optical", BOXES_MACHINE_SCREENSHOT_HEIGHT, 0, &_inner_error_);
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					icon = _tmp25_;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					if (_inner_error_ != NULL) {
#line 5865 "machine.c"
						goto __catch50_g_error;
					}
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp26_ = icon;
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp27_ = pixbuf;
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					gdk_pixbuf_copy_area (_tmp26_, 0, 0, BOXES_MACHINE_SCREENSHOT_HEIGHT, BOXES_MACHINE_SCREENSHOT_HEIGHT, _tmp27_, (BOXES_MACHINE_SCREENSHOT_WIDTH - BOXES_MACHINE_SCREENSHOT_HEIGHT) / 2, 0);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_g_object_unref0 (icon);
#line 5876 "machine.c"
				}
				goto __finally50;
				__catch50_g_error:
				{
					GError* err = NULL;
					GError* _tmp28_;
					const gchar* _tmp29_;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					err = _inner_error_;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_inner_error_ = NULL;
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp28_ = err;
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp29_ = _tmp28_->message;
#line 679 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_warning ("machine.vala:679: %s", _tmp29_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_g_error_free0 (err);
#line 5896 "machine.c"
				}
				__finally50:
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				if (_inner_error_ != NULL) {
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_g_object_unref0 (theme);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_g_object_unref0 (pixbuf);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					block40_data_unref (_data40_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_data40_ = NULL;
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_clear_error (&_inner_error_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					return;
#line 5915 "machine.c"
				}
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (theme);
#line 5919 "machine.c"
			} else {
				BoxesMachine* _tmp30_;
				GdkPixbuf* _tmp31_;
				GdkPixbuf* _tmp32_;
				GdkPixbuf* _tmp33_;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp30_ = self->priv->machine;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp31_ = boxes_machine_get_pixbuf (_tmp30_);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp32_ = _tmp31_;
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp33_ = _g_object_ref0 (_tmp32_);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (pixbuf);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				pixbuf = _tmp33_;
#line 5937 "machine.c"
			}
			{
				GtkClutterTexture* _tmp34_;
				GdkPixbuf* _tmp35_;
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp34_ = self->priv->thumbnail_screenshot;
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp35_ = pixbuf;
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				gtk_clutter_texture_set_from_pixbuf (_tmp34_, _tmp35_, &_inner_error_);
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				if (_inner_error_ != NULL) {
#line 5950 "machine.c"
					goto __catch51_g_error;
				}
			}
			goto __finally51;
			__catch51_g_error:
			{
				GError* err = NULL;
				GError* _tmp36_;
				const gchar* _tmp37_;
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				err = _inner_error_;
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_inner_error_ = NULL;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp36_ = err;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp37_ = _tmp36_->message;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_warning ("machine.vala:687: %s", _tmp37_);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_error_free0 (err);
#line 5972 "machine.c"
			}
			__finally51:
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_inner_error_ != NULL) {
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (pixbuf);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				block40_data_unref (_data40_);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data40_ = NULL;
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_clear_error (&_inner_error_);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				return;
#line 5989 "machine.c"
			}
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp38_ = self->priv->thumbnail_screenshot;
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp39_ = _g_object_ref0 ((ClutterActor*) _tmp38_);
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (self->priv->thumbnail);
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			self->priv->thumbnail = _tmp39_;
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 6001 "machine.c"
		}
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp40_ = self->priv->thumbnail;
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_set_name (_tmp40_, "properties-thumbnail");
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp41_ = self->priv->thumbnail;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_set_x_align (_tmp41_, CLUTTER_ACTOR_ALIGN_FILL);
#line 693 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp42_ = self->priv->thumbnail;
#line 693 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_set_y_align (_tmp42_, CLUTTER_ACTOR_ALIGN_FILL);
#line 694 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp43_ = boxes_app_app;
#line 694 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp44_ = _tmp43_->overlay_bin_actor;
#line 694 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp45_ = self->priv->thumbnail;
#line 694 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_add_child (_tmp44_, _tmp45_);
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp46_ = (ClutterClickAction*) clutter_click_action_new ();
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_ref_sink (_tmp46_);
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		click = _tmp46_;
#line 697 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp47_ = self->priv->thumbnail;
#line 697 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp48_ = click;
#line 697 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		clutter_actor_add_action (_tmp47_, (ClutterAction*) _tmp48_);
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp49_ = display_widget;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp49_ != NULL) {
#line 6039 "machine.c"
			ClutterClickAction* _tmp50_;
			BoxesMachine* _tmp51_;
			BoxesDisplay* _tmp52_;
			BoxesDisplay* _tmp53_;
			GtkWidget* _tmp54_;
#line 700 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp50_ = click;
#line 700 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			g_signal_connect_object (_tmp50_, "clicked", (GCallback) _____lambda155__clutter_click_action_clicked, self, 0);
#line 704 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp51_ = self->priv->machine;
#line 704 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp52_ = boxes_machine_get_display (_tmp51_);
#line 704 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp53_ = _tmp52_;
#line 704 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp54_ = display_widget;
#line 704 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_set_enable_inputs (_tmp53_, _tmp54_, FALSE);
#line 6059 "machine.c"
		} else {
			BoxesUIState _tmp55_;
			BoxesUIState _tmp56_;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp55_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp56_ = _tmp55_;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp56_ != BOXES_UI_STATE_WIZARD) {
#line 6069 "machine.c"
				ClutterClickAction* _tmp57_;
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp57_ = click;
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_signal_connect_object (_tmp57_, "clicked", (GCallback) ______lambda156__clutter_click_action_clicked, self, 0);
#line 6075 "machine.c"
			}
		}
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc = ____lambda157__boxes_actor_func;
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc_target = g_object_ref (self);
#line 712 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_->update_screenshot_alloc_target_destroy_notify = g_object_unref;
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp58_ = boxes_app_app;
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp59_ = _tmp58_->properties;
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp60_ = _tmp59_->screenshot_placeholder;
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp61_ = g_signal_connect_data (_tmp60_, "size-allocate", (GCallback) ____lambda158__gtk_widget_size_allocate, block40_data_ref (_data40_), (GClosureNotify) block40_data_unref, 0);
#line 734 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->track_screenshot_id = _tmp61_;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp62_ = zoom;
#line 743 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		if (!_tmp62_) {
#line 6098 "machine.c"
			ClutterActor* _tmp63_;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp63_ = self->priv->thumbnail;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_easing_duration (_tmp63_, (guint) 0);
#line 6104 "machine.c"
		}
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp64_ = _data40_->update_screenshot_alloc;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp64__target = _data40_->update_screenshot_alloc_target;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp65_ = self->priv->thumbnail;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp64_ (_tmp65_, _tmp64__target);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (click);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		block40_data_unref (_data40_);
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_data40_ = NULL;
#line 6120 "machine.c"
	}
}


static void _____lambda166_ (BoxesMachineActor* self) {
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_;
#line 794 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_actor_steal_display_widget_from_thumbnail (self);
#line 794 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	widget = _tmp0_;
#line 795 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = widget;
#line 795 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_ != NULL) {
#line 6137 "machine.c"
		BoxesApp* _tmp2_;
		BoxesDisplayPage* _tmp3_;
		BoxesMachine* _tmp4_;
		BoxesDisplay* _tmp5_;
		BoxesDisplay* _tmp6_;
		GtkWidget* _tmp7_;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_app;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->display_page;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->machine;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_machine_get_display (_tmp4_);
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = widget;
#line 796 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_page_show_display (_tmp3_, _tmp6_, _tmp7_);
#line 6158 "machine.c"
	}
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (widget);
#line 6162 "machine.c"
}


static void ______lambda166__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self) {
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_____lambda166_ (self);
#line 6169 "machine.c"
}


static Block41Data* block41_data_ref (Block41Data* _data41_) {
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data41_->_ref_count_);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return _data41_;
#line 6178 "machine.c"
}


static void block41_data_unref (void * _userdata_) {
	Block41Data* _data41_;
	_data41_ = (Block41Data*) _userdata_;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data41_->_ref_count_)) {
#line 6187 "machine.c"
		BoxesMachineActor * self;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		self = _data41_->self;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_slice_free (Block41Data, _data41_);
#line 6195 "machine.c"
	}
}


static void ____lambda167_ (Block41Data* _data41_) {
	BoxesMachineActor * self;
	ClutterActor* _tmp0_;
	gulong _tmp1_;
	ClutterActor* _tmp2_;
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = _data41_->self;
#line 825 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->thumbnail;
#line 825 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _data41_->completed_id;
#line 825 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 826 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = self->priv->thumbnail;
#line 826 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	clutter_actor_set_easing_duration (_tmp2_, (guint) 0);
#line 6217 "machine.c"
}


static void _____lambda167__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self) {
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	____lambda167_ (self);
#line 6224 "machine.c"
}


static void boxes_machine_actor_real_ui_state_changed (BoxesUI* base) {
	BoxesMachineActor * self;
	gint window_width = 0;
	gint window_height = 0;
	gint width = 0;
	gint height = 0;
	gint x = 0;
	gint y = 0;
	BoxesApp* _tmp0_;
	BoxesDisplayPage* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	BoxesApp* _tmp4_;
	GtkApplicationWindow* _tmp5_;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	gint _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	BoxesUIState _tmp12_;
	BoxesUIState _tmp13_;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) base;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->display_page;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_display_page_get_size (_tmp1_, &_tmp2_, &_tmp3_);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	width = _tmp2_;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	height = _tmp3_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_app_app;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_->window;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	gtk_window_get_size ((GtkWindow*) _tmp5_, &_tmp6_, &_tmp7_);
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	window_width = _tmp6_;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	window_height = _tmp7_;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = window_width;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = width;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	x = _tmp8_ - _tmp9_;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = window_height;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = height;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	y = _tmp10_ - _tmp11_;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_tmp13_) {
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_CREDS:
#line 6292 "machine.c"
		{
			ClutterActor* _tmp14_;
			ClutterActor* _tmp15_;
			ClutterActor* _tmp16_;
			ClutterActor* _tmp17_;
			ClutterActor* _tmp18_;
			ClutterActor* _tmp19_;
			ClutterActor* _tmp20_;
			ClutterActor* _tmp21_;
			GtkClutterActor* _tmp22_;
#line 761 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp14_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 761 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp15_ = _tmp14_;
#line 761 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_x_align (_tmp15_, CLUTTER_ACTOR_ALIGN_CENTER);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp17_ = _tmp16_;
#line 762 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_y_align (_tmp17_, CLUTTER_ACTOR_ALIGN_CENTER);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp18_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp19_ = _tmp18_;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_x_expand (_tmp19_, TRUE);
#line 764 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp20_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 764 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp21_ = _tmp20_;
#line 764 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_y_expand (_tmp21_, TRUE);
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp22_ = self->priv->gtk_vbox;
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_show ((ClutterActor*) _tmp22_);
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 6333 "machine.c"
		}
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 6337 "machine.c"
		{
			GtkClutterActor* _tmp23_;
			BoxesUIState _tmp24_;
			BoxesUIState _tmp25_;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp23_ = self->priv->gtk_vbox;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_hide ((ClutterActor*) _tmp23_);
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp24_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp25_ = _tmp24_;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp25_ == BOXES_UI_STATE_CREDS) {
#line 6352 "machine.c"
				ClutterActor* _tmp26_;
				ClutterActor* _tmp27_;
				ClutterActor* _tmp28_;
				ClutterActor* _tmp29_;
				ClutterActor* _tmp30_;
				ClutterActor* _tmp31_;
				ClutterActor* _tmp32_;
				ClutterActor* _tmp33_;
				ClutterActor* _tmp34_;
				ClutterActor* _tmp35_;
				ClutterActor* _tmp36_;
				ClutterActor* _tmp37_;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp26_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp27_ = _tmp26_;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_x_align (_tmp27_, CLUTTER_ACTOR_ALIGN_FILL);
#line 772 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp28_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 772 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp29_ = _tmp28_;
#line 772 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_y_align (_tmp29_, CLUTTER_ACTOR_ALIGN_FILL);
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp30_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp31_ = _tmp30_;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_x_expand (_tmp31_, TRUE);
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp32_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp33_ = _tmp32_;
#line 774 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_y_expand (_tmp33_, TRUE);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp34_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp35_ = _tmp34_;
#line 775 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_object_set (_tmp35_, "natural-width-set", FALSE, NULL);
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp36_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp37_ = _tmp36_;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				g_object_set (_tmp37_, "natural-height-set", FALSE, NULL);
#line 6401 "machine.c"
			} else {
				ClutterActor* _tmp38_;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp38_ = self->priv->thumbnail;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				if (_tmp38_ != NULL) {
#line 6408 "machine.c"
					BoxesApp* _tmp39_;
					BoxesProperties* _tmp40_;
					GtkWidget* _tmp41_;
					gulong _tmp42_;
					ClutterActor* _tmp43_;
					BoxesApp* _tmp44_;
					guint _tmp45_;
					ClutterActor* _tmp46_;
					ClutterActor* _tmp47_;
					ClutterActor* _tmp48_;
					ClutterActor* _tmp49_;
					ClutterActor* _tmp50_;
					ClutterActor* _tmp51_;
					ClutterActor* _tmp52_;
					ClutterActor* _tmp53_;
					ClutterActor* _tmp54_;
					ClutterActor* _tmp55_;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp39_ = boxes_app_app;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp40_ = _tmp39_->properties;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp41_ = _tmp40_->screenshot_placeholder;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp42_ = self->priv->track_screenshot_id;
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_signal_handler_disconnect ((GObject*) _tmp41_, _tmp42_);
#line 782 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					self->priv->track_screenshot_id = (gulong) 0;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp43_ = self->priv->thumbnail;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp44_ = boxes_app_app;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp45_ = _tmp44_->duration;
#line 784 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_easing_duration (_tmp43_, _tmp45_);
#line 785 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp46_ = self->priv->thumbnail;
#line 785 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_x_align (_tmp46_, CLUTTER_ACTOR_ALIGN_FILL);
#line 786 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp47_ = self->priv->thumbnail;
#line 786 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_y_align (_tmp47_, CLUTTER_ACTOR_ALIGN_FILL);
#line 787 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp48_ = self->priv->thumbnail;
#line 787 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_x_expand (_tmp48_, TRUE);
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp49_ = self->priv->thumbnail;
#line 788 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_y_expand (_tmp49_, TRUE);
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp50_ = self->priv->thumbnail;
#line 789 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					clutter_actor_set_fixed_position_set (_tmp50_, FALSE);
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp51_ = self->priv->thumbnail;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp52_ = self->priv->thumbnail;
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_object_set (_tmp52_, "natural-width-set", FALSE, NULL);
#line 790 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_object_set (_tmp51_, "min-width-set", FALSE, NULL);
#line 791 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp53_ = self->priv->thumbnail;
#line 791 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp54_ = self->priv->thumbnail;
#line 791 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_object_set (_tmp54_, "natural-height-set", FALSE, NULL);
#line 791 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_object_set (_tmp53_, "min-height-set", FALSE, NULL);
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp55_ = self->priv->thumbnail;
#line 793 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					g_signal_connect_object (_tmp55_, "transitions-completed", (GCallback) ______lambda166__clutter_actor_transitions_completed, self, 0);
#line 6486 "machine.c"
				} else {
					BoxesApp* _tmp56_;
					BoxesDisplayPage* _tmp57_;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp56_ = boxes_app_app;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp57_ = _tmp56_->display_page;
#line 799 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
					boxes_display_page_show (_tmp57_);
#line 6496 "machine.c"
				}
			}
#line 801 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 6501 "machine.c"
		}
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 6505 "machine.c"
		{
			ClutterActor* _tmp58_;
			ClutterActor* _tmp59_;
			ClutterActor* _tmp60_;
			ClutterActor* _tmp61_;
			GtkEntry* _tmp62_;
			GtkEntry* _tmp63_;
			GtkLabel* _tmp64_;
#line 804 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp58_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 804 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp59_ = _tmp58_;
#line 804 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_x_expand (_tmp59_, FALSE);
#line 805 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp60_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 805 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp61_ = _tmp60_;
#line 805 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_set_y_expand (_tmp61_, FALSE);
#line 806 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp62_ = self->priv->password_entry;
#line 806 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_widget_set_can_focus ((GtkWidget*) _tmp62_, FALSE);
#line 807 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp63_ = self->priv->password_entry;
#line 807 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_widget_hide ((GtkWidget*) _tmp63_);
#line 808 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp64_ = self->priv->label;
#line 808 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_widget_show ((GtkWidget*) _tmp64_);
#line 809 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 6540 "machine.c"
		}
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 6544 "machine.c"
		{
			GtkWidget* display_widget = NULL;
			BoxesApp* _tmp65_;
			BoxesDisplayPage* _tmp66_;
			GtkWidget* _tmp67_ = NULL;
			gboolean zoom = FALSE;
			GtkWidget* _tmp68_;
			GtkWidget* _tmp69_;
			gboolean _tmp70_;
			gboolean _tmp71_;
			ClutterActor* _tmp81_;
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp65_ = boxes_app_app;
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp66_ = _tmp65_->display_page;
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp67_ = boxes_display_page_remove_display (_tmp66_);
#line 812 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			display_widget = _tmp67_;
#line 813 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp68_ = display_widget;
#line 813 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			zoom = _tmp68_ != NULL;
#line 815 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp69_ = display_widget;
#line 815 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp70_ = zoom;
#line 815 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_actor_update_thumbnail (self, _tmp69_, _tmp70_);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp71_ = zoom;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp71_) {
#line 6578 "machine.c"
				Block41Data* _data41_;
				ClutterActor* _tmp72_;
				gint _tmp73_;
				gint _tmp74_;
				ClutterActor* _tmp75_;
				ClutterActor* _tmp76_;
				BoxesApp* _tmp77_;
				guint _tmp78_;
				ClutterActor* _tmp79_;
				gulong _tmp80_ = 0UL;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_ = g_slice_new0 (Block41Data);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_->_ref_count_ = 1;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_->self = g_object_ref (self);
#line 819 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp72_ = self->priv->thumbnail;
#line 819 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp73_ = width;
#line 819 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp74_ = height;
#line 819 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				boxes_allocate_actor_no_animation (_tmp72_, (gfloat) 0, (gfloat) 0, (gfloat) _tmp73_, (gfloat) _tmp74_);
#line 821 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp75_ = self->priv->thumbnail;
#line 821 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_easing_mode (_tmp75_, CLUTTER_LINEAR);
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp76_ = self->priv->thumbnail;
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp77_ = boxes_app_app;
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp78_ = _tmp77_->duration;
#line 822 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				clutter_actor_set_easing_duration (_tmp76_, _tmp78_);
#line 823 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_->completed_id = (gulong) 0;
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp79_ = self->priv->thumbnail;
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp80_ = g_signal_connect_data (_tmp79_, "transitions-completed", (GCallback) _____lambda167__clutter_actor_transitions_completed, block41_data_ref (_data41_), (GClosureNotify) block41_data_unref, 0);
#line 824 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_->completed_id = _tmp80_;
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				block41_data_unref (_data41_);
#line 818 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
				_data41_ = NULL;
#line 6627 "machine.c"
			}
#line 830 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp81_ = self->priv->thumbnail;
#line 830 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			clutter_actor_show (_tmp81_);
#line 832 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (display_widget);
#line 832 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 6637 "machine.c"
		}
		default:
		{
#line 835 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 6643 "machine.c"
		}
	}
}


static ClutterActor* boxes_machine_actor_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesMachineActor* self;
	ClutterActor* _tmp0_;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) base;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->_actor;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 6661 "machine.c"
}


static void boxes_machine_actor_class_init (BoxesMachineActorClass * klass) {
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_actor_parent_class = g_type_class_peek_parent (klass);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachineActorPrivate));
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_machine_actor_real_ui_state_changed;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_machine_actor_real_get_actor;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_actor_get_property;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_actor_finalize;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_ACTOR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6680 "machine.c"
}


static void boxes_machine_actor_instance_init (BoxesMachineActor * self) {
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv = BOXES_MACHINE_ACTOR_GET_PRIVATE (self);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->track_screenshot_id = (gulong) 0;
#line 6689 "machine.c"
}


static void boxes_machine_actor_finalize (GObject* obj) {
	BoxesMachineActor * self;
	gulong _tmp0_;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->track_screenshot_id;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 6702 "machine.c"
		BoxesApp* _tmp1_;
		BoxesProperties* _tmp2_;
		GtkWidget* _tmp3_;
		gulong _tmp4_;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp1_->properties;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->screenshot_placeholder;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->track_screenshot_id;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 6717 "machine.c"
	}
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->_actor);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->screenshot);
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->gtk_vbox);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->thumbnail);
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->thumbnail_screenshot);
#line 537 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->label);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->vbox);
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 540 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (boxes_machine_actor_parent_class)->finalize (obj);
#line 6739 "machine.c"
}


GType boxes_machine_actor_get_type (void) {
	static volatile gsize boxes_machine_actor_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_actor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineActorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_actor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachineActor), 0, (GInstanceInitFunc) boxes_machine_actor_instance_init, NULL };
		GType boxes_machine_actor_type_id;
		boxes_machine_actor_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesMachineActor", &g_define_type_info, 0);
		g_once_init_leave (&boxes_machine_actor_type_id__volatile, boxes_machine_actor_type_id);
	}
	return boxes_machine_actor_type_id__volatile;
}


static void _vala_boxes_machine_actor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachineActor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_ACTOR_ACTOR:
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6766 "machine.c"
		default:
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6772 "machine.c"
	}
}



