/* wizard.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from wizard.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libxml/uri.h>
#include <libgd/gd.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <pango/pango.h>


#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;
typedef struct _BoxesWizardPrivate BoxesWizardPrivate;

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;

#define BOXES_WIZARD_TYPE_WIZARD_SUMMARY (boxes_wizard_wizard_summary_get_type ())
#define BOXES_WIZARD_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary))
#define BOXES_WIZARD_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryClass))
#define BOXES_WIZARD_IS_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_IS_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_WIZARD_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_WIZARD_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryClass))

typedef struct _BoxesWizardWizardSummary BoxesWizardWizardSummary;
typedef struct _BoxesWizardWizardSummaryClass BoxesWizardWizardSummaryClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;
typedef struct _Block74Data Block74Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesWizardCreateData BoxesWizardCreateData;
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _Block75Data Block75Data;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesWizardPrepareMediaData BoxesWizardPrepareMediaData;
typedef struct _BoxesWizardReviewData BoxesWizardReviewData;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _Block76Data Block76Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesWizardDoReviewCancellableData BoxesWizardDoReviewCancellableData;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesWizardWizardSummaryPrivate BoxesWizardWizardSummaryPrivate;
typedef struct _Block77Data Block77Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesWizard {
	BoxesUI parent_instance;
	BoxesWizardPrivate * priv;
};

struct _BoxesWizardClass {
	BoxesUIClass parent_class;
};

struct _BoxesWizardPrivate {
	GtkClutterActor* gtk_actor;
	GPtrArray* steps;
	GtkNotebook* notebook;
	GtkButton* cancel_button;
	GtkButton* back_button;
	GtkButton* next_button;
	GtkButton* continue_button;
	GtkButton* create_button;
	GtkSizeGroup* toolbar_sizegroup;
	BoxesWizardSource* wizard_source;
	BoxesWizardWizardSummary* summary;
	BoxesCollectionSource* source;
	GtkProgressBar* prep_progress;
	GtkLabel* prep_media_label;
	GtkLabel* prep_status_label;
	GtkBox* setup_vbox;
	GtkLabel* review_label;
	GtkLabel* nokvm_label;
	GtkImage* installer_image;
	BoxesMediaManager* media_manager;
	BoxesVMCreator* vm_creator;
	BoxesMachine* _machine;
	BoxesWizardPage _page;
	GCancellable* review_cancellable;
	gboolean skip_review_for_live;
};

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

struct _BoxesWizardSource {
	GObject parent_instance;
	BoxesWizardSourcePrivate * priv;
	GtkEntry* url_entry;
};

struct _BoxesWizardSourceClass {
	GObjectClass parent_class;
};

struct _Block74Data {
	int _ref_count_;
	BoxesWizard * self;
	gpointer _async_data_;
};

struct _BoxesWizardCreateData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	Block74Data* _data74_;
	BoxesCollectionSource* _tmp0_;
	BoxesVMCreator* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	GCancellable* _tmp4_;
	gulong wait;
	gulong _tmp5_;
	gulong _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	GtkButton* _tmp9_;
	BoxesVMCreator* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	GError* _error_;
	GError* _tmp13_;
	const gchar* _tmp14_;
	BoxesVMCreator* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesInstallerMedia* _tmp17_;
	BoxesWizardSource* _tmp18_;
	BoxesCollectionSource* _tmp19_;
	BoxesApp* _tmp20_;
	BoxesCollectionSource* _tmp21_;
	GError * _inner_error_;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block75Data {
	int _ref_count_;
	BoxesWizard * self;
	BoxesActivityProgress* progress;
	gpointer _async_data_;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
};

struct _BoxesWizardPrepareMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	BoxesInstallerMedia* install_media;
	Block75Data* _data75_;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	GtkLabel* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	OsinfoOs* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GtkImage* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	BoxesActivityProgress* _tmp10_;
	GtkLabel* _tmp11_;
	BoxesInstallerMedia* _tmp12_;
	BoxesInstallerMedia* _tmp13_;
	BoxesVMCreator* _tmp14_;
	GtkProgressBar* _tmp15_;
};

struct _BoxesWizardReviewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	gboolean _result_;
	gboolean _tmp2_;
};

struct _Block76Data {
	int _ref_count_;
	BoxesWizard * self;
	GVirConfigDomain* config;
};

typedef void (*BoxesWizardWizardSummaryCustomizeFunc) (void* user_data);
struct _BoxesWizardDoReviewCancellableData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GtkLabel* _tmp1_;
	BoxesWizardWizardSummary* _tmp2_;
	BoxesCollectionSource* _tmp3_;
	BoxesRemoteMachine* _tmp4_;
	BoxesCollectionSource* _tmp5_;
	BoxesRemoteMachine* _tmp6_;
	BoxesRemoteMachine* _tmp7_;
	GError* _error_;
	GError* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_;
	BoxesVMCreator* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	gboolean _tmp14_;
	BoxesLibvirtMachine* _tmp15_;
	BoxesVMCreator* _tmp16_;
	GCancellable* _tmp17_;
	BoxesLibvirtMachine* _tmp18_;
	BoxesLibvirtMachine* _tmp19_;
	GError* cancel_error;
	GError* _vala1__error_;
	BoxesApp* _tmp20_;
	BoxesNotificationbar* _tmp21_;
	const gchar* _tmp22_;
	GdNotification* _tmp23_;
	GdNotification* _tmp24_;
	GError* _tmp25_;
	const gchar* _tmp26_;
	BoxesLibvirtMachine* _tmp27_;
	BoxesLibvirtMachine* _tmp28_;
	GCancellable* _tmp29_;
	gboolean _tmp30_;
	GtkLabel* _tmp31_;
	const gchar* _tmp32_;
	BoxesCollectionSource* _tmp33_;
	xmlURI* uri;
	BoxesCollectionSource* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	xmlURI* _tmp38_;
	xmlURI* _tmp39_;
	BoxesWizardWizardSummary* _tmp40_;
	const gchar* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gboolean _tmp46_;
	xmlURI* _tmp47_;
	xmlURI* _tmp48_;
	const gchar* _tmp49_;
	gboolean _tmp50_;
	BoxesWizardWizardSummary* _tmp51_;
	const gchar* _tmp52_;
	xmlURI* _tmp53_;
	const gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	BoxesWizardWizardSummary* _tmp57_;
	const gchar* _tmp58_;
	BoxesCollectionSource* _tmp59_;
	gchar* _tmp60_;
	gchar* _tmp61_;
	gchar* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	xmlURI* _tmp65_;
	const gchar* _tmp66_;
	const gchar* _tmp67_;
	GQuark _tmp69_;
	gint port;
	gint tls_port;
	BoxesCollectionSource* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	gint* _tmp74_;
	gint* _tmp75_;
	gint* _tmp76_;
	gint* _tmp77_;
	gint _tmp78_;
	BoxesWizardWizardSummary* _tmp79_;
	const gchar* _tmp80_;
	gint _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gint _tmp84_;
	BoxesWizardWizardSummary* _tmp85_;
	const gchar* _tmp86_;
	gint _tmp87_;
	gchar* _tmp88_;
	gchar* _tmp89_;
	GError* _vala2__error_;
	GError* _tmp90_;
	const gchar* _tmp91_;
	xmlURI* _tmp92_;
	gint _tmp93_;
	BoxesWizardWizardSummary* _tmp94_;
	const gchar* _tmp95_;
	xmlURI* _tmp96_;
	gint _tmp97_;
	gchar* _tmp98_;
	gchar* _tmp99_;
	BoxesApp* _tmp100_;
	BoxesCollectionSource* _tmp101_;
	gchar* _tmp102_;
	gchar* _tmp103_;
	gchar* _tmp104_;
	gboolean _tmp105_;
	gboolean _tmp106_;
	GtkLabel* _tmp107_;
	const gchar* _tmp108_;
	BoxesLibvirtMachine* _tmp109_;
	BoxesLibvirtMachine* _tmp110_;
	BoxesVMCreator* _tmp111_;
	BoxesInstallerMedia* _tmp112_;
	BoxesInstallerMedia* _tmp113_;
	GList* _tmp114_;
	GList* property_collection;
	GList* property_it;
	BoxesPair* _tmp115_;
	BoxesPair* property;
	BoxesWizardWizardSummary* _tmp116_;
	BoxesPair* _tmp117_;
	gconstpointer _tmp118_;
	BoxesPair* _tmp119_;
	gconstpointer _tmp120_;
	Block76Data* _data76_;
	gpointer _tmp121_;
	GVirConfigDomain* _tmp122_;
	gchar* memory;
	GVirConfigDomain* _tmp123_;
	guint64 _tmp124_;
	guint64 _tmp125_;
	gchar* _tmp126_;
	BoxesWizardWizardSummary* _tmp127_;
	const gchar* _tmp128_;
	const gchar* _tmp129_;
	GError* _vala3__error_;
	BoxesLibvirtMachine* _tmp130_;
	BoxesLibvirtMachine* _tmp131_;
	const gchar* _tmp132_;
	const gchar* _tmp133_;
	GError* _tmp134_;
	const gchar* _tmp135_;
	BoxesLibvirtMachine* _tmp136_;
	BoxesLibvirtMachine* _tmp137_;
	GVirStorageVol* _tmp138_;
	GVirStorageVol* _tmp139_;
	GVirStorageVolInfo* volume_info;
	BoxesLibvirtMachine* _tmp140_;
	BoxesLibvirtMachine* _tmp141_;
	GVirStorageVol* _tmp142_;
	GVirStorageVol* _tmp143_;
	GVirStorageVolInfo* _tmp144_;
	gchar* capacity;
	GVirStorageVolInfo* _tmp145_;
	guint64 _tmp146_;
	gchar* _tmp147_;
	BoxesWizardWizardSummary* _tmp148_;
	const gchar* _tmp149_;
	const gchar* _tmp150_;
	gchar* _tmp151_;
	gchar* _tmp152_;
	const gchar* _tmp153_;
	GError* _vala4__error_;
	BoxesLibvirtMachine* _tmp154_;
	BoxesLibvirtMachine* _tmp155_;
	GVirStorageVol* _tmp156_;
	GVirStorageVol* _tmp157_;
	const gchar* _tmp158_;
	GError* _tmp159_;
	const gchar* _tmp160_;
	GtkLabel* _tmp161_;
	BoxesLibvirtMachine* _tmp162_;
	BoxesLibvirtMachine* _tmp163_;
	GVirConfigDomain* _tmp164_;
	GVirConfigDomain* _tmp165_;
	GVirConfigDomainVirtType _tmp166_;
	BoxesWizardWizardSummary* _tmp167_;
	GError * _inner_error_;
};

struct _BoxesSidebar {
	BoxesUI parent_instance;
	BoxesSidebarPrivate * priv;
	GtkNotebook* notebook;
};

struct _BoxesSidebarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkNotebook* notebook;
	gchar* _status;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES
} BoxesTopbarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesWizardWizardSummary {
	GObject parent_instance;
	BoxesWizardWizardSummaryPrivate * priv;
};

struct _BoxesWizardWizardSummaryClass {
	GObjectClass parent_class;
};

struct _BoxesWizardWizardSummaryPrivate {
	GtkGrid* grid;
	gint current_row;
};

struct _Block77Data {
	int _ref_count_;
	BoxesWizardWizardSummary * self;
	BoxesWizardWizardSummaryCustomizeFunc customize_func;
	gpointer customize_func_target;
};


static gpointer boxes_wizard_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_wizard_wizard_summary_parent_class = NULL;

GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
static GType boxes_wizard_wizard_summary_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD, BoxesWizardPrivate))
enum  {
	BOXES_WIZARD_DUMMY_PROPERTY,
	BOXES_WIZARD_ACTOR,
	BOXES_WIZARD_MACHINE
};
static void boxes_wizard_wizard_source_update_next (BoxesWizard* self);
GType boxes_source_page_get_type (void) G_GNUC_CONST;
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
BoxesWizardSource* boxes_wizard_source_new (BoxesMediaManager* media_manager);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type, BoxesMediaManager* media_manager);
static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void __lambda195_ (BoxesWizard* self);
static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value);
static void ___lambda195__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_wizard_setup_ui (BoxesWizard* self);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_wizard_destroy_machine (BoxesWizard* self);
static void boxes_wizard_create_data_free (gpointer _data);
static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self);
static void ____lambda193_ (Block74Data* _data74_);
static void _____lambda193__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value);
static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error);
static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_);
static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_wizard_prepare_media_data_free (gpointer _data);
static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_);
static Block75Data* block75_data_ref (Block75Data* _data75_);
static void block75_data_unref (void * _userdata_);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static void __lambda186_ (Block75Data* _data75_);
static void ___lambda186__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
static gboolean boxes_wizard_prepare (BoxesWizard* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static gboolean boxes_wizard_setup (BoxesWizard* self);
void boxes_installer_media_populate_setup_vbox (BoxesInstallerMedia* self, GtkBox* setup_vbox);
static void __lambda187_ (BoxesWizard* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
static void ___lambda187__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self);
static void boxes_wizard_review_data_free (gpointer _data);
static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_);
static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_);
static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_do_review_cancellable_data_free (gpointer _data);
static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_);
static void boxes_wizard_wizard_summary_clear (BoxesWizardWizardSummary* self);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_wizard_summary_add_property (BoxesWizardWizardSummary* self, const gchar* name, const gchar* value);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static Block76Data* block76_data_ref (Block76Data* _data76_);
static void block76_data_unref (void * _userdata_);
static void _____lambda190_ (Block76Data* _data76_, GError** error);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ______lambda190__boxes_run_in_thread_func (gpointer self, GError** error);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_wizard_wizard_summary_append_customize_button (BoxesWizardWizardSummary* self, BoxesWizardWizardSummaryCustomizeFunc customize_func, void* customize_func_target);
static void __lambda191_ (BoxesWizard* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self);
static void ___lambda191__boxes_wizard_wizard_summary_customize_func (gpointer self);
static void boxes_wizard_add_step (BoxesWizard* self, GtkWidget* widget, const gchar* title, BoxesWizardPage page);
GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
GtkWidget* boxes_wizard_source_get_widget (BoxesWizardSource* self);
static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_new (void);
static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_construct (GType object_type);
static GtkWidget* boxes_wizard_wizard_summary_get_widget (BoxesWizardWizardSummary* self);
GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
static void __lambda196_ (BoxesWizard* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda196__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda197_ (BoxesWizard* self);
static void ___lambda197__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda198_ (BoxesWizard* self);
static void ___lambda198__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda199_ (BoxesWizard* self);
static void ___lambda199__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
static void boxes_wizard_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
static void _boxes_wizard_page_____lambda192_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda192__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_wizard_page_____lambda194_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda194__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_object_unref0_ (gpointer var);
BoxesMediaManager* boxes_media_manager_get_instance (void);
#define BOXES_WIZARD_WIZARD_SUMMARY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummaryPrivate))
enum  {
	BOXES_WIZARD_WIZARD_SUMMARY_DUMMY_PROPERTY,
	BOXES_WIZARD_WIZARD_SUMMARY_WIDGET
};
static Block77Data* block77_data_ref (Block77Data* _data77_);
static void block77_data_unref (void * _userdata_);
static void __lambda185_ (Block77Data* _data77_);
static void ___lambda185__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_wizard_summary_finalize (GObject* obj);
static void _vala_boxes_wizard_wizard_summary_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void boxes_wizard_finalize (GObject* obj);
static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_wizard_page_get_type (void) {
	static volatile gsize boxes_wizard_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_WIZARD_PAGE_INTRODUCTION, "BOXES_WIZARD_PAGE_INTRODUCTION", "introduction"}, {BOXES_WIZARD_PAGE_SOURCE, "BOXES_WIZARD_PAGE_SOURCE", "source"}, {BOXES_WIZARD_PAGE_PREPARATION, "BOXES_WIZARD_PAGE_PREPARATION", "preparation"}, {BOXES_WIZARD_PAGE_SETUP, "BOXES_WIZARD_PAGE_SETUP", "setup"}, {BOXES_WIZARD_PAGE_REVIEW, "BOXES_WIZARD_PAGE_REVIEW", "review"}, {BOXES_WIZARD_PAGE_LAST, "BOXES_WIZARD_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_wizard_page_type_id;
		boxes_wizard_page_type_id = g_enum_register_static ("BoxesWizardPage", values);
		g_once_init_leave (&boxes_wizard_page_type_id__volatile, boxes_wizard_page_type_id);
	}
	return boxes_wizard_page_type_id__volatile;
}


static void boxes_wizard_wizard_source_update_next (BoxesWizard* self) {
	GtkButton* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesSourcePage _tmp2_;
	BoxesSourcePage _tmp3_;
	GError * _inner_error_ = NULL;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_source_get_page (_tmp1_);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp3_) {
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 1032 "wizard.c"
		{
			GtkButton* _tmp4_;
			BoxesWizardSource* _tmp5_;
			GtkWidget* _tmp6_;
			GtkWidget* _tmp7_;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->next_button;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp5_ = self->priv->wizard_source;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = boxes_wizard_source_get_selected (_tmp5_);
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = _tmp6_;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp4_, _tmp7_ != NULL);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->source);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->source = NULL;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1054 "wizard.c"
		}
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 1058 "wizard.c"
		{
			GtkButton* _tmp8_;
			BoxesWizardSource* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* text = NULL;
			const gchar* _tmp14_ = NULL;
			gchar* _tmp15_;
			gchar* icon = NULL;
			gchar* _tmp16_;
			BoxesWizardSource* _tmp34_;
			const gchar* _tmp35_ = NULL;
			const gchar* _tmp36_;
			const gchar* _tmp37_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->next_button;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = self->priv->wizard_source;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = boxes_wizard_source_get_uri (_tmp9_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = _tmp10_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = strlen (_tmp11_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, _tmp13_ != 0);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = _ ("Please enter desktop or collection URI");
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = g_strdup (_tmp14_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			text = _tmp15_;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = g_strdup ("preferences-desktop-remote-desktop");
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			icon = _tmp16_;
#line 1099 "wizard.c"
			{
				BoxesWizardSource* _tmp17_;
				const gchar* _tmp18_;
				const gchar* _tmp19_;
				gboolean _tmp20_ = FALSE;
				BoxesCollectionSource* _tmp21_;
				gboolean _tmp28_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp17_ = self->priv->wizard_source;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp18_ = boxes_wizard_source_get_uri (_tmp17_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = _tmp18_;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp19_, TRUE, &_inner_error_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_inner_error_ != NULL) {
#line 1117 "wizard.c"
					goto __catch99_g_error;
				}
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = self->priv->source;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp21_ != NULL) {
#line 1124 "wizard.c"
					BoxesApp* _tmp22_;
					BoxesCollectionSource* _tmp23_;
					gchar* _tmp24_;
					gchar* _tmp25_;
					gchar* _tmp26_;
					gboolean _tmp27_ = FALSE;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp22_ = boxes_app_app;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp23_ = self->priv->source;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp24_ = boxes_collection_source_get_source_type (_tmp23_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp25_ = _tmp24_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp26_ = _tmp25_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp27_ = boxes_app_has_broker_for_source_type (_tmp22_, _tmp26_);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp20_ = _tmp27_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp26_);
#line 1147 "wizard.c"
				} else {
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp20_ = FALSE;
#line 1151 "wizard.c"
				}
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = _tmp20_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp28_) {
#line 1157 "wizard.c"
					const gchar* _tmp29_ = NULL;
					gchar* _tmp30_;
					gchar* _tmp31_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp29_ = _ ("Will add boxes for all systems available from this account.");
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp30_ = g_strdup (_tmp29_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp30_;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp31_ = g_strdup ("network-workgroup");
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (icon);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					icon = _tmp31_;
#line 1175 "wizard.c"
				} else {
					const gchar* _tmp32_ = NULL;
					gchar* _tmp33_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp32_ = _ ("Will add a single box.");
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp33_ = g_strdup (_tmp32_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp33_;
#line 1187 "wizard.c"
				}
			}
			goto __finally99;
			__catch99_g_error:
			{
				GError* _error_ = NULL;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 1200 "wizard.c"
			}
			__finally99:
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (icon);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (text);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1215 "wizard.c"
			}
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp34_ = self->priv->wizard_source;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = _ ("Desktop Access");
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = text;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = icon;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_update_url_page (_tmp34_, _tmp35_, _tmp36_, _tmp37_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (icon);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (text);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1233 "wizard.c"
		}
		default:
		{
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warn_if_reached ();
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1241 "wizard.c"
		}
	}
}


static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next (self);
#line 1250 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next (self);
#line 1257 "wizard.c"
}


static void __lambda195_ (BoxesWizard* self) {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 1264 "wizard.c"
}


static void ___lambda195__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda195_ (self);
#line 1271 "wizard.c"
}


BoxesWizard* boxes_wizard_construct (GType object_type) {
	BoxesWizard * self = NULL;
	BoxesMediaManager* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	BoxesWizardSource* _tmp4_;
	GtkEntry* _tmp5_;
	BoxesWizardSource* _tmp6_;
	GtkEntry* _tmp7_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) boxes_ui_construct (object_type);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->media_manager;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_source_new (_tmp0_);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->wizard_source = _tmp1_;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::page", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::selected", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->wizard_source;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_->url_entry;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GtkEditable*) _tmp5_, "changed", (GCallback) _boxes_wizard_wizard_source_update_next_gtk_editable_changed, self, 0);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->wizard_source;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_->url_entry;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp7_, "activate", (GCallback) ___lambda195__gtk_entry_activate, self, 0);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_setup_ui (self);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 1319 "wizard.c"
}


BoxesWizard* boxes_wizard_new (void) {
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_construct (BOXES_TYPE_WIZARD);
#line 1326 "wizard.c"
}


void boxes_wizard_cleanup (BoxesWizard* self) {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 1335 "wizard.c"
}


static void boxes_wizard_create_data_free (gpointer _data) {
	BoxesWizardCreateData* _data_;
	_data_ = _data;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardCreateData, _data_);
#line 1346 "wizard.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? g_object_ref (self) : NULL;
#line 1353 "wizard.c"
}


static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardCreateData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardCreateData);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_create);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_create_data_free);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data_);
#line 1372 "wizard.c"
}


static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardCreateData* _data_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 1385 "wizard.c"
}


static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data74_;
#line 1394 "wizard.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 1403 "wizard.c"
		BoxesWizard * self;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data74_->self;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block74Data, _data74_);
#line 1411 "wizard.c"
	}
}


static void ____lambda193_ (Block74Data* _data74_) {
	BoxesWizard * self;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data74_->self;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data74_->_async_data_);
#line 1422 "wizard.c"
}


static void _____lambda193__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	____lambda193_ (self);
#line 1429 "wizard.c"
}


static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 1438 "wizard.c"
		goto _state_0;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 1442 "wizard.c"
		goto _state_1;
		default:
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 1447 "wizard.c"
	}
	_state_0:
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_ = g_slice_new0 (Block74Data);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_->_ref_count_ = 1;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_->self = g_object_ref (_data_->self);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_->_async_data_ = _data_;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->source;
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp0_ == NULL) {
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = _data_->self->priv->vm_creator;
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_return_val_if_fail (_data_->_tmp1_ != NULL, FALSE);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp3_ == NULL) {
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = _data_->self->priv->review_cancellable;
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_return_val_if_fail (_data_->_tmp4_ != NULL, FALSE);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = 0UL;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = g_signal_connect_data ((GObject*) _data_->self, "notify::machine", (GCallback) _____lambda193__g_object_notify, block74_data_ref (_data_->_data74_), (GClosureNotify) block74_data_unref, 0);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->wait = _data_->_tmp5_;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_state_ = 1;
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1486 "wizard.c"
			_state_1:
			;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = _data_->wait;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp6_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_tmp7_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp8_ == NULL) {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				block74_data_unref (_data_->_data74_);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data74_ = NULL;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1509 "wizard.c"
				} else {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1513 "wizard.c"
				}
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 1519 "wizard.c"
			}
		}
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->self->priv->next_button;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp9_, FALSE);
#line 1526 "wizard.c"
		{
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = _data_->self->priv->vm_creator;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_tmp11_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_launch_vm (_data_->_tmp10_, _data_->_tmp12_, &_data_->_inner_error_);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 1538 "wizard.c"
				goto __catch100_g_error;
			}
		}
		goto __finally100;
		__catch100_g_error:
		{
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_error_;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp14_ = _data_->_tmp13_->message;
#line 208 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:208: %s", _data_->_tmp14_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			block74_data_unref (_data_->_data74_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data74_ = NULL;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ == 0) {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1567 "wizard.c"
			} else {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1571 "wizard.c"
			}
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1577 "wizard.c"
		}
		__finally100:
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_inner_error_ != NULL) {
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			block74_data_unref (_data_->_data74_);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data74_ = NULL;
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 205 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1592 "wizard.c"
		}
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = _data_->self->priv->vm_creator;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = boxes_vm_creator_get_install_media (_data_->_tmp15_);
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->_tmp16_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_installer_media_clean_up_preparation_cache (_data_->_tmp17_);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->self->priv->vm_creator = NULL;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = _data_->self->priv->wizard_source;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_data_->_tmp18_, "");
#line 1610 "wizard.c"
	} else {
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = _data_->self->priv->source;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_iconfig_save ((BoxesIConfig*) _data_->_tmp19_);
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp20_ = boxes_app_app;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp21_ = _data_->self->priv->source;
#line 218 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_app_add_collection_source (_data_->_tmp20_, _data_->_tmp21_, NULL, NULL);
#line 1622 "wizard.c"
	}
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_machine (_data_->self, NULL);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	block74_data_unref (_data_->_data74_);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_ = NULL;
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1636 "wizard.c"
	} else {
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1640 "wizard.c"
	}
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 222 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	block74_data_unref (_data_->_data74_);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data74_ = NULL;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1654 "wizard.c"
	} else {
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1658 "wizard.c"
	}
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1664 "wizard.c"
}


static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error) {
	const gchar* _tmp0_;
	GFile* file = NULL;
	const gchar* _tmp2_;
	GFile* _tmp3_ = NULL;
	GFile* _tmp4_;
	gboolean _tmp5_ = FALSE;
	GError * _inner_error_ = NULL;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (location != NULL);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = location;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp0_, "") == 0) {
#line 1684 "wizard.c"
		GError* _tmp1_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "empty location");
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp1_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 1694 "wizard.c"
	}
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = location;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = g_file_new_for_uri (_tmp2_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	file = _tmp3_;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = file;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = g_file_is_native (_tmp4_);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp5_) {
#line 1708 "wizard.c"
		gboolean _tmp6_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = probing;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (!_tmp6_) {
#line 1714 "wizard.c"
			GFile* _tmp7_;
			gchar* _tmp8_ = NULL;
			gchar* _tmp9_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = file;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = g_file_get_path (_tmp7_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp8_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_installer (self, _tmp9_, &_inner_error_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp9_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1736 "wizard.c"
			}
		}
	} else {
		gboolean uncertain = FALSE;
		gchar* uri = NULL;
		GFile* _tmp10_;
		gchar* _tmp11_ = NULL;
		gchar* mimetype = NULL;
		const gchar* _tmp12_;
		gboolean _tmp13_ = FALSE;
		gchar* _tmp14_ = NULL;
		gboolean _tmp15_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = file;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = g_file_get_uri (_tmp10_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		uri = _tmp11_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = uri;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = g_content_type_guess (_tmp12_, NULL, (gsize) 0, &_tmp13_);
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		uncertain = _tmp13_;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		mimetype = _tmp14_;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = uncertain;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp15_) {
#line 1767 "wizard.c"
			const gchar* _tmp16_;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = uri;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_uri (self, _tmp16_, &_inner_error_);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (mimetype);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (uri);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1785 "wizard.c"
			}
		} else {
			const gchar* _tmp17_;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = mimetype;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = g_strdup_printf ("FIXME: %s", _tmp17_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp19_ = _tmp18_;
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_debug ("wizard.vala:244: %s", _tmp19_);
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp19_);
#line 1801 "wizard.c"
		}
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (mimetype);
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (uri);
#line 1807 "wizard.c"
	}
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (file);
#line 1811 "wizard.c"
}


static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error) {
	xmlURI* uri = NULL;
	const gchar* _tmp0_;
	xmlURI* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	xmlURI* _tmp3_;
	gboolean _tmp6_;
	gchar* _tmp9_ = NULL;
	xmlURI* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp16_;
	xmlURI* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	BoxesCollectionSource* _tmp20_;
	xmlURI* _tmp21_;
	const gchar* _tmp22_;
	GError * _inner_error_ = NULL;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = uri_as_text;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	uri = _tmp1_;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = uri;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ == NULL) {
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = TRUE;
#line 1851 "wizard.c"
	} else {
		xmlURI* _tmp4_;
		const gchar* _tmp5_;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = uri;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->scheme;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp5_ == NULL;
#line 1861 "wizard.c"
	}
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp2_;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp6_) {
#line 1867 "wizard.c"
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _ ("Invalid URI");
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp7_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp8_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 1884 "wizard.c"
		} else {
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 1894 "wizard.c"
		}
	}
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = uri;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = _tmp10_->server;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = _tmp12_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = _tmp9_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp13_ == NULL) {
#line 1909 "wizard.c"
		const gchar* _tmp14_;
		gchar* _tmp15_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = uri_as_text;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_tmp9_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = _tmp15_;
#line 1920 "wizard.c"
	}
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = _tmp9_;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = uri;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = _tmp17_->scheme;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = uri_as_text;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp20_ = boxes_collection_source_new (_tmp16_, _tmp18_, _tmp19_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->source = _tmp20_;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp21_ = uri;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp22_ = _tmp21_->scheme;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp22_, "spice") == 0) {
#line 1942 "wizard.c"
		const gchar* _tmp23_;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp23_ = uri_as_text;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		spice_validate_uri (_tmp23_, NULL, NULL, &_inner_error_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_tmp9_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1960 "wizard.c"
			} else {
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_tmp9_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1972 "wizard.c"
			}
		}
	} else {
		xmlURI* _tmp24_;
		const gchar* _tmp25_;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp24_ = uri;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp25_ = _tmp24_->scheme;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (g_strcmp0 (_tmp25_, "vnc") == 0) {
#line 1984 "wizard.c"
		} else {
			xmlURI* _tmp26_;
			const gchar* _tmp27_;
			gboolean _tmp28_ = FALSE;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp26_ = uri;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp27_ = _tmp26_->scheme;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = g_str_has_prefix (_tmp27_, "qemu");
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp28_) {
#line 1997 "wizard.c"
				BoxesCollectionSource* _tmp29_;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp29_ = self->priv->source;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_collection_source_set_source_type (_tmp29_, "libvirt");
#line 2003 "wizard.c"
			} else {
				BoxesApp* _tmp30_;
				xmlURI* _tmp31_;
				const gchar* _tmp32_;
				gboolean _tmp33_ = FALSE;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp30_ = boxes_app_app;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp31_ = uri;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp32_ = _tmp31_->scheme;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp33_ = boxes_app_has_broker_for_source_type (_tmp30_, _tmp32_);
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp33_) {
#line 2019 "wizard.c"
					BoxesCollectionSource* _tmp34_;
					xmlURI* _tmp35_;
					const gchar* _tmp36_;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp34_ = self->priv->source;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp35_ = uri;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp36_ = _tmp35_->scheme;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_collection_source_set_source_type (_tmp34_, _tmp36_);
#line 2031 "wizard.c"
				} else {
					const gchar* _tmp37_ = NULL;
					xmlURI* _tmp38_;
					const gchar* _tmp39_;
					gchar* _tmp40_ = NULL;
					gchar* _tmp41_;
					GError* _tmp42_;
					GError* _tmp43_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp37_ = _ ("Unsupported protocol '%s'");
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp38_ = uri;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp39_ = _tmp38_->scheme;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp40_ = g_strdup_printf (_tmp37_, _tmp39_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp41_ = _tmp40_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp42_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp41_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp42_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp41_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_inner_error_ = _tmp43_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_propagate_error (error, _inner_error_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_tmp9_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2068 "wizard.c"
					} else {
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_tmp9_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_inner_error_);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2080 "wizard.c"
					}
				}
			}
		}
	}
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp9_);
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_xmlFreeURI0 (uri);
#line 2090 "wizard.c"
}


static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_on_installer_media_instantiated (self, source_object, res);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 2099 "wizard.c"
}


static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error) {
	GtkButton* _tmp0_;
	GtkLabel* _tmp1_;
	const gchar* _tmp2_ = NULL;
	GtkLabel* _tmp3_;
	const gchar* _tmp4_ = NULL;
	BoxesMediaManager* _tmp5_;
	const gchar* _tmp6_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (path != NULL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->prep_media_label;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _ ("Unknown installer media");
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp1_, _tmp2_);
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->prep_status_label;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _ ("Analyzing...");
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp3_, _tmp4_);
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->media_manager;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = path;
#line 275 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_media_manager_create_installer_media_for_path (_tmp5_, _tmp6_, NULL, _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback, g_object_ref (self));
#line 2137 "wizard.c"
}


static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_) {
	GError * _inner_error_ = NULL;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 2147 "wizard.c"
	{
		BoxesInstallerMedia* install_media = NULL;
		BoxesMediaManager* _tmp0_;
		GAsyncResult* _tmp1_;
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = self->priv->media_manager;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = _result_;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_media_manager_create_installer_media_for_path_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		install_media = _tmp2_;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2166 "wizard.c"
				goto __catch101_g_io_error_cancelled;
			}
			goto __catch101_g_error;
		}
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = install_media;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp3_, NULL, NULL);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (install_media);
#line 2177 "wizard.c"
	}
	goto __finally101;
	__catch101_g_io_error_cancelled:
	{
		GError* cancel_error = NULL;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		cancel_error = _inner_error_;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (cancel_error);
#line 2189 "wizard.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
		BoxesApp* _tmp6_;
		BoxesNotificationbar* _tmp7_;
		const gchar* _tmp8_ = NULL;
		GdNotification* _tmp9_ = NULL;
		GdNotification* _tmp10_;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _error_;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->message;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:284: Failed to analyze installer image: %s", _tmp5_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_app_app;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_->notificationbar;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = _ ("Failed to analyze installer media. Corrupted or incomplete media?");
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = boxes_notificationbar_display_error (_tmp7_, _tmp8_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp10_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 2228 "wizard.c"
	}
	__finally101:
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_inner_error_ != NULL) {
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2239 "wizard.c"
	}
}


static void boxes_wizard_prepare_media_data_free (gpointer _data) {
	BoxesWizardPrepareMediaData* _data_;
	_data_ = _data;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardPrepareMediaData, _data_);
#line 2253 "wizard.c"
}


static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
	BoxesWizard* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardPrepareMediaData);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_prepare_media);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_prepare_media_data_free);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = install_media;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->install_media = _tmp2_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2282 "wizard.c"
}


static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardPrepareMediaData* _data_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2290 "wizard.c"
}


static Block75Data* block75_data_ref (Block75Data* _data75_) {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data75_->_ref_count_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data75_;
#line 2299 "wizard.c"
}


static void block75_data_unref (void * _userdata_) {
	Block75Data* _data75_;
	_data75_ = (Block75Data*) _userdata_;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data75_->_ref_count_)) {
#line 2308 "wizard.c"
		BoxesWizard * self;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data75_->self;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data75_->progress);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block75Data, _data75_);
#line 2318 "wizard.c"
	}
}


static void __lambda186_ (Block75Data* _data75_) {
	BoxesWizard * self;
	gdouble _tmp0_;
	gdouble _tmp1_;
	GtkProgressBar* _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data75_->self;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_get_progress (_data75_->progress);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->prep_progress;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = gtk_progress_bar_get_fraction (_tmp2_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if ((_tmp1_ - _tmp4_) >= 0.01) {
#line 2344 "wizard.c"
		GtkProgressBar* _tmp5_;
		gdouble _tmp6_;
		gdouble _tmp7_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = self->priv->prep_progress;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_activity_progress_get_progress (_data75_->progress);
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 299 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp5_, _tmp7_);
#line 2356 "wizard.c"
	}
}


static void ___lambda186__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda186_ (self);
#line 2364 "wizard.c"
}


static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2378 "wizard.c"
}


static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_) {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 2387 "wizard.c"
		goto _state_0;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 2391 "wizard.c"
		goto _state_1;
		default:
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2396 "wizard.c"
	}
	_state_0:
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_ = g_slice_new0 (Block75Data);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_->_ref_count_ = 1;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_->self = g_object_ref (_data_->self);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_->_async_data_ = _data_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->install_media;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->_tmp0_->os;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp1_ != NULL) {
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->self->priv->prep_media_label;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->install_media;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->_tmp3_->os;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp4_);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_data_->_tmp2_, _data_->_tmp6_);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = _data_->self->priv->installer_image;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->install_media;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_os_logo (_data_->_tmp7_, _data_->_tmp9_, 128, NULL, NULL);
#line 2433 "wizard.c"
	}
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = boxes_activity_progress_new ();
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_->progress = _data_->_tmp10_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data ((GObject*) _data_->_data75_->progress, "notify::progress", (GCallback) ___lambda186__g_object_notify, block75_data_ref (_data_->_data75_), (GClosureNotify) block75_data_unref, 0);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = _data_->self->priv->prep_status_label;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_data75_->progress, "info", (GObject*) _data_->_tmp11_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = _data_->install_media;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare (_data_->_tmp12_, _data_->_data75_->progress, NULL, boxes_wizard_prepare_media_ready, _data_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2453 "wizard.c"
	_state_1:
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare_finish (_data_->_tmp12_, _data_->_res_);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp13_ = _data_->install_media;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp14_ = boxes_vm_creator_new (_data_->_tmp13_);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->vm_creator = _data_->_tmp14_;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp15_ = _data_->self->priv->prep_progress;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_data_->_tmp15_, 1.0);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SETUP);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	block75_data_unref (_data_->_data75_);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data75_ = NULL;
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2479 "wizard.c"
	} else {
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2483 "wizard.c"
	}
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 290 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2489 "wizard.c"
}


static gboolean boxes_wizard_prepare (BoxesWizard* self) {
	gboolean result = FALSE;
	GtkImage* _tmp0_;
	BoxesWizardSource* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	GError * _inner_error_ = NULL;
#line 310 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->installer_image;
#line 311 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_image_set_from_icon_name (_tmp0_, "media-optical", 0);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_source_get_install_media (_tmp1_);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ != NULL) {
#line 2514 "wizard.c"
		GtkLabel* _tmp4_;
		const gchar* _tmp5_ = NULL;
		GtkLabel* _tmp6_;
		const gchar* _tmp7_ = NULL;
		BoxesWizardSource* _tmp8_;
		BoxesInstallerMedia* _tmp9_;
		BoxesInstallerMedia* _tmp10_;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->prep_media_label;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _ ("Unknown installer media");
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp4_, _tmp5_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = self->priv->prep_status_label;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _ ("Analyzing...");
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp6_, _tmp7_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = self->priv->wizard_source;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = boxes_wizard_source_get_install_media (_tmp8_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp10_, NULL, NULL);
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 2546 "wizard.c"
	} else {
		{
			BoxesWizardSource* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->wizard_source;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_wizard_source_get_uri (_tmp11_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_location (self, _tmp13_, FALSE, &_inner_error_);
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_ != NULL) {
#line 2562 "wizard.c"
				goto __catch102_g_error;
			}
		}
		goto __finally102;
		__catch102_g_error:
		{
			GError* _error_ = NULL;
			BoxesApp* _tmp14_;
			BoxesNotificationbar* _tmp15_;
			GError* _tmp16_;
			const gchar* _tmp17_;
			GdNotification* _tmp18_ = NULL;
			GdNotification* _tmp19_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_error_ = _inner_error_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_inner_error_ = NULL;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = boxes_app_app;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_->notificationbar;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = _error_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = _tmp16_->message;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = boxes_notificationbar_display_error (_tmp15_, _tmp17_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp19_ = _tmp18_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_tmp19_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			result = FALSE;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_error_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return result;
#line 2600 "wizard.c"
		}
		__finally102:
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_ != NULL) {
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 2611 "wizard.c"
		}
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 2617 "wizard.c"
	}
}


static void __lambda187_ (BoxesWizard* self) {
	BoxesVMCreator* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->vm_creator;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_vm_creator_get_install_media (_tmp0_);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_installer_media_get_ready_to_create (_tmp2_);
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 2640 "wizard.c"
		BoxesWizardPage _tmp5_;
		BoxesWizardPage _tmp6_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_get_page (self);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp6_ + 1);
#line 2649 "wizard.c"
	}
}


static void ___lambda187__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self) {
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda187_ (self);
#line 2657 "wizard.c"
}


static gboolean boxes_wizard_setup (BoxesWizard* self) {
	gboolean result = FALSE;
	BoxesCollectionSource* _tmp0_;
	BoxesVMCreator* _tmp1_;
	BoxesVMCreator* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	BoxesInstallerMedia* _tmp4_;
	GtkButton* _tmp5_;
	BoxesVMCreator* _tmp6_;
	BoxesInstallerMedia* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	GtkBox* _tmp9_;
	BoxesVMCreator* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	BoxesInstallerMedia* _tmp12_;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->source;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 2686 "wizard.c"
	}
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->vm_creator;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_tmp1_ != NULL);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->vm_creator;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_vm_creator_get_install_media (_tmp2_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->continue_button;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp4_, "ready-to-create", (GObject*) _tmp5_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->vm_creator;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = boxes_vm_creator_get_install_media (_tmp6_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = _tmp7_;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->setup_vbox;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_populate_setup_vbox (_tmp8_, _tmp9_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = self->priv->vm_creator;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = boxes_vm_creator_get_install_media (_tmp10_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = _tmp11_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp12_, "user-wants-to-create", (GCallback) ___lambda187__boxes_installer_media_user_wants_to_create, self, 0);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 2724 "wizard.c"
}


static void boxes_wizard_review_data_free (gpointer _data) {
	BoxesWizardReviewData* _data_;
	_data_ = _data;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardReviewData, _data_);
#line 2735 "wizard.c"
}


static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardReviewData);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_review);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_review_data_free);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2754 "wizard.c"
}


static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardReviewData* _data_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 2767 "wizard.c"
}


static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2781 "wizard.c"
}


static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_) {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 2790 "wizard.c"
		goto _state_0;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 2794 "wizard.c"
		goto _state_1;
		default:
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2799 "wizard.c"
	}
	_state_0:
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 354 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ == NULL);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = g_cancellable_new ();
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = _data_->_tmp1_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable (_data_->self, boxes_wizard_review_ready, _data_);
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2818 "wizard.c"
	_state_1:
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = FALSE;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = boxes_wizard_do_review_cancellable_finish (_data_->self, _data_->_res_);
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_result_ = _data_->_tmp2_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = NULL;
#line 360 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->skip_review_for_live = FALSE;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = _data_->_result_;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2838 "wizard.c"
	} else {
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2842 "wizard.c"
	}
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2852 "wizard.c"
	} else {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2856 "wizard.c"
	}
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2862 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_data_free (gpointer _data) {
	BoxesWizardDoReviewCancellableData* _data_;
	_data_ = _data;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDoReviewCancellableData, _data_);
#line 2873 "wizard.c"
}


static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
	BoxesWizard* _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDoReviewCancellableData);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_do_review_cancellable);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_do_review_cancellable_data_free);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 2892 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardDoReviewCancellableData* _data_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 2905 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 2919 "wizard.c"
}


static gpointer _boxes_pair_ref0 (gpointer self) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? boxes_pair_ref (self) : NULL;
#line 2926 "wizard.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 2933 "wizard.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_free (self);
#line 2942 "wizard.c"
}


static Block76Data* block76_data_ref (Block76Data* _data76_) {
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data76_->_ref_count_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data76_;
#line 2951 "wizard.c"
}


static void block76_data_unref (void * _userdata_) {
	Block76Data* _data76_;
	_data76_ = (Block76Data*) _userdata_;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data76_->_ref_count_)) {
#line 2960 "wizard.c"
		BoxesWizard * self;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data76_->self;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data76_->config);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block76Data, _data76_);
#line 2970 "wizard.c"
	}
}


static void _____lambda190_ (Block76Data* _data76_, GError** error) {
	BoxesWizard * self;
	GVirConfigDomain* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirDomain* _tmp3_;
	GVirDomain* _tmp4_;
	GVirConfigDomain* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data76_->self;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_libvirt_machine (self);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gvir_domain_get_config (_tmp4_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _tmp5_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_inner_error_ != NULL) {
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 3004 "wizard.c"
	}
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data76_->config);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data76_->config = _tmp0_;
#line 3010 "wizard.c"
}


static void ______lambda190__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_____lambda190_ (self, error);
#line 3017 "wizard.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3024 "wizard.c"
}


static void __lambda191_ (BoxesWizard* self) {
	BoxesApp* _tmp0_;
	BoxesMachine* _tmp1_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_app;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->_machine;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_app_select_item (_tmp0_, (BoxesCollectionItem*) _tmp1_);
#line 3037 "wizard.c"
}


static void ___lambda191__boxes_wizard_wizard_summary_customize_func (gpointer self) {
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda191_ (self);
#line 3044 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_) {
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 3053 "wizard.c"
		goto _state_0;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 3057 "wizard.c"
		goto _state_1;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 2:
#line 3061 "wizard.c"
		goto _state_2;
		default:
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 3066 "wizard.c"
	}
	_state_0:
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 365 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ != NULL);
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->self->priv->nokvm_label;
#line 367 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_hide ((GtkWidget*) _data_->_tmp1_);
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->summary;
#line 368 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_clear (_data_->_tmp2_);
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = _data_->self->priv->source;
#line 370 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp3_ != NULL) {
#line 3085 "wizard.c"
		{
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->self->priv->source;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_remote_machine_new (_data_->_tmp5_, &_data_->_inner_error_);
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = _data_->_tmp6_;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3097 "wizard.c"
					goto __catch103_boxes_error;
				}
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3106 "wizard.c"
			}
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_tmp4_;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp7_);
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 3114 "wizard.c"
		}
		goto __finally103;
		__catch103_boxes_error:
		{
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_error_;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->_tmp8_->message;
#line 374 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:374: %s", _data_->_tmp9_);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 3131 "wizard.c"
		}
		__finally103:
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_inner_error_ != NULL) {
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 3142 "wizard.c"
		}
	} else {
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp11_ = _data_->self->priv->vm_creator;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp11_ != NULL) {
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_tmp12_;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = _data_->_tmp13_ == NULL;
#line 3155 "wizard.c"
		} else {
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = FALSE;
#line 3159 "wizard.c"
		}
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = _data_->_tmp10_;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp14_) {
#line 3165 "wizard.c"
			{
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = _data_->self->priv->vm_creator;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = _data_->self->priv->review_cancellable;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 1;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_vm_creator_create_vm (_data_->_tmp16_, _data_->_tmp17_, boxes_wizard_do_review_cancellable_ready, _data_);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3177 "wizard.c"
				_state_1:
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = NULL;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = boxes_vm_creator_create_vm_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = _data_->_tmp18_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_ != NULL) {
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3189 "wizard.c"
						goto __catch104_g_io_error_cancelled;
					}
					goto __catch104_g_error;
				}
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = _data_->_tmp15_;
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp19_);
#line 378 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp19_);
#line 3200 "wizard.c"
			}
			goto __finally104;
			__catch104_g_io_error_cancelled:
			{
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->cancel_error = _data_->_inner_error_;
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->cancel_error);
#line 3211 "wizard.c"
			}
			goto __finally104;
			__catch104_g_error:
			{
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = boxes_app_app;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = _data_->_tmp20_->notificationbar;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = NULL;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = _ ("Box setup failed");
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = NULL;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = boxes_notificationbar_display_error (_data_->_tmp21_, _data_->_tmp22_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp24_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = _data_->_vala1__error_;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = _data_->_tmp25_->message;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:382: %s", _data_->_tmp26_);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 3244 "wizard.c"
			}
			__finally104:
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3255 "wizard.c"
			}
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp27_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp28_ = _data_->_tmp27_;
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp28_ == NULL) {
#line 387 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_notify ((GObject*) _data_->self, "machine");
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3271 "wizard.c"
				} else {
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3275 "wizard.c"
				}
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3281 "wizard.c"
			}
		}
	}
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = _data_->self->priv->review_cancellable;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = FALSE;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = g_cancellable_is_cancelled (_data_->_tmp29_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp30_) {
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->result = FALSE;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_state_ == 0) {
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3299 "wizard.c"
		} else {
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3303 "wizard.c"
		}
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 3309 "wizard.c"
	}
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp31_ = _data_->self->priv->review_label;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp32_ = NULL;
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp32_ = _ ("Boxes will create a new box with the following properties:");
#line 395 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_text (_data_->_tmp31_, _data_->_tmp32_);
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp33_ = _data_->self->priv->source;
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp33_ != NULL) {
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp68_label0 = 0;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp68_label1 = 0;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = _data_->self->priv->source;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = boxes_collection_source_get_uri (_data_->_tmp34_);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = _data_->_tmp36_;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = NULL;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = xmlParseURI (_data_->_tmp37_);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = _data_->_tmp38_;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp37_);
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->uri = _data_->_tmp39_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = _data_->self->priv->summary;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = NULL;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = _ ("Type");
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = _data_->self->priv->source;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp43_ = boxes_collection_source_get_source_type (_data_->_tmp42_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp44_ = _data_->_tmp43_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_wizard_summary_add_property (_data_->_tmp40_, _data_->_tmp41_, _data_->_tmp45_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp45_);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp47_ = _data_->uri;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp47_ != NULL) {
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = _data_->uri;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = _data_->_tmp48_->server;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = _data_->_tmp49_ != NULL;
#line 3373 "wizard.c"
		} else {
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = FALSE;
#line 3377 "wizard.c"
		}
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp50_ = _data_->_tmp46_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp50_) {
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = _data_->self->priv->summary;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = _ ("Host");
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = _data_->uri;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = _data_->_tmp53_->server;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = NULL;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = g_utf8_strdown (_data_->_tmp54_, (gssize) (-1));
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = _data_->_tmp55_;
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp51_, _data_->_tmp52_, _data_->_tmp56_);
#line 403 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp56_);
#line 3403 "wizard.c"
		} else {
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp57_ = _data_->self->priv->summary;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = NULL;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = _ ("URI");
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp59_ = _data_->self->priv->source;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp60_ = boxes_collection_source_get_uri (_data_->_tmp59_);
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp61_ = _data_->_tmp60_;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp62_ = _data_->_tmp61_;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp63_ = NULL;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp63_ = g_utf8_strdown (_data_->_tmp62_, (gssize) (-1));
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp64_ = _data_->_tmp63_;
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_wizard_summary_add_property (_data_->_tmp57_, _data_->_tmp58_, _data_->_tmp64_);
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp64_);
#line 405 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp62_);
#line 3431 "wizard.c"
		}
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp65_ = _data_->uri;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp66_ = _data_->_tmp65_->scheme;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp69_ = 0U;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp67_ = _data_->_tmp66_;
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp69_ = (NULL == _data_->_tmp67_) ? 0 : g_quark_from_string (_data_->_tmp67_);
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp69_ == ((0 != _tmp68_label0) ? _tmp68_label0 : (_tmp68_label0 = g_quark_from_static_string ("spice")))) {
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 3447 "wizard.c"
				default:
				{
					{
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = 0;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = 0;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp70_ = _data_->self->priv->source;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp71_ = boxes_collection_source_get_uri (_data_->_tmp70_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp72_ = _data_->_tmp71_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp73_ = _data_->_tmp72_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp74_ = NULL;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp75_ = NULL;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						spice_validate_uri (_data_->_tmp73_, &_data_->_tmp74_, &_data_->_tmp75_, &_data_->_inner_error_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp76_ = _data_->_tmp74_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = *_data_->_tmp76_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp77_ = _data_->_tmp75_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = *_data_->_tmp77_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp77_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp76_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp73_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_inner_error_ != NULL) {
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3487 "wizard.c"
								goto __catch105_boxes_error;
							}
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_xmlFreeURI0 (_data_->uri);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_clear_error (&_data_->_inner_error_);
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							return FALSE;
#line 3498 "wizard.c"
						}
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp78_ = _data_->port;
#line 413 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp78_ > 0) {
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = _data_->self->priv->summary;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp80_ = NULL;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp80_ = _ ("Port");
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp81_ = _data_->port;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = NULL;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = g_strdup_printf ("%i", _data_->_tmp81_);
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp83_ = _data_->_tmp82_;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_wizard_summary_add_property (_data_->_tmp79_, _data_->_tmp80_, _data_->_tmp83_);
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp83_);
#line 3522 "wizard.c"
						}
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp84_ = _data_->tls_port;
#line 415 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp84_ > 0) {
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp85_ = _data_->self->priv->summary;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp86_ = NULL;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp86_ = _ ("TLS Port");
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp87_ = _data_->tls_port;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp88_ = NULL;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp88_ = g_strdup_printf ("%i", _data_->_tmp87_);
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp89_ = _data_->_tmp88_;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_wizard_summary_add_property (_data_->_tmp85_, _data_->_tmp86_, _data_->_tmp89_);
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp89_);
#line 3546 "wizard.c"
						}
					}
					goto __finally105;
					__catch105_boxes_error:
					{
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_vala2__error_ = _data_->_inner_error_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_inner_error_ = NULL;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp90_ = _data_->_vala2__error_;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp91_ = _data_->_tmp90_->message;
#line 419 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("wizard.vala:419: %s", _data_->_tmp91_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_error_free0 (_data_->_vala2__error_);
#line 3564 "wizard.c"
					}
					__finally105:
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_data_->_inner_error_ != NULL) {
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (_data_->uri);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_data_->_inner_error_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						return FALSE;
#line 3577 "wizard.c"
					}
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 3581 "wizard.c"
				}
			}
		} else if (_data_->_tmp69_ == ((0 != _tmp68_label1) ? _tmp68_label1 : (_tmp68_label1 = g_quark_from_static_string ("vnc")))) {
#line 407 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 3587 "wizard.c"
				default:
				{
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp92_ = _data_->uri;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp93_ = _data_->_tmp92_->port;
#line 424 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp93_ > 0) {
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = _data_->self->priv->summary;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = NULL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = _ ("Port");
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp96_ = _data_->uri;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp97_ = _data_->_tmp96_->port;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp98_ = NULL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp98_ = g_strdup_printf ("%i", _data_->_tmp97_);
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp99_ = _data_->_tmp98_;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_wizard_summary_add_property (_data_->_tmp94_, _data_->_tmp95_, _data_->_tmp99_);
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp99_);
#line 3616 "wizard.c"
					}
#line 426 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 3620 "wizard.c"
				}
			}
		}
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp100_ = boxes_app_app;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp101_ = _data_->self->priv->source;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp102_ = boxes_collection_source_get_source_type (_data_->_tmp101_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp103_ = _data_->_tmp102_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp104_ = _data_->_tmp103_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = FALSE;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = boxes_app_has_broker_for_source_type (_data_->_tmp100_, _data_->_tmp104_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp106_ = _data_->_tmp105_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp104_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp106_) {
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = _data_->self->priv->review_label;
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = NULL;
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = _ ("Will add boxes for all systems available from this account:");
#line 430 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_label_set_text (_data_->_tmp107_, _data_->_tmp108_);
#line 3652 "wizard.c"
		}
#line 397 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (_data_->uri);
#line 3656 "wizard.c"
	} else {
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp109_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp110_ = _data_->_tmp109_;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp110_ != NULL) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp111_ = _data_->self->priv->vm_creator;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp112_ = boxes_vm_creator_get_install_media (_data_->_tmp111_);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp113_ = _data_->_tmp112_;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp114_ = NULL;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp114_ = boxes_installer_media_get_vm_properties (_data_->_tmp113_);
#line 3674 "wizard.c"
			{
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->property_collection = _data_->_tmp114_;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				for (_data_->property_it = _data_->property_collection; _data_->property_it != NULL; _data_->property_it = _data_->property_it->next) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp115_ = _boxes_pair_ref0 ((BoxesPair*) _data_->property_it->data);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->property = _data_->_tmp115_;
#line 3684 "wizard.c"
					{
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp116_ = _data_->self->priv->summary;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp117_ = _data_->property;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp118_ = _data_->_tmp117_->first;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp119_ = _data_->property;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp120_ = _data_->_tmp119_->second;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_wizard_summary_add_property (_data_->_tmp116_, (const gchar*) _data_->_tmp118_, (const gchar*) _data_->_tmp120_);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
						_boxes_pair_unref0 (_data_->property);
#line 3700 "wizard.c"
					}
				}
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				__g_list_free__boxes_pair_unref0_0 (_data_->property_collection);
#line 3705 "wizard.c"
			}
			{
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data76_ = g_slice_new0 (Block76Data);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data76_->_ref_count_ = 1;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data76_->self = g_object_ref (_data_->self);
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = NULL;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp121_, gvir_config_domain_get_type ()) ? ((GVirConfigDomain*) _data_->_tmp121_) : NULL);
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data76_->config = _data_->_tmp122_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 2;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread (______lambda190__boxes_run_in_thread_func, block76_data_ref (_data_->_data76_), block76_data_unref, NULL, boxes_wizard_do_review_cancellable_ready, _data_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3726 "wizard.c"
				_state_2:
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_ != NULL) {
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					block76_data_unref (_data_->_data76_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_data76_ = NULL;
#line 3736 "wizard.c"
					goto __catch106_g_error;
				}
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = _data_->_data76_->config;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = gvir_config_domain_get_memory (_data_->_tmp123_);
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = _data_->_tmp124_;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = NULL;
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = g_format_size_full (_data_->_tmp125_ * OSINFO_KIBIBYTES, G_FORMAT_SIZE_IEC_UNITS);
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->memory = _data_->_tmp126_;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp127_ = _data_->self->priv->summary;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = NULL;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = _ ("Memory");
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp129_ = _data_->memory;
#line 441 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_wizard_summary_add_property (_data_->_tmp127_, _data_->_tmp128_, _data_->_tmp129_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->memory);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				block76_data_unref (_data_->_data76_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data76_ = NULL;
#line 3767 "wizard.c"
			}
			goto __finally106;
			__catch106_g_error:
			{
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala3__error_ = _data_->_inner_error_;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = _data_->_tmp130_;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp131_);
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp133_ = _data_->_tmp132_;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp134_ = _data_->_vala3__error_;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp135_ = _data_->_tmp134_->message;
#line 443 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:443: Failed to get configuration for machine '%s': %s", _data_->_tmp133_, _data_->_tmp135_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala3__error_);
#line 3792 "wizard.c"
			}
			__finally106:
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_inner_error_ != NULL) {
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3803 "wizard.c"
			}
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp136_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp137_ = _data_->_tmp136_;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp138_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp137_);
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp139_ = _data_->_tmp138_;
#line 446 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp139_ != NULL) {
#line 3815 "wizard.c"
				{
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp140_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = _data_->_tmp140_;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp141_);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = _data_->_tmp142_;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = NULL;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = gvir_storage_vol_get_info (_data_->_tmp143_, &_data_->_inner_error_);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->volume_info = _data_->_tmp144_;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_data_->_inner_error_ != NULL) {
#line 3833 "wizard.c"
						goto __catch107_g_error;
					}
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = _data_->volume_info;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = _data_->_tmp145_->capacity;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = NULL;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = g_format_size_full (_data_->_tmp146_, G_FORMAT_SIZE_DEFAULT);
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->capacity = _data_->_tmp147_;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = _data_->self->priv->summary;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = NULL;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = _ ("Disk");
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = _data_->capacity;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = NULL;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = g_strdup_printf ("%s maximum", _data_->_tmp150_);
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = _data_->_tmp151_;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = NULL;
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = _ (_data_->_tmp152_);
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_wizard_wizard_summary_add_property (_data_->_tmp148_, _data_->_tmp149_, _data_->_tmp153_);
#line 450 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp152_);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->capacity);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					__vala_GVirStorageVolInfo_free0 (_data_->volume_info);
#line 3872 "wizard.c"
				}
				goto __finally107;
				__catch107_g_error:
				{
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_vala4__error_ = _data_->_inner_error_;
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_inner_error_ = NULL;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp154_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp155_ = _data_->_tmp154_;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp156_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp155_);
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp157_ = _data_->_tmp156_;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = NULL;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = gvir_storage_vol_get_name (_data_->_tmp157_);
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp159_ = _data_->_vala4__error_;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp160_ = _data_->_tmp159_->message;
#line 452 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_warning ("wizard.vala:452: Failed to get information on volume '%s': %s", _data_->_tmp158_, _data_->_tmp160_);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_error_free0 (_data_->_vala4__error_);
#line 3901 "wizard.c"
				}
				__finally107:
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_ != NULL) {
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_clear_error (&_data_->_inner_error_);
#line 447 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					return FALSE;
#line 3912 "wizard.c"
				}
			}
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp161_ = _data_->self->priv->nokvm_label;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp162_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp163_ = _data_->_tmp162_;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp164_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp163_);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp165_ = _data_->_tmp164_;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = 0;
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = gvir_config_domain_get_virt_type (_data_->_tmp165_);
#line 458 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp161_, _data_->_tmp166_ != GVIR_CONFIG_DOMAIN_VIRT_KVM);
#line 3931 "wizard.c"
		}
	}
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp167_ = _data_->self->priv->summary;
#line 461 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_append_customize_button (_data_->_tmp167_, ___lambda191__boxes_wizard_wizard_summary_customize_func, _data_->self);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3944 "wizard.c"
	} else {
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3948 "wizard.c"
	}
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3958 "wizard.c"
	} else {
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3962 "wizard.c"
	}
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3968 "wizard.c"
}


static void g_ptr_array_set (GPtrArray* self, guint index, gpointer data) {
	gpointer _tmp0_;
	guint _tmp1_;
#line 4091 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4092 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = data;
#line 4092 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	data = NULL;
#line 4092 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_add (self, _tmp0_);
#line 4093 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp1_ = index;
#line 4093 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_remove_index_fast (self, _tmp1_);
#line 3987 "wizard.c"
}


static void boxes_wizard_add_step (BoxesWizard* self, GtkWidget* widget, const gchar* title, BoxesWizardPage page) {
	GtkNotebook* _tmp0_;
	GtkWidget* _tmp1_;
	GtkBox* vbox = NULL;
	BoxesApp* _tmp2_;
	BoxesSidebar* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkWidget* _tmp5_ = NULL;
	GtkBox* _tmp6_;
	GtkLabel* label = NULL;
	const gchar* _tmp7_;
	GtkLabel* _tmp8_;
	GtkStyleContext* _tmp9_ = NULL;
	GPtrArray* _tmp10_;
	BoxesWizardPage _tmp11_;
	GtkLabel* _tmp12_;
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (widget != NULL);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (title != NULL);
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->notebook;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = widget;
#line 470 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_notebook_append_page (_tmp0_, _tmp1_, NULL);
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_app_app;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_->sidebar;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->notebook;
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_notebook_get_nth_page (_tmp4_, (gint) BOXES_SIDEBAR_PAGE_WIZARD);
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp5_) : NULL);
#line 473 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	vbox = _tmp6_;
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = title;
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = (GtkLabel*) gtk_label_new (_tmp7_);
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp8_);
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label = _tmp8_;
#line 476 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_margin_left ((GtkWidget*) label, 25);
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) label);
#line 477 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp9_, "boxes-step-label");
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) label, GTK_ALIGN_START);
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (vbox, (GtkWidget*) label, FALSE, FALSE, (guint) 10);
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) vbox);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = self->priv->steps;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = page;
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = _g_object_ref0 (label);
#line 482 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_ptr_array_set (_tmp10_, (guint) _tmp11_, _tmp12_);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 4063 "wizard.c"
}


static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page) {
	gboolean result = FALSE;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
	BoxesWizardPage _tmp2_;
	BoxesWizardPage skip_to = 0;
	BoxesWizardPage _tmp3_;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionSource* _tmp5_;
	gboolean _tmp8_;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_;
	gboolean _tmp17_;
	BoxesVMCreator* _tmp19_;
	BoxesWizardPage _tmp48_;
	BoxesWizardPage _tmp49_;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = page;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = page;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	skip_to = _tmp3_;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->source;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp5_ != NULL) {
#line 4102 "wizard.c"
		BoxesWizardPage _tmp6_;
		BoxesWizardPage _tmp7_;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = page;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 493 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = (BOXES_WIZARD_PAGE_SOURCE < _tmp7_) && (_tmp7_ < BOXES_WIZARD_PAGE_REVIEW);
#line 4111 "wizard.c"
	} else {
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = FALSE;
#line 4115 "wizard.c"
	}
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = _tmp4_;
#line 492 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp8_) {
#line 4121 "wizard.c"
		BoxesWizardPage _tmp9_ = 0;
		gboolean _tmp10_;
		BoxesWizardPage _tmp13_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = forwards;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp10_) {
#line 4129 "wizard.c"
			BoxesWizardPage _tmp11_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = page;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp11_ + 1;
#line 4135 "wizard.c"
		} else {
			BoxesWizardPage _tmp12_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = page;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp12_ - 1;
#line 4142 "wizard.c"
		}
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp13_ = _tmp9_;
#line 494 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp13_;
#line 4148 "wizard.c"
	}
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = forwards;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp15_) {
#line 4154 "wizard.c"
		BoxesWizardPage _tmp16_;
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp16_ = page;
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = _tmp16_ == BOXES_WIZARD_PAGE_PREPARATION;
#line 4160 "wizard.c"
	} else {
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = FALSE;
#line 4164 "wizard.c"
	}
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp14_;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp17_) {
#line 4170 "wizard.c"
		BoxesWizardPage _tmp18_;
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp18_ = page;
#line 499 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp18_ - 1;
#line 4176 "wizard.c"
	}
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = self->priv->vm_creator;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp19_ != NULL) {
#line 4182 "wizard.c"
		gboolean _tmp20_ = FALSE;
		BoxesWizardPage _tmp21_;
		gboolean _tmp27_;
		gboolean _tmp33_ = FALSE;
		gboolean _tmp34_ = FALSE;
		gboolean _tmp35_ = FALSE;
		BoxesWizardPage _tmp36_;
		gboolean _tmp38_;
		gboolean _tmp44_;
		gboolean _tmp46_;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp21_ = page;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp21_ == BOXES_WIZARD_PAGE_SETUP) {
#line 4197 "wizard.c"
			BoxesVMCreator* _tmp22_;
			BoxesInstallerMedia* _tmp23_;
			BoxesInstallerMedia* _tmp24_;
			gboolean _tmp25_;
			gboolean _tmp26_;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp22_ = self->priv->vm_creator;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp23_ = boxes_vm_creator_get_install_media (_tmp22_);
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp24_ = _tmp23_;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp25_ = boxes_installer_media_get_need_user_input_for_vm_creation (_tmp24_);
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp26_ = _tmp25_;
#line 504 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = !_tmp26_;
#line 4215 "wizard.c"
		} else {
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = FALSE;
#line 4219 "wizard.c"
		}
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp27_ = _tmp20_;
#line 503 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp27_) {
#line 4225 "wizard.c"
			BoxesWizardPage _tmp28_ = 0;
			gboolean _tmp29_;
			BoxesWizardPage _tmp32_;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = forwards;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp29_) {
#line 4233 "wizard.c"
				BoxesWizardPage _tmp30_;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp30_ = page;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = _tmp30_ + 1;
#line 4239 "wizard.c"
			} else {
				BoxesWizardPage _tmp31_;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp31_ = page;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = _tmp31_ - 1;
#line 4246 "wizard.c"
			}
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp32_ = _tmp28_;
#line 505 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp32_;
#line 4252 "wizard.c"
		}
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp36_ = page;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp36_ == BOXES_WIZARD_PAGE_REVIEW) {
#line 4258 "wizard.c"
			gboolean _tmp37_;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = forwards;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = _tmp37_;
#line 4264 "wizard.c"
		} else {
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = FALSE;
#line 4268 "wizard.c"
		}
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp38_ = _tmp35_;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp38_) {
#line 4274 "wizard.c"
			BoxesVMCreator* _tmp39_;
			BoxesInstallerMedia* _tmp40_;
			BoxesInstallerMedia* _tmp41_;
			gboolean _tmp42_;
			gboolean _tmp43_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp39_ = self->priv->vm_creator;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp40_ = boxes_vm_creator_get_install_media (_tmp39_);
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp41_ = _tmp40_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp42_ = boxes_installer_media_get_live (_tmp41_);
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp43_ = _tmp42_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp34_ = _tmp43_;
#line 4292 "wizard.c"
		} else {
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp34_ = FALSE;
#line 4296 "wizard.c"
		}
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp44_ = _tmp34_;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp44_) {
#line 4302 "wizard.c"
			gboolean _tmp45_;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp45_ = self->priv->skip_review_for_live;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp33_ = _tmp45_;
#line 4308 "wizard.c"
		} else {
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp33_ = FALSE;
#line 4312 "wizard.c"
		}
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp46_ = _tmp33_;
#line 508 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp46_) {
#line 4318 "wizard.c"
			BoxesWizardPage _tmp47_;
#line 511 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp47_ = skip_to;
#line 511 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp47_ + 1;
#line 4324 "wizard.c"
		}
	}
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp48_ = skip_to;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp49_ = page;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp48_ != _tmp49_) {
#line 4333 "wizard.c"
		BoxesWizardPage _tmp50_;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp50_ = skip_to;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp50_);
#line 516 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 516 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 4343 "wizard.c"
	}
#line 519 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = FALSE;
#line 519 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 4349 "wizard.c"
}


static void __lambda196_ (BoxesWizard* self) {
	BoxesWizardSource* _tmp0_;
	BoxesApp* _tmp1_;
#line 658 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 659 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->vm_creator = NULL;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 660 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp0_, BOXES_SOURCE_PAGE_MAIN);
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_app_app;
#line 661 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 4370 "wizard.c"
}


static void ___lambda196__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda196_ (self);
#line 4377 "wizard.c"
}


static void __lambda197_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 669 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ - 1);
#line 4390 "wizard.c"
}


static void ___lambda197__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda197_ (self);
#line 4397 "wizard.c"
}


static void __lambda198_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 678 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 4410 "wizard.c"
}


static void ___lambda198__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda198_ (self);
#line 4417 "wizard.c"
}


static void __lambda199_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_;
	BoxesWizardPage _tmp1_;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 687 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 4430 "wizard.c"
}


static void ___lambda199__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 686 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda199_ (self);
#line 4437 "wizard.c"
}


static void boxes_wizard_setup_ui (BoxesWizard* self) {
	GtkNotebook* _tmp0_;
	GtkNotebook* _tmp1_;
	GtkNotebook* _tmp2_;
	GtkNotebook* _tmp3_;
	GtkNotebook* _tmp4_;
	GtkStyleContext* _tmp5_ = NULL;
	GtkNotebook* _tmp6_;
	GtkClutterActor* _tmp7_;
	GtkClutterActor* _tmp8_;
	GtkWidget* _tmp9_ = NULL;
	GtkStyleContext* _tmp10_ = NULL;
	GtkClutterActor* _tmp11_;
	GtkClutterActor* _tmp12_;
	GtkClutterActor* _tmp13_;
	GtkClutterActor* _tmp14_;
	GtkClutterActor* _tmp15_;
	GtkClutterActor* _tmp16_;
	GtkBox* hbox = NULL;
	GtkBox* _tmp17_;
	GtkBox* _tmp18_;
	GtkBox* _tmp19_;
	const gchar* _tmp20_ = NULL;
	GtkBox* _tmp21_;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_;
	GtkImage* _tmp24_;
	GtkImage* _tmp25_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp26_;
	GtkLabel* _tmp27_;
	GtkStyleContext* _tmp28_ = NULL;
	GtkLabel* _tmp29_;
	const gchar* _tmp30_ = NULL;
	GtkLabel* _tmp31_;
	GtkLabel* _tmp32_;
	GtkLabel* _tmp33_;
	GtkBox* _tmp34_;
	GtkLabel* _tmp35_;
	GtkBox* _tmp36_;
	GtkBox* vbox = NULL;
	GtkBox* _tmp37_;
	GtkBox* _tmp38_;
	GtkBox* _tmp39_;
	GtkBox* _tmp40_;
	const gchar* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
	GtkLabel* _tmp43_;
	GtkLabel* _tmp44_;
	GtkStyleContext* _tmp45_ = NULL;
	GtkLabel* _tmp46_;
	GtkLabel* _tmp47_;
	GtkLabel* _tmp48_;
	GtkBox* _tmp49_;
	GtkLabel* _tmp50_;
	GtkBox* _tmp51_;
	BoxesWizardSource* _tmp52_;
	GtkWidget* _tmp53_;
	GtkWidget* _tmp54_;
	BoxesWizardSource* _tmp55_;
	GtkWidget* _tmp56_;
	GtkWidget* _tmp57_;
	BoxesWizardSource* _tmp58_;
	GtkWidget* _tmp59_;
	GtkWidget* _tmp60_;
	const gchar* _tmp61_ = NULL;
	GtkLabel* _tmp62_;
	GtkLabel* _tmp63_;
	GtkStyleContext* _tmp64_ = NULL;
	GtkLabel* _tmp65_;
	GtkLabel* _tmp66_;
	GtkLabel* _tmp67_;
	GtkBox* _tmp68_;
	GtkLabel* _tmp69_;
	GtkBox* _tmp70_;
	GtkBox* _tmp71_;
	GtkBox* _tmp72_;
	GtkBox* _tmp73_;
	GtkBox* _tmp74_;
	const gchar* _tmp75_ = NULL;
	const gchar* _tmp76_ = NULL;
	GtkLabel* _tmp77_;
	GtkLabel* _tmp78_;
	GtkStyleContext* _tmp79_ = NULL;
	GtkLabel* _tmp80_;
	GtkLabel* _tmp81_;
	GtkLabel* _tmp82_;
	GtkBox* _tmp83_;
	GtkLabel* _tmp84_;
	GtkBox* _tmp85_;
	GtkBox* _tmp86_;
	GtkBox* _tmp87_;
	GtkBox* _tmp88_;
	GtkBox* _tmp89_;
	GtkImage* _tmp90_;
	GtkImage* _tmp91_;
	GtkBox* _tmp92_;
	GtkImage* _tmp93_;
	GtkBox* prep_vbox = NULL;
	GtkBox* _tmp94_;
	GtkBox* _tmp95_;
	GtkLabel* _tmp96_;
	GtkLabel* _tmp97_;
	GtkStyleContext* _tmp98_ = NULL;
	GtkLabel* _tmp99_;
	GtkLabel* _tmp100_;
	GtkLabel* _tmp101_;
	GtkLabel* _tmp102_;
	GtkLabel* _tmp103_;
	GtkStyleContext* _tmp104_ = NULL;
	GtkLabel* _tmp105_;
	GtkLabel* _tmp106_;
	GtkProgressBar* _tmp107_;
	GtkProgressBar* _tmp108_;
	GtkBox* _tmp109_;
	GtkBox* _tmp110_;
	GtkBox* _tmp111_;
	GtkBox* _tmp112_;
	GtkBox* _tmp113_;
	const gchar* _tmp114_ = NULL;
	GtkBox* _tmp115_;
	GtkBox* _tmp116_;
	GtkBox* _tmp117_;
	GtkBox* _tmp118_;
	GtkBox* _tmp119_;
	const gchar* _tmp120_ = NULL;
	GtkLabel* _tmp121_;
	GtkLabel* _tmp122_;
	GtkStyleContext* _tmp123_ = NULL;
	GtkLabel* _tmp124_;
	GtkLabel* _tmp125_;
	GtkLabel* _tmp126_;
	GtkBox* _tmp127_;
	GtkLabel* _tmp128_;
	BoxesWizardWizardSummary* _tmp129_;
	GtkBox* _tmp130_;
	BoxesWizardWizardSummary* _tmp131_;
	GtkWidget* _tmp132_;
	GtkWidget* _tmp133_;
	const gchar* _tmp134_ = NULL;
	GtkLabel* _tmp135_;
	GtkLabel* _tmp136_;
	GtkStyleContext* _tmp137_ = NULL;
	GtkLabel* _tmp138_;
	GtkLabel* _tmp139_;
	GtkBox* _tmp140_;
	GtkLabel* _tmp141_;
	GtkBox* _tmp142_;
	BoxesApp* _tmp143_;
	BoxesTopbar* _tmp144_;
	GtkNotebook* _tmp145_;
	GtkWidget* _tmp146_ = NULL;
	GtkBox* _tmp147_;
	GdMainToolbar* toolbar = NULL;
	GdMainToolbar* _tmp148_;
	GtkStyleContext* _tmp149_ = NULL;
	GtkBox* _tmp150_;
	const gchar* _tmp151_ = NULL;
	GtkSizeGroup* _tmp152_;
	const gchar* _tmp153_ = NULL;
	GtkWidget* _tmp154_ = NULL;
	GtkButton* _tmp155_;
	GtkButton* _tmp156_;
	GtkButton* _tmp157_;
	const gchar* _tmp158_ = NULL;
	GtkButton* _tmp159_;
	GtkSizeGroup* _tmp160_;
	GtkButton* _tmp161_;
	const gchar* _tmp162_ = NULL;
	GtkWidget* _tmp163_ = NULL;
	GtkButton* _tmp164_;
	GtkButton* _tmp165_;
	GtkButton* _tmp166_;
	const gchar* _tmp167_ = NULL;
	GtkButton* _tmp168_;
	GtkSizeGroup* _tmp169_;
	GtkButton* _tmp170_;
	const gchar* _tmp171_ = NULL;
	GtkWidget* _tmp172_ = NULL;
	GtkButton* _tmp173_;
	GtkButton* _tmp174_;
	GtkButton* _tmp175_;
	const gchar* _tmp176_ = NULL;
	GtkButton* _tmp177_;
	GtkStyleContext* _tmp178_ = NULL;
	GtkButton* _tmp179_;
	GtkSizeGroup* _tmp180_;
	GtkButton* _tmp181_;
	const gchar* _tmp182_ = NULL;
	GtkWidget* _tmp183_ = NULL;
	GtkButton* _tmp184_;
	GtkButton* _tmp185_;
	GtkButton* _tmp186_;
	const gchar* _tmp187_ = NULL;
	GtkButton* _tmp188_;
	GtkStyleContext* _tmp189_ = NULL;
	GtkButton* _tmp190_;
	GtkSizeGroup* _tmp191_;
	GtkButton* _tmp192_;
	GtkBox* _tmp193_;
	GtkNotebook* _tmp194_;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp0_);
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->notebook);
#line 523 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->notebook = _tmp0_;
#line 524 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->notebook;
#line 524 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkWidget*) _tmp1_, "margin", 15, NULL);
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->notebook;
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkWidget*) _tmp2_, "width-request", 500, NULL);
#line 526 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->notebook;
#line 526 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_notebook_set_show_tabs (_tmp3_, FALSE);
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->notebook;
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 527 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp5_, "boxes-bg");
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->notebook;
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp6_);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp7_);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->gtk_actor = _tmp7_;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->gtk_actor;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = gtk_clutter_actor_get_widget (_tmp8_);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = gtk_widget_get_style_context (_tmp9_);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp10_, "boxes-bg");
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = self->priv->gtk_actor;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp11_, "wizard");
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->gtk_actor;
#line 531 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp12_, (guint) 0);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = self->priv->gtk_actor;
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp13_, CLUTTER_ACTOR_ALIGN_FILL);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = self->priv->gtk_actor;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp14_, CLUTTER_ACTOR_ALIGN_FILL);
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->gtk_actor;
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp15_, TRUE);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = self->priv->gtk_actor;
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp16_, TRUE);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp17_);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	hbox = _tmp17_;
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = hbox;
#line 539 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp18_, GTK_ALIGN_CENTER);
#line 540 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = hbox;
#line 540 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp20_ = _ ("Introduction");
#line 540 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp19_, _tmp20_, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp21_ = hbox;
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp22_ = boxes_get_pixmap ("boxes-create.png");
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp23_ = _tmp22_;
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp24_ = (GtkImage*) gtk_image_new_from_file (_tmp23_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp24_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp25_ = _tmp24_;
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_container_add ((GtkContainer*) _tmp21_, (GtkWidget*) _tmp25_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp25_);
#line 541 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (_tmp23_);
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp26_ = (GtkLabel*) gtk_label_new (NULL);
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp26_);
#line 542 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label = _tmp26_;
#line 543 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp27_ = label;
#line 543 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp28_ = gtk_widget_get_style_context ((GtkWidget*) _tmp27_);
#line 543 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp28_, "boxes-wizard-label");
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp29_ = label;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp30_ = _ ("Creating a Box will allow you to use another operating system directly" \
" from your existing login.\n" \
"\n" \
"You may connect to an existing machine <b><i>over the network</i></b> " \
"or create a <b><i>virtual machine</i></b> that runs locally on your ow" \
"n.");
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_markup (_tmp29_, _tmp30_);
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp31_ = label;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp31_, "wrap", TRUE, NULL);
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp32_ = label;
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp32_, 30);
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp33_ = label;
#line 548 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp33_, 40);
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp34_ = hbox;
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp35_ = label;
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_container_add ((GtkContainer*) _tmp34_, (GtkWidget*) _tmp35_);
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp36_ = hbox;
#line 550 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp36_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp37_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 30);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp37_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	vbox = _tmp37_;
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp38_ = vbox;
#line 554 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp38_, GTK_ALIGN_CENTER);
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp39_ = vbox;
#line 555 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp39_, GTK_ALIGN_CENTER);
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp40_ = vbox;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp41_ = _ ("Source Selection");
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp40_, _tmp41_, BOXES_WIZARD_PAGE_SOURCE);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp42_ = _ ("Insert operating system installation media or select a source below");
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp43_ = (GtkLabel*) gtk_label_new (_tmp42_);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp43_);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 557 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label = _tmp43_;
#line 558 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp44_ = label;
#line 558 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp45_ = gtk_widget_get_style_context ((GtkWidget*) _tmp44_);
#line 558 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp45_, "boxes-wizard-label");
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp46_ = label;
#line 559 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp46_, "wrap", TRUE, NULL);
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp47_ = label;
#line 561 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp47_, 30);
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp48_ = label;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp48_, "xalign", 0.0f, NULL);
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp49_ = vbox;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp50_ = label;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp49_, (GtkWidget*) _tmp50_, FALSE, FALSE, (guint) 0);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp51_ = vbox;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp52_ = self->priv->wizard_source;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp53_ = boxes_wizard_source_get_widget (_tmp52_);
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp54_ = _tmp53_;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp51_, _tmp54_, FALSE, FALSE, (guint) 0);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp55_ = self->priv->wizard_source;
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp56_ = boxes_wizard_source_get_widget (_tmp55_);
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp57_ = _tmp56_;
#line 565 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_hexpand (_tmp57_, TRUE);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp58_ = self->priv->wizard_source;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp59_ = boxes_wizard_source_get_widget (_tmp58_);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp60_ = _tmp59_;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign (_tmp60_, GTK_ALIGN_CENTER);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp61_ = _ ("Any trademarks shown above are used merely for identification of softw" \
"are products you have already obtained and are the property of their r" \
"espective owners.");
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp62_ = (GtkLabel*) gtk_label_new (_tmp61_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp62_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label = _tmp62_;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp63_ = label;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp64_ = gtk_widget_get_style_context ((GtkWidget*) _tmp63_);
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp64_, "boxes-logo-notice-label");
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp65_ = label;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp65_, "wrap", TRUE, NULL);
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp66_ = label;
#line 571 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp66_, 30);
#line 572 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp67_ = label;
#line 572 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp67_, 50);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp68_ = vbox;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp69_ = label;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp68_, (GtkWidget*) _tmp69_, FALSE, FALSE, (guint) 0);
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp70_ = vbox;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp70_);
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp71_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 30);
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp71_);
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 577 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	vbox = _tmp71_;
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp72_ = vbox;
#line 578 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp72_, GTK_ALIGN_CENTER);
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp73_ = vbox;
#line 579 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp73_, GTK_ALIGN_CENTER);
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp74_ = vbox;
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp75_ = _ ("Preparation");
#line 580 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp74_, _tmp75_, BOXES_WIZARD_PAGE_PREPARATION);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp76_ = _ ("Preparing to create new box");
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp77_ = (GtkLabel*) gtk_label_new (_tmp76_);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp77_);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 581 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label = _tmp77_;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp78_ = label;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp79_ = gtk_widget_get_style_context ((GtkWidget*) _tmp78_);
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp79_, "boxes-wizard-label");
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp80_ = label;
#line 583 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp80_, "wrap", TRUE, NULL);
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp81_ = label;
#line 585 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp81_, 30);
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp82_ = label;
#line 586 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp82_, "xalign", 0.0f, NULL);
#line 587 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp83_ = vbox;
#line 587 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp84_ = label;
#line 587 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp83_, (GtkWidget*) _tmp84_, FALSE, FALSE, (guint) 0);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp85_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp85_);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 589 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	hbox = _tmp85_;
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp86_ = hbox;
#line 590 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp86_, GTK_ALIGN_CENTER);
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp87_ = hbox;
#line 591 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp87_, GTK_ALIGN_CENTER);
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp88_ = vbox;
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp89_ = hbox;
#line 592 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp88_, (GtkWidget*) _tmp89_, TRUE, TRUE, (guint) 0);
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp90_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp90_);
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 594 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->installer_image = _tmp90_;
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp91_ = self->priv->installer_image;
#line 595 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_image_set_pixel_size (_tmp91_, 128);
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp92_ = hbox;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp93_ = self->priv->installer_image;
#line 596 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp92_, (GtkWidget*) _tmp93_, FALSE, FALSE, (guint) 0);
#line 597 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp94_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
#line 597 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp94_);
#line 597 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	prep_vbox = _tmp94_;
#line 598 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_set_homogeneous (prep_vbox, TRUE);
#line 599 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) prep_vbox, GTK_ALIGN_CENTER);
#line 600 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp95_ = hbox;
#line 600 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp95_, (GtkWidget*) prep_vbox, TRUE, TRUE, (guint) 0);
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp96_ = (GtkLabel*) gtk_label_new (NULL);
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp96_);
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_media_label);
#line 601 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->prep_media_label = _tmp96_;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp97_ = self->priv->prep_media_label;
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp98_ = gtk_widget_get_style_context ((GtkWidget*) _tmp97_);
#line 602 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp98_, "boxes-wizard-media-os-label");
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp99_ = self->priv->prep_media_label;
#line 603 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_ellipsize (_tmp99_, PANGO_ELLIPSIZE_END);
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp100_ = self->priv->prep_media_label;
#line 604 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp100_, GTK_ALIGN_START);
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp101_ = self->priv->prep_media_label;
#line 605 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (prep_vbox, (GtkWidget*) _tmp101_, FALSE, FALSE, (guint) 0);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp102_ = (GtkLabel*) gtk_label_new (NULL);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp102_);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_status_label);
#line 606 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->prep_status_label = _tmp102_;
#line 607 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp103_ = self->priv->prep_status_label;
#line 607 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp104_ = gtk_widget_get_style_context ((GtkWidget*) _tmp103_);
#line 607 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp104_, "boxes-wizard-label");
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp105_ = self->priv->prep_status_label;
#line 608 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp105_, GTK_ALIGN_START);
#line 609 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp106_ = self->priv->prep_status_label;
#line 609 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (prep_vbox, (GtkWidget*) _tmp106_, FALSE, FALSE, (guint) 0);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp107_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp107_);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 610 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->prep_progress = _tmp107_;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp108_ = self->priv->prep_progress;
#line 611 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (prep_vbox, (GtkWidget*) _tmp108_, FALSE, FALSE, (guint) 0);
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp109_ = vbox;
#line 612 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp109_);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp110_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 30);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp110_);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_vbox);
#line 615 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->setup_vbox = _tmp110_;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp111_ = self->priv->setup_vbox;
#line 616 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp111_, GTK_ALIGN_CENTER);
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp112_ = self->priv->setup_vbox;
#line 617 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp112_, GTK_ALIGN_CENTER);
#line 618 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp113_ = self->priv->setup_vbox;
#line 618 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp114_ = _ ("Setup");
#line 618 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp113_, _tmp114_, BOXES_WIZARD_PAGE_SETUP);
#line 619 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp115_ = self->priv->setup_vbox;
#line 619 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp115_);
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp116_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 30);
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp116_);
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 622 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	vbox = _tmp116_;
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp117_ = vbox;
#line 623 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp117_, GTK_ALIGN_CENTER);
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp118_ = vbox;
#line 624 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp118_, GTK_ALIGN_CENTER);
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp119_ = vbox;
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp120_ = _ ("Review");
#line 625 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_add_step (self, (GtkWidget*) _tmp119_, _tmp120_, BOXES_WIZARD_PAGE_REVIEW);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp121_ = (GtkLabel*) gtk_label_new (NULL);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp121_);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 627 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->review_label = _tmp121_;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp122_ = self->priv->review_label;
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp123_ = gtk_widget_get_style_context ((GtkWidget*) _tmp122_);
#line 628 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp123_, "boxes-wizard-label");
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp124_ = self->priv->review_label;
#line 629 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp124_, "xalign", 0.0f, NULL);
#line 630 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp125_ = self->priv->review_label;
#line 630 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp125_, "wrap", TRUE, NULL);
#line 631 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp126_ = self->priv->review_label;
#line 631 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_width_chars (_tmp126_, 30);
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp127_ = vbox;
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp128_ = self->priv->review_label;
#line 632 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp127_, (GtkWidget*) _tmp128_, FALSE, FALSE, (guint) 0);
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp129_ = boxes_wizard_wizard_summary_new ();
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 634 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->summary = _tmp129_;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp130_ = vbox;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp131_ = self->priv->summary;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp132_ = boxes_wizard_wizard_summary_get_widget (_tmp131_);
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp133_ = _tmp132_;
#line 635 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp130_, _tmp133_, TRUE, TRUE, (guint) 0);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp134_ = _ ("Virtualization extensions are unavailable on your system. Expect this " \
"box to be extremely slow. If your system is recent enough (made in or " \
"after 2008), these extensions are probably available on your system an" \
"d you may need to enable them in your system's BIOS setup.");
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp135_ = (GtkLabel*) gtk_label_new (_tmp134_);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp135_);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_label);
#line 636 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->nokvm_label = _tmp135_;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp136_ = self->priv->nokvm_label;
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp137_ = gtk_widget_get_style_context ((GtkWidget*) _tmp136_);
#line 637 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp137_, "boxes-logo-notice-label");
#line 638 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp138_ = self->priv->nokvm_label;
#line 638 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set (_tmp138_, "wrap", TRUE, NULL);
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp139_ = self->priv->nokvm_label;
#line 639 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp139_, 50);
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp140_ = vbox;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp141_ = self->priv->nokvm_label;
#line 640 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp140_, (GtkWidget*) _tmp141_, FALSE, FALSE, (guint) 0);
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp142_ = vbox;
#line 641 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp142_);
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp143_ = boxes_app_app;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp144_ = _tmp143_->topbar;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp145_ = _tmp144_->notebook;
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp146_ = gtk_notebook_get_nth_page (_tmp145_, (gint) BOXES_TOPBAR_PAGE_WIZARD);
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp147_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp146_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp146_) : NULL);
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 644 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	hbox = _tmp147_;
#line 646 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp148_ = (GdMainToolbar*) gd_main_toolbar_new ();
#line 646 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp148_);
#line 646 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	toolbar = _tmp148_;
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp149_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 647 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp149_, GTK_STYLE_CLASS_MENUBAR);
#line 648 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkToolbar*) toolbar, "toolbar-style", GTK_TOOLBAR_TEXT, NULL);
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp150_ = hbox;
#line 649 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_box_pack_start (_tmp150_, (GtkWidget*) toolbar, TRUE, TRUE, (guint) 0);
#line 651 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp151_ = _ ("Create a Box");
#line 651 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gd_main_toolbar_set_labels (toolbar, _tmp151_, NULL);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp152_ = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->toolbar_sizegroup);
#line 653 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->toolbar_sizegroup = _tmp152_;
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp153_ = _ ("_Cancel");
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp154_ = gd_main_toolbar_add_button (toolbar, NULL, _tmp153_, TRUE);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp155_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp154_, GTK_TYPE_BUTTON) ? ((GtkButton*) _tmp154_) : NULL);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 654 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->cancel_button = _tmp155_;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp156_ = self->priv->cancel_button;
#line 655 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_use_underline (_tmp156_, TRUE);
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp157_ = self->priv->cancel_button;
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp158_ = _ ("_Cancel");
#line 656 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_label (_tmp157_, _tmp158_);
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp159_ = self->priv->cancel_button;
#line 657 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp159_, "clicked", (GCallback) ___lambda196__gtk_button_clicked, self, 0);
#line 663 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp160_ = self->priv->toolbar_sizegroup;
#line 663 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp161_ = self->priv->cancel_button;
#line 663 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_size_group_add_widget (_tmp160_, (GtkWidget*) _tmp161_);
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp162_ = _ ("_Back");
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp163_ = gd_main_toolbar_add_button (toolbar, NULL, _tmp162_, FALSE);
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp164_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp163_, GTK_TYPE_BUTTON) ? ((GtkButton*) _tmp163_) : NULL);
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 665 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->back_button = _tmp164_;
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp165_ = self->priv->back_button;
#line 666 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_use_underline (_tmp165_, TRUE);
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp166_ = self->priv->back_button;
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp167_ = _ ("_Back");
#line 667 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_label (_tmp166_, _tmp167_);
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp168_ = self->priv->back_button;
#line 668 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp168_, "clicked", (GCallback) ___lambda197__gtk_button_clicked, self, 0);
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp169_ = self->priv->toolbar_sizegroup;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp170_ = self->priv->back_button;
#line 671 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_size_group_add_widget (_tmp169_, (GtkWidget*) _tmp170_);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp171_ = _ ("C_ontinue");
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp172_ = gd_main_toolbar_add_button (toolbar, NULL, _tmp171_, FALSE);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp173_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp172_, GTK_TYPE_BUTTON) ? ((GtkButton*) _tmp172_) : NULL);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 673 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->continue_button = _tmp173_;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp174_ = self->priv->continue_button;
#line 674 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_use_underline (_tmp174_, TRUE);
#line 675 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp175_ = self->priv->continue_button;
#line 675 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp176_ = _ ("C_ontinue");
#line 675 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_label (_tmp175_, _tmp176_);
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp177_ = self->priv->continue_button;
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp178_ = gtk_widget_get_style_context ((GtkWidget*) _tmp177_);
#line 676 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp178_, "boxes-continue");
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp179_ = self->priv->continue_button;
#line 677 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp179_, "clicked", (GCallback) ___lambda198__gtk_button_clicked, self, 0);
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp180_ = self->priv->toolbar_sizegroup;
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp181_ = self->priv->continue_button;
#line 680 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_size_group_add_widget (_tmp180_, (GtkWidget*) _tmp181_);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp182_ = _ ("C_reate");
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp183_ = gd_main_toolbar_add_button (toolbar, NULL, _tmp182_, FALSE);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp184_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp183_, GTK_TYPE_BUTTON) ? ((GtkButton*) _tmp183_) : NULL);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 682 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->create_button = _tmp184_;
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp185_ = self->priv->create_button;
#line 683 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_use_underline (_tmp185_, TRUE);
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp186_ = self->priv->create_button;
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp187_ = _ ("C_reate");
#line 684 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_button_set_label (_tmp186_, _tmp187_);
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp188_ = self->priv->create_button;
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp189_ = gtk_widget_get_style_context ((GtkWidget*) _tmp188_);
#line 685 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp189_, "boxes-continue");
#line 686 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp190_ = self->priv->create_button;
#line 686 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp190_, "clicked", (GCallback) ___lambda199__gtk_button_clicked, self, 0);
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp191_ = self->priv->toolbar_sizegroup;
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp192_ = self->priv->create_button;
#line 689 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_size_group_add_widget (_tmp191_, (GtkWidget*) _tmp192_);
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp193_ = hbox;
#line 691 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp193_);
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp194_ = self->priv->notebook;
#line 692 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp194_);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (toolbar);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (prep_vbox);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (vbox);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (hbox);
#line 5398 "wizard.c"
}


void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live) {
	BoxesApp* _tmp0_;
	gboolean _tmp1_;
	BoxesWizardSource* _tmp2_;
	BoxesWizardSource* _tmp3_;
	const gchar* _tmp4_;
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 695 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri != NULL);
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_app;
#line 696 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 697 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = skip_review_for_live;
#line 697 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->skip_review_for_live = _tmp1_;
#line 699 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 700 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 700 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp2_, BOXES_SOURCE_PAGE_URL);
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri;
#line 701 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp3_, _tmp4_);
#line 702 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5434 "wizard.c"
}


static void boxes_wizard_real_ui_state_changed (BoxesUI* base) {
	BoxesWizard * self;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	gint _tmp5_ = 0;
	BoxesUIState _tmp6_;
	BoxesUIState _tmp7_;
	ClutterActor* _tmp8_;
	ClutterActor* _tmp9_;
	gint _tmp10_;
#line 705 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 706 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == BOXES_UI_STATE_WIZARD) {
#line 5456 "wizard.c"
		BoxesUIState _tmp2_;
		BoxesUIState _tmp3_;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = _tmp2_;
#line 707 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp3_ == BOXES_UI_STATE_PROPERTIES) {
#line 708 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_review (self, NULL, NULL);
#line 5467 "wizard.c"
		} else {
			BoxesWizardSource* _tmp4_;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->wizard_source;
#line 710 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_uri (_tmp4_, "");
#line 711 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 5476 "wizard.c"
		}
	}
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp7_ == BOXES_UI_STATE_WIZARD) {
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = 255;
#line 5487 "wizard.c"
	} else {
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = 0;
#line 5491 "wizard.c"
	}
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = _tmp8_;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = _tmp5_;
#line 715 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_fade_actor (_tmp9_, (guint) _tmp10_);
#line 5501 "wizard.c"
}


static void boxes_wizard_destroy_machine (BoxesWizard* self) {
	GCancellable* _tmp0_;
	BoxesMachine* _tmp2_;
#line 718 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 719 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->review_cancellable;
#line 719 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 5514 "wizard.c"
		GCancellable* _tmp1_;
#line 720 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->review_cancellable;
#line 720 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 5520 "wizard.c"
	}
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->_machine;
#line 722 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp2_ != NULL) {
#line 5526 "wizard.c"
		BoxesApp* _tmp3_;
		BoxesMachine* _tmp4_;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_app;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->_machine;
#line 723 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_app_delete_machine (_tmp3_, _tmp4_, TRUE);
#line 724 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, NULL);
#line 5537 "wizard.c"
	}
}


static ClutterActor* boxes_wizard_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesWizard* self;
	GtkClutterActor* _tmp0_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = (ClutterActor*) _tmp0_;
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5554 "wizard.c"
}


BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self) {
	BoxesMachine* result;
	BoxesMachine* _tmp0_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5569 "wizard.c"
}


void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value) {
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_machine = _tmp1_;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "machine");
#line 5588 "wizard.c"
}


static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self) {
	BoxesLibvirtMachine* result;
	BoxesMachine* _tmp0_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5603 "wizard.c"
}


static BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self) {
	BoxesWizardPage result;
	BoxesWizardPage _tmp0_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_page;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5618 "wizard.c"
}


static void _boxes_wizard_page_____lambda192_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GtkButton* _tmp0_;
	GAsyncResult* _tmp1_;
	gboolean _tmp2_ = FALSE;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _result_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_review_finish (self, _tmp1_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp2_) {
#line 5638 "wizard.c"
		BoxesWizardPage _tmp3_;
		BoxesWizardPage _tmp4_;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_wizard_get_page (self);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp3_;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp4_ - 1);
#line 5647 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda192__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda192_ (self, source_object, res);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5657 "wizard.c"
}


static void _boxes_wizard_page_____lambda194_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _result_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_create_finish (self, _tmp0_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_) {
#line 5672 "wizard.c"
		BoxesApp* _tmp2_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_app_app;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_ui_state ((BoxesUI*) _tmp2_, BOXES_UI_STATE_COLLECTION);
#line 5678 "wizard.c"
	} else {
		BoxesApp* _tmp3_;
		BoxesNotificationbar* _tmp4_;
		const gchar* _tmp5_ = NULL;
		GdNotification* _tmp6_ = NULL;
		GdNotification* _tmp7_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_app;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp3_->notificationbar;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _ ("Box creation failed");
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_notificationbar_display_error (_tmp4_, _tmp5_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp7_);
#line 5697 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda194__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda194_ (self, source_object, res);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5707 "wizard.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4112 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 5722 "wizard.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4113 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 5734 "wizard.c"
}


static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value) {
	GtkButton* _tmp0_;
	BoxesWizardPage _tmp1_;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp2_;
	BoxesWizardPage _tmp3_;
	BoxesWizardPage _tmp4_;
	BoxesWizardPage _tmp5_;
	gboolean _tmp16_;
	BoxesWizardPage _tmp33_;
	gboolean _tmp34_ = FALSE;
	BoxesWizardPage _tmp35_;
	GtkNotebook* _tmp36_;
	BoxesWizardPage _tmp37_;
	GPtrArray* _tmp51_;
	BoxesWizardPage _tmp52_;
	BoxesWizardPage _tmp53_;
	gconstpointer _tmp54_ = NULL;
	GtkStyleContext* _tmp55_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->back_button;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = value;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp1_ != BOXES_WIZARD_PAGE_INTRODUCTION);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = value;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_get_page (self);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp2_ > _tmp4_;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = value;
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_INTRODUCTION:
#line 5779 "wizard.c"
		{
			GtkButton* _tmp6_;
			GtkButton* _tmp7_;
			GtkButton* _tmp8_;
			GtkButton* _tmp9_;
			GtkButton* _tmp10_;
			GtkButton* _tmp11_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->create_button;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp6_, FALSE);
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->continue_button;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->continue_button;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _g_object_ref0 (_tmp8_);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->next_button);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->next_button = _tmp9_;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, TRUE);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->next_button;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp11_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5813 "wizard.c"
		}
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 5817 "wizard.c"
		{
			BoxesWizardSource* _tmp12_;
			BoxesWizardSource* _tmp13_;
			BoxesSourcePage _tmp14_;
			BoxesSourcePage _tmp15_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = self->priv->wizard_source;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = self->priv->wizard_source;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = boxes_wizard_source_get_page (_tmp13_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_page (_tmp12_, _tmp15_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5835 "wizard.c"
		}
		default:
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5840 "wizard.c"
	}
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = forwards;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_) {
#line 5846 "wizard.c"
		BoxesWizardPage _tmp17_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp17_ = value;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp17_) {
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SOURCE:
#line 5854 "wizard.c"
			{
				BoxesWizardSource* _tmp18_;
				BoxesWizardSource* _tmp19_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp18_ = self->priv->wizard_source;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_selected (_tmp18_, NULL);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = self->priv->wizard_source;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_page (_tmp19_, BOXES_SOURCE_PAGE_MAIN);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5868 "wizard.c"
			}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_PREPARATION:
#line 5872 "wizard.c"
			{
				gboolean _tmp20_ = FALSE;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = boxes_wizard_prepare (self);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp20_) {
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 5881 "wizard.c"
				}
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5885 "wizard.c"
			}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SETUP:
#line 5889 "wizard.c"
			{
				gboolean _tmp21_ = FALSE;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = boxes_wizard_setup (self);
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp21_) {
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 5898 "wizard.c"
				}
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5902 "wizard.c"
			}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5906 "wizard.c"
			{
				GtkButton* _tmp22_;
				GtkButton* _tmp23_;
				GtkButton* _tmp24_;
				GtkButton* _tmp25_;
				GtkButton* _tmp26_;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp22_ = self->priv->continue_button;
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp22_, FALSE);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp23_ = self->priv->create_button;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp23_, TRUE);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = self->priv->create_button;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp25_ = _g_object_ref0 (_tmp24_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp25_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp26_ = self->priv->next_button;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp26_, FALSE);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_review (self, __boxes_wizard_page_____lambda192__gasync_ready_callback, g_object_ref (self));
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5937 "wizard.c"
			}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_LAST:
#line 5941 "wizard.c"
			{
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_create (self, __boxes_wizard_page_____lambda194__gasync_ready_callback, g_object_ref (self));
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 5947 "wizard.c"
			}
			default:
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5952 "wizard.c"
		}
	} else {
		BoxesWizardPage _tmp27_;
		BoxesWizardPage _tmp28_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp27_ = boxes_wizard_get_page (self);
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp28_ = _tmp27_;
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp28_) {
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5965 "wizard.c"
			{
				GtkButton* _tmp29_;
				GtkButton* _tmp30_;
				GtkButton* _tmp31_;
				GtkButton* _tmp32_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp29_ = self->priv->create_button;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp29_, FALSE);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp30_ = self->priv->continue_button;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp30_, TRUE);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp31_ = self->priv->continue_button;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp32_ = _g_object_ref0 (_tmp31_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp32_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_destroy_machine (self);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5991 "wizard.c"
			}
			default:
#line 105 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5996 "wizard.c"
		}
	}
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp33_ = value;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp34_ = boxes_wizard_skip_page (self, _tmp33_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp34_) {
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6007 "wizard.c"
	}
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp35_ = value;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_page = _tmp35_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp36_ = self->priv->notebook;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp37_ = value;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_notebook_set_current_page (_tmp36_, (gint) _tmp37_);
#line 6019 "wizard.c"
	{
		gint i = 0;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		i = 0;
#line 6024 "wizard.c"
		{
			gboolean _tmp38_ = FALSE;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp38_ = TRUE;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			while (TRUE) {
#line 6031 "wizard.c"
				gboolean _tmp39_;
				gint _tmp41_;
				GPtrArray* _tmp42_;
				gint _tmp43_;
				gint _tmp44_;
				GtkLabel* label = NULL;
				GPtrArray* _tmp45_;
				gint _tmp46_;
				gconstpointer _tmp47_ = NULL;
				GtkLabel* _tmp48_;
				GtkLabel* _tmp49_;
				GtkStyleContext* _tmp50_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp39_ = _tmp38_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp39_) {
#line 6048 "wizard.c"
					gint _tmp40_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp40_ = i;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					i = _tmp40_ + 1;
#line 6054 "wizard.c"
				}
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp38_ = FALSE;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp41_ = i;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp42_ = self->priv->steps;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp43_ = g_ptr_array_get_length (_tmp42_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp44_ = _tmp43_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!(_tmp41_ < _tmp44_)) {
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 6070 "wizard.c"
				}
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp45_ = self->priv->steps;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp46_ = i;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp47_ = g_ptr_array_index (_tmp45_, (guint) _tmp46_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp48_ = _g_object_ref0 ((GtkLabel*) _tmp47_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				label = _tmp48_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp49_ = label;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp50_ = gtk_widget_get_style_context ((GtkWidget*) _tmp49_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_style_context_remove_class (_tmp50_, "boxes-wizard-current-page-label");
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (label);
#line 6090 "wizard.c"
			}
		}
	}
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp51_ = self->priv->steps;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp52_ = boxes_wizard_get_page (self);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp53_ = _tmp52_;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp54_ = g_ptr_array_index (_tmp51_, (guint) _tmp53_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp55_ = gtk_widget_get_style_context ((GtkWidget*) ((GtkLabel*) _tmp54_));
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp55_, "boxes-wizard-current-page-label");
#line 6106 "wizard.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 6113 "wizard.c"
}


static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizard * self;
	GPtrArray* _tmp0_;
	GPtrArray* _tmp1_;
	BoxesMediaManager* _tmp2_ = NULL;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_parent_class);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = g_ptr_array_new_with_free_func (_g_object_unref0_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_ptr_array_unref0 (self->priv->steps);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->steps = _tmp0_;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->steps;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_ptr_array_set_length (_tmp1_, (gint) BOXES_WIZARD_PAGE_LAST);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_media_manager_get_instance ();
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->media_manager = _tmp2_;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return obj;
#line 6148 "wizard.c"
}


static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_construct (GType object_type) {
	BoxesWizardWizardSummary * self = NULL;
	GtkGrid* _tmp0_;
	GtkGrid* _tmp1_;
	GtkGrid* _tmp2_;
#line 735 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizardWizardSummary*) g_object_new (object_type, NULL);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp0_);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->grid);
#line 736 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->grid = _tmp0_;
#line 737 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->grid;
#line 737 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_set_row_spacing (_tmp1_, 10);
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->grid;
#line 738 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_set_column_spacing (_tmp2_, 20);
#line 739 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 741 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_clear (self);
#line 735 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 6181 "wizard.c"
}


static BoxesWizardWizardSummary* boxes_wizard_wizard_summary_new (void) {
#line 735 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_wizard_summary_construct (BOXES_WIZARD_TYPE_WIZARD_SUMMARY);
#line 6188 "wizard.c"
}


static void boxes_wizard_wizard_summary_add_property (BoxesWizardWizardSummary* self, const gchar* name, const gchar* value) {
	const gchar* _tmp0_;
	GtkLabel* label_name = NULL;
	const gchar* _tmp1_;
	GtkLabel* _tmp2_;
	GtkLabel* _tmp3_;
	GtkStyleContext* _tmp4_ = NULL;
	GtkLabel* _tmp5_;
	GtkGrid* _tmp6_;
	GtkLabel* _tmp7_;
	gint _tmp8_;
	GtkLabel* label_value = NULL;
	const gchar* _tmp9_;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	GtkStyleContext* _tmp12_ = NULL;
	GtkLabel* _tmp13_;
	GtkLabel* _tmp14_;
	GtkGrid* _tmp15_;
	GtkLabel* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GtkGrid* _tmp19_;
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (name != NULL);
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 745 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 746 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6225 "wizard.c"
	}
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = name;
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 748 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_name = _tmp2_;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = label_name;
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 749 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-wizard-summary-prop-name-label");
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = label_name;
#line 750 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp5_, "xalign", 1.0f, NULL);
#line 751 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->grid;
#line 751 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = label_name;
#line 751 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->current_row;
#line 751 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach (_tmp6_, (GtkWidget*) _tmp7_, 0, _tmp8_, 1, 1);
#line 753 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = value;
#line 753 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = (GtkLabel*) gtk_label_new (_tmp9_);
#line 753 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp10_);
#line 753 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_value = _tmp10_;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = label_value;
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 754 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp12_, "boxes-wizard-summary-prop-value-label");
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = label_value;
#line 755 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_ellipsize (_tmp13_, PANGO_ELLIPSIZE_END);
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = label_value;
#line 756 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp14_, "xalign", 0.0f, NULL);
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = self->priv->grid;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = label_value;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = self->priv->current_row;
#line 757 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach (_tmp15_, (GtkWidget*) _tmp16_, 1, _tmp17_, 1, 1);
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = self->priv->current_row;
#line 759 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = _tmp18_ + 1;
#line 760 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = self->priv->grid;
#line 760 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp19_);
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_value);
#line 744 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_name);
#line 6295 "wizard.c"
}


static Block77Data* block77_data_ref (Block77Data* _data77_) {
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data77_->_ref_count_);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data77_;
#line 6304 "wizard.c"
}


static void block77_data_unref (void * _userdata_) {
	Block77Data* _data77_;
	_data77_ = (Block77Data*) _userdata_;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data77_->_ref_count_)) {
#line 6313 "wizard.c"
		BoxesWizardWizardSummary * self;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data77_->self;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block77Data, _data77_);
#line 6321 "wizard.c"
	}
}


static void __lambda185_ (Block77Data* _data77_) {
	BoxesWizardWizardSummary * self;
	BoxesWizardWizardSummaryCustomizeFunc _tmp0_;
	void* _tmp0__target;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data77_->self;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _data77_->customize_func;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = _data77_->customize_func_target;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ (_tmp0__target);
#line 6338 "wizard.c"
}


static void ___lambda185__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda185_ (self);
#line 6345 "wizard.c"
}


static void boxes_wizard_wizard_summary_append_customize_button (BoxesWizardWizardSummary* self, BoxesWizardWizardSummaryCustomizeFunc customize_func, void* customize_func_target) {
	Block77Data* _data77_;
	BoxesWizardWizardSummaryCustomizeFunc _tmp0_;
	void* _tmp0__target;
	gint _tmp1_;
	GtkButton* button = NULL;
	const gchar* _tmp2_ = NULL;
	GtkButton* _tmp3_;
	GtkButton* _tmp4_;
	GtkStyleContext* _tmp5_ = NULL;
	GtkGrid* _tmp6_;
	GtkButton* _tmp7_;
	gint _tmp8_;
	GtkButton* _tmp9_;
	GtkButton* _tmp10_;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_ = g_slice_new0 (Block77Data);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_->_ref_count_ = 1;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_->self = g_object_ref (self);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = customize_func;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = customize_func_target;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_->customize_func = _tmp0_;
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_->customize_func_target = _tmp0__target;
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->current_row;
#line 765 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == 0) {
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		block77_data_unref (_data77_);
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data77_ = NULL;
#line 766 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6390 "wizard.c"
	}
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _ ("C_ustomize...");
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp2_);
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp3_);
#line 768 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	button = _tmp3_;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = button;
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 769 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp5_, "boxes-wizard-summary-customize-button");
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = self->priv->grid;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = button;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->current_row;
#line 770 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach (_tmp6_, (GtkWidget*) _tmp7_, 2, _tmp8_ - 1, 1, 1);
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = button;
#line 771 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show ((GtkWidget*) _tmp9_);
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = button;
#line 773 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data (_tmp10_, "clicked", (GCallback) ___lambda185__gtk_button_clicked, block77_data_ref (_data77_), (GClosureNotify) block77_data_unref, 0);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (button);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	block77_data_unref (_data77_);
#line 763 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data77_ = NULL;
#line 6428 "wizard.c"
}


static void boxes_wizard_wizard_summary_clear (BoxesWizardWizardSummary* self) {
	GtkGrid* _tmp0_;
	GList* _tmp1_ = NULL;
#line 776 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->grid;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 6441 "wizard.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		child_collection = _tmp1_;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 6449 "wizard.c"
			GtkWidget* child = NULL;
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
			child = (GtkWidget*) child_it->data;
#line 6453 "wizard.c"
			{
				GtkGrid* _tmp2_;
				GtkWidget* _tmp3_;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp2_ = self->priv->grid;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp3_ = child;
#line 778 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_container_remove ((GtkContainer*) _tmp2_, _tmp3_);
#line 6463 "wizard.c"
			}
		}
#line 777 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_list_free0 (child_collection);
#line 6468 "wizard.c"
	}
#line 781 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 6472 "wizard.c"
}


static GtkWidget* boxes_wizard_wizard_summary_get_widget (BoxesWizardWizardSummary* self) {
	GtkWidget* result;
	GtkGrid* _tmp0_;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->grid;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = (GtkWidget*) _tmp0_;
#line 731 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 6487 "wizard.c"
}


static void boxes_wizard_wizard_summary_class_init (BoxesWizardWizardSummaryClass * klass) {
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_summary_parent_class = g_type_class_peek_parent (klass);
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardWizardSummaryPrivate));
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_wizard_summary_get_property;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_wizard_summary_finalize;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_WIZARD_SUMMARY_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6502 "wizard.c"
}


static void boxes_wizard_wizard_summary_instance_init (BoxesWizardWizardSummary * self) {
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_WIZARD_SUMMARY_GET_PRIVATE (self);
#line 6509 "wizard.c"
}


static void boxes_wizard_wizard_summary_finalize (GObject* obj) {
	BoxesWizardWizardSummary * self;
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary);
#line 732 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->grid);
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_wizard_summary_parent_class)->finalize (obj);
#line 6521 "wizard.c"
}


static GType boxes_wizard_wizard_summary_get_type (void) {
	static volatile gsize boxes_wizard_wizard_summary_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_wizard_summary_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardWizardSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_wizard_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardWizardSummary), 0, (GInstanceInitFunc) boxes_wizard_wizard_summary_instance_init, NULL };
		GType boxes_wizard_wizard_summary_type_id;
		boxes_wizard_wizard_summary_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesWizardWizardSummary", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_wizard_summary_type_id__volatile, boxes_wizard_wizard_summary_type_id);
	}
	return boxes_wizard_wizard_summary_type_id__volatile;
}


static void _vala_boxes_wizard_wizard_summary_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardWizardSummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_WIZARD_TYPE_WIZARD_SUMMARY, BoxesWizardWizardSummary);
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_WIZARD_SUMMARY_WIDGET:
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_wizard_summary_get_widget (self));
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6548 "wizard.c"
		default:
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 728 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6554 "wizard.c"
	}
}


static void boxes_wizard_class_init (BoxesWizardClass * klass) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_parent_class = g_type_class_peek_parent (klass);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardPrivate));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_wizard_real_ui_state_changed;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_wizard_real_get_actor;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_get_property;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_set_property;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_constructor;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_finalize;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_MACHINE, g_param_spec_object ("machine", "machine", "machine", BOXES_TYPE_MACHINE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6580 "wizard.c"
}


static void boxes_wizard_instance_init (BoxesWizard * self) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_GET_PRIVATE (self);
#line 6587 "wizard.c"
}


static void boxes_wizard_finalize (GObject* obj) {
	BoxesWizard * self;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_ptr_array_unref0 (self->priv->steps);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->notebook);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->toolbar_sizegroup);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_media_label);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_status_label);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_vbox);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_label);
#line 34 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 350 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_cancellable);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_parent_class)->finalize (obj);
#line 6643 "wizard.c"
}


GType boxes_wizard_get_type (void) {
	static volatile gsize boxes_wizard_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizard), 0, (GInstanceInitFunc) boxes_wizard_instance_init, NULL };
		GType boxes_wizard_type_id;
		boxes_wizard_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesWizard", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_type_id__volatile, boxes_wizard_type_id);
	}
	return boxes_wizard_type_id__volatile;
}


static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_ACTOR:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_get_machine (self));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6676 "wizard.c"
		default:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6682 "wizard.c"
	}
}


static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, g_value_get_object (value));
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6698 "wizard.c"
		default:
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 6704 "wizard.c"
	}
}



