/* libvirt-machine-properties.c generated by valac 0.20.1.16-ff48-dirty, the Vala compiler
 * generated from libvirt-machine-properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libcommon.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <clutter/clutter.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gdk/gdk.h>
#include <config.h>
#include <pango/pango.h>
#include <osinfo/osinfo.h>
#include <libgd/gd.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;
typedef struct _BoxesLibvirtMachinePropertiesPrivate BoxesLibvirtMachinePropertiesPrivate;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _Block28Data Block28Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _Block29Data Block29Data;
typedef struct _Block30Data Block30Data;
typedef struct _Block31Data Block31Data;
typedef struct _Block32Data Block32Data;
typedef struct _Block33Data Block33Data;
typedef struct _Block34Data Block34Data;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData;
typedef struct _Block35Data Block35Data;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _Block36Data Block36Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _Block37Data Block37Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block38Data Block38Data;

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesLibvirtMachineProperties {
	GObject parent_instance;
	BoxesLibvirtMachinePropertiesPrivate * priv;
};

struct _BoxesLibvirtMachinePropertiesClass {
	GObjectClass parent_class;
};

struct _BoxesLibvirtMachinePropertiesPrivate {
	BoxesLibvirtMachine* machine;
	guint shutdown_timeout;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block28Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	gchar* log;
	GtkDialog* dialog;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block29Data {
	int _ref_count_;
	Block28Data * _data28_;
	GtkFileChooserDialog* chooser;
};

struct _Block30Data {
	int _ref_count_;
	Block29Data * _data29_;
	GtkMessageDialog* m;
};

struct _Block31Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	BoxesProperty* property;
};

struct _Block32Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	BoxesProperty* property;
};

struct _Block33Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	GtkLabel* label;
	gboolean empty;
	GtkLabel* button_label;
	GVirConfigDomainDisk* disk_config;
};

struct _Block34Data {
	int _ref_count_;
	Block33Data * _data33_;
	GtkFileChooserDialog* dialog;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* ram_property;
	BoxesSizeProperty* storage_property;
	gboolean _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	gboolean _tmp3_;
	gchar* os_id;
	BoxesLibvirtMachine* _tmp4_;
	GVirConfigDomain* _tmp5_;
	GVirConfigDomain* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	BoxesOSDatabase* os_db;
	BoxesMediaManager* _tmp9_;
	BoxesMediaManager* _tmp10_;
	BoxesOSDatabase* _tmp11_;
	BoxesOSDatabase* _tmp12_;
	BoxesOSDatabase* _tmp13_;
	BoxesOSDatabase* _tmp14_;
	OsinfoOs* os;
	OsinfoOs* _tmp15_;
	BoxesOSDatabase* _tmp16_;
	const gchar* _tmp17_;
	OsinfoOs* _tmp18_;
	GError* _error_;
	const gchar* _tmp19_;
	GError* _tmp20_;
	const gchar* _tmp21_;
	gchar* architecture;
	BoxesLibvirtMachine* _tmp22_;
	GVirConfigDomain* _tmp23_;
	GVirConfigDomain* _tmp24_;
	GVirConfigDomainOs* _tmp25_;
	GVirConfigDomainOs* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	OsinfoResources* resources;
	BoxesOSDatabase* _tmp30_;
	OsinfoOs* _tmp31_;
	const gchar* _tmp32_;
	OsinfoResources* _tmp33_;
	OsinfoResources* _tmp34_;
	BoxesSizeProperty* _tmp35_;
	BoxesSizeProperty* _tmp36_;
	OsinfoResources* _tmp37_;
	gint64 _tmp38_;
	gint64 _tmp39_;
	BoxesSizeProperty* _tmp40_;
	BoxesSizeProperty* _tmp41_;
	OsinfoResources* _tmp42_;
	gint64 _tmp43_;
	gint64 _tmp44_;
	GError * _inner_error_;
};

struct _Block35Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	BoxesSizeProperty* property;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _Block36Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	BoxesProperty* property;
	guint64 value;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef void (*BoxesNotificationbarOKFunc) (void* user_data);
typedef void (*BoxesNotificationbarCancelFunc) (void* user_data);
struct _Block37Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	gulong state_id;
	GdNotification* notification;
};

struct _Block38Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties * self;
	guint64 value;
};


static gpointer boxes_libvirt_machine_properties_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface* boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesPrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_PROPERTIES_DUMMY_PROPERTY
};
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES ((guint64) (1000 * 1000))
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_remove_usb_controllers (GVirConfigDomain* domain, GError** error);
void boxes_vm_configurator_add_usb_support (GVirConfigDomain* domain);
static void boxes_libvirt_machine_properties_notify_reboot_required (BoxesLibvirtMachineProperties* self);
void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_add_smartcard_support (GVirConfigDomain* domain);
static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self);
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
const gchar* gvir_domain_state_to_string (GVirDomainState self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_string_property_set_editable (BoxesStringProperty* self, gboolean value);
static gboolean ___lambda128_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name);
static gboolean ____lambda128__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self);
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
gchar* boxes_display_get_uri (BoxesDisplay* self);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list);
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list);
static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void ___lambda132_ (BoxesLibvirtMachineProperties* self);
static Block28Data* block28_data_ref (Block28Data* _data28_);
static void block28_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void __lambda133_ (Block28Data* _data28_, gint response_id);
static Block29Data* block29_data_ref (Block29Data* _data29_);
static void block29_data_unref (void * _userdata_);
static void ___lambda134_ (Block29Data* _data29_, gint response_id);
static Block30Data* block30_data_ref (Block30Data* _data30_);
static void block30_data_unref (void * _userdata_);
static void ____lambda135_ (Block30Data* _data30_);
static void _____lambda135__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda134__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda133__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list);
static Block31Data* block31_data_ref (Block31Data* _data31_);
static void block31_data_unref (void * _userdata_);
static void ____lambda138_ (Block31Data* _data31_);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
static void _____lambda138__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block32Data* block32_data_ref (Block32Data* _data32_);
static void block32_data_unref (void * _userdata_);
static void ____lambda139_ (Block32Data* _data32_);
static void _____lambda139__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block33Data* block33_data_ref (Block33Data* _data33_);
static void block33_data_unref (void * _userdata_);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
static void __lambda136_ (Block33Data* _data33_);
static Block34Data* block34_data_ref (Block34Data* _data34_);
static void block34_data_unref (void * _userdata_);
static void ___lambda137_ (Block34Data* _data34_, gint response);
static void ____lambda137__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda136__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_recommended_resources_for_os (BoxesOSDatabase* self, OsinfoOs* os, const gchar* architecture);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 step, GFormatSizeFlags format_flags);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void ___lambda130_ (Block35Data* _data35_);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void ____lambda130__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block36Data* block36_data_ref (Block36Data* _data36_);
static void block36_data_unref (void * _userdata_);
static gboolean __lambda129_ (Block36Data* _data36_);
static gboolean ___lambda129__gsource_func (gpointer self);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationbarOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationbarCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void boxes_libvirt_machine_properties_reboot (BoxesLibvirtMachineProperties* self);
static void _boxes_libvirt_machine_properties_reboot_boxes_notificationbar_ok_func (gpointer self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static Block37Data* block37_data_ref (Block37Data* _data37_);
static void block37_data_unref (void * _userdata_);
void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ___lambda103_ (BoxesLibvirtMachineProperties* self, GObject* obj, GAsyncResult* res);
static void ____lambda103__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda104_ (Block37Data* _data37_);
static void ___lambda105_ (BoxesLibvirtMachineProperties* self, GObject* obj, GAsyncResult* res);
static void ____lambda105__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda104__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda106_ (Block37Data* _data37_);
static void __lambda107_ (Block37Data* _data37_);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
static void ___lambda107__boxes_notificationbar_ok_func (gpointer self);
static gboolean ___lambda106__gsource_func (gpointer self);
void boxes_libvirt_machine_try_shutdown (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static Block38Data* block38_data_ref (Block38Data* _data38_);
static void block38_data_unref (void * _userdata_);
static gboolean __lambda131_ (Block38Data* _data38_);
gboolean boxes_machine_is_running (BoxesMachine* self);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static gboolean ___lambda131__gsource_func (gpointer self);
static void boxes_libvirt_machine_properties_finalize (GObject* obj);


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachineProperties * self = NULL;
	BoxesLibvirtMachine* _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) g_object_new (object_type, NULL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->machine = _tmp0_;
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self;
#line 796 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine) {
#line 11 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return boxes_libvirt_machine_properties_construct (BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, machine);
#line 803 "libvirt-machine-properties.c"
}


gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 814 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_;
		GVirDomain* _tmp1_;
		GVirDomain* _tmp2_;
		GVirConfigDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_;
		const gchar* _tmp5_;
		BoxesLibvirtMachine* _tmp6_;
		GVirDomain* _tmp7_;
		GVirDomain* _tmp8_;
		GVirConfigDomain* _tmp9_;
		BoxesLibvirtMachine* _tmp10_;
		const gchar* _tmp11_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 841 "libvirt-machine-properties.c"
			goto __catch24_g_error;
		}
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = config;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = name;
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_title (_tmp4_, _tmp5_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = self->priv->machine;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = config;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 864 "libvirt-machine-properties.c"
			goto __catch24_g_error;
		}
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = name;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_collection_item_set_name ((BoxesCollectionItem*) _tmp10_, _tmp11_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = TRUE;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 879 "libvirt-machine-properties.c"
	}
	goto __finally24;
	__catch24_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_;
		GVirDomain* _tmp13_;
		GVirDomain* _tmp14_;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_;
		GError* _tmp17_;
		const gchar* _tmp18_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = gvir_domain_get_name (_tmp14_);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = name;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _error_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_->message;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:26: Failed to change title of box '%s'" \
" to '%s': %s", _tmp15_, _tmp16_, _tmp18_);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 918 "libvirt-machine-properties.c"
	}
	__finally24:
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 927 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomain* _tmp2_;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_;
	GVirConfigDomain* _tmp5_;
	BoxesLibvirtMachine* _tmp6_;
	GVirDomain* _tmp7_;
	GVirDomain* _tmp8_;
	GVirConfigDomain* _tmp9_;
	GError * _inner_error_ = NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 962 "libvirt-machine-properties.c"
	}
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_remove_usb_controllers (_tmp4_, &_inner_error_);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 976 "libvirt-machine-properties.c"
	}
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = config;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_usb_support (_tmp5_);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = self->priv->machine;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _tmp7_;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = config;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1000 "libvirt-machine-properties.c"
	}
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_notify_reboot_required (self);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1006 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomain* _tmp2_;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_;
	BoxesLibvirtMachine* _tmp5_;
	GVirDomain* _tmp6_;
	GVirDomain* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GError * _inner_error_ = NULL;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1040 "libvirt-machine-properties.c"
	}
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_smartcard_support (_tmp4_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = config;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp7_, _tmp8_, &_inner_error_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1064 "libvirt-machine-properties.c"
	}
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_notify_reboot_required (self);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1070 "libvirt-machine-properties.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1077 "libvirt-machine-properties.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 1084 "libvirt-machine-properties.c"
}


static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_;
	GString* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirDomain* _tmp3_;
	GVirDomain* _tmp4_;
	const gchar* _tmp5_ = NULL;
	GString* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirDomain* _tmp8_;
	GVirDomain* _tmp9_;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	BoxesLibvirtMachine* _tmp12_;
	GVirDomain* _tmp13_;
	GVirDomain* _tmp14_;
	gboolean _tmp15_ = FALSE;
	GString* _tmp16_;
	const gchar* _tmp17_;
	BoxesLibvirtMachine* _tmp43_;
	BoxesDisplay* _tmp44_;
	BoxesDisplay* _tmp45_;
	GString* _tmp74_;
	const gchar* _tmp75_;
	gchar* _tmp76_;
	GError * _inner_error_ = NULL;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = g_string_new ("");
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	builder = _tmp0_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = builder;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp1_, "Domain: %s\n", _tmp5_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = builder;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = self->priv->machine;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = boxes_libvirt_machine_get_domain (_tmp7_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _tmp8_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_domain_get_uuid (_tmp9_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp6_, "UUID: %s\n", _tmp10_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = self->priv->machine;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = gvir_domain_get_persistent (_tmp14_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "yes";
#line 1158 "libvirt-machine-properties.c"
	} else {
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "no";
#line 1162 "libvirt-machine-properties.c"
	}
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = builder;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp17_ = _tmp11_;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp16_, "Persistent: %s\n", _tmp17_);
#line 1170 "libvirt-machine-properties.c"
	{
		GVirDomainInfo* info = NULL;
		BoxesLibvirtMachine* _tmp18_;
		GVirDomain* _tmp19_;
		GVirDomain* _tmp20_;
		GVirDomainInfo* _tmp21_ = NULL;
		GString* _tmp22_;
		GVirDomainInfo* _tmp23_;
		guint64 _tmp24_;
		GString* _tmp25_;
		GVirDomainInfo* _tmp26_;
		guint64 _tmp27_;
		GVirNodeInfo* _tmp28_ = NULL;
		BoxesLibvirtMachine* _tmp29_;
		GVirConnection* _tmp30_;
		GVirConnection* _tmp31_;
		GVirNodeInfo* _tmp32_ = NULL;
		GString* _tmp33_;
		GVirNodeInfo* _tmp34_;
		gulong _tmp35_;
		GString* _tmp36_;
		GVirDomainInfo* _tmp37_;
		guint16 _tmp38_;
		GString* _tmp39_;
		GVirDomainInfo* _tmp40_;
		GVirDomainState _tmp41_;
		GEnumValue* _tmp42_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = self->priv->machine;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_libvirt_machine_get_domain (_tmp18_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = gvir_domain_get_info (_tmp20_, &_inner_error_);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		info = _tmp21_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 1210 "libvirt-machine-properties.c"
			goto __catch25_g_error;
		}
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = builder;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = info;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_->cpuTime;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp22_, "Cpu time: %" G_GINT64_MODIFIER "d\n", _tmp24_);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = builder;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = info;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp26_->memory;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp25_, "Memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp27_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = self->priv->machine;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_libvirt_machine_get_connection (_tmp29_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = gvir_connection_get_node_info (_tmp31_, &_inner_error_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = _tmp32_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirDomainInfo_free0 (info);
#line 1243 "libvirt-machine-properties.c"
			goto __catch25_g_error;
		}
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = builder;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _tmp28_;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _tmp34_->memory;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp33_, "Max memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp35_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp34_);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = builder;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = info;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_->nrVirtCpu;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp36_, "CPUs: %d\n", (gint) _tmp38_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = builder;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = info;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _tmp40_->state;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = g_enum_get_value (g_type_class_ref (gvir_domain_state_get_type ()), _tmp41_);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp39_, "State: %s\n", (_tmp42_ != NULL) ? _tmp42_->value_name : NULL);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirDomainInfo_free0 (info);
#line 1276 "libvirt-machine-properties.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* e = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1288 "libvirt-machine-properties.c"
	}
	__finally25:
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1301 "libvirt-machine-properties.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp43_ = self->priv->machine;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp44_ = boxes_machine_get_display ((BoxesMachine*) _tmp43_);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp45_ = _tmp44_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp45_ != NULL) {
#line 1311 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp46_;
		BoxesDisplay* _tmp47_;
		BoxesDisplay* _tmp48_;
		GString* _tmp49_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = self->priv->machine;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = boxes_machine_get_display ((BoxesMachine*) _tmp46_);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = _tmp47_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp49_ = builder;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_display_collect_logs (_tmp48_, _tmp49_);
#line 1326 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* conf = NULL;
		BoxesLibvirtMachine* _tmp50_;
		GVirDomain* _tmp51_;
		GVirDomain* _tmp52_;
		GVirConfigDomain* _tmp53_ = NULL;
		GString* _tmp54_;
		GString* _tmp55_;
		GString* _tmp56_;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_;
		GString* _tmp59_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp50_ = self->priv->machine;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp51_ = boxes_libvirt_machine_get_domain (_tmp50_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = _tmp51_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = gvir_domain_get_config (_tmp52_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		conf = _tmp53_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 1352 "libvirt-machine-properties.c"
			goto __catch26_g_error;
		}
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = builder;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp54_, "\nDomain config:\n");
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = builder;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp55_, "------------------------------------------------------------\n");
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = builder;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = gvir_config_object_to_xml ((GVirConfigObject*) conf);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _tmp57_;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp56_, _tmp58_);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp58_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = builder;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp59_, "%s", "\n" "------------------------------------------------------------\n");
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (conf);
#line 1379 "libvirt-machine-properties.c"
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* _error_ = NULL;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1391 "libvirt-machine-properties.c"
	}
	__finally26:
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1404 "libvirt-machine-properties.c"
	}
	{
		gchar* logfile = NULL;
		const gchar* _tmp60_ = NULL;
		BoxesLibvirtMachine* _tmp61_;
		GVirDomain* _tmp62_;
		GVirDomain* _tmp63_;
		const gchar* _tmp64_ = NULL;
		gchar* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_;
		gchar* data = NULL;
		gchar* _tmp69_ = NULL;
		GString* _tmp70_;
		GString* _tmp71_;
		GString* _tmp72_;
		GString* _tmp73_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = g_get_user_cache_dir ();
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = self->priv->machine;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = boxes_libvirt_machine_get_domain (_tmp61_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = _tmp62_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = gvir_domain_get_name (_tmp63_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = g_strconcat (_tmp64_, ".log", NULL);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = _tmp65_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = g_build_filename (_tmp60_, "libvirt/qemu/log", _tmp66_, NULL);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = _tmp67_;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp66_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		logfile = _tmp68_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_file_get_contents (logfile, &_tmp69_, NULL, &_inner_error_);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		data = _tmp69_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (data);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (logfile);
#line 1457 "libvirt-machine-properties.c"
			goto __catch27_g_error;
		}
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = builder;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp70_, "\nQEMU log:\n");
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = builder;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp71_, "------------------------------------------------------------\n");
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = builder;
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp72_, data);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = builder;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp73_, "------------------------------------------------------------\n");
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (logfile);
#line 1480 "libvirt-machine-properties.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* e = NULL;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1492 "libvirt-machine-properties.c"
	}
	__finally27:
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1505 "libvirt-machine-properties.c"
	}
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp74_ = builder;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp75_ = _tmp74_->str;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp76_ = g_strdup (_tmp75_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp76_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_string_free0 (builder);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1519 "libvirt-machine-properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1526 "libvirt-machine-properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_free (self);
#line 1535 "libvirt-machine-properties.c"
}


static gboolean ___lambda128_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (property != NULL, FALSE);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = name;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_properties_try_change_name (self, _tmp0_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp1_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1555 "libvirt-machine-properties.c"
}


static gboolean ____lambda128__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self) {
	gboolean result;
	result = ___lambda128_ (self, _sender, value);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1564 "libvirt-machine-properties.c"
}


static Block28Data* block28_data_ref (Block28Data* _data28_) {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data28_->_ref_count_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data28_;
#line 1573 "libvirt-machine-properties.c"
}


static void block28_data_unref (void * _userdata_) {
	Block28Data* _data28_;
	_data28_ = (Block28Data*) _userdata_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data28_->_ref_count_)) {
#line 1582 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data28_->self;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data28_->dialog);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data28_->log);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block28Data, _data28_);
#line 1594 "libvirt-machine-properties.c"
	}
}


static Block29Data* block29_data_ref (Block29Data* _data29_) {
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data29_->_ref_count_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data29_;
#line 1604 "libvirt-machine-properties.c"
}


static void block29_data_unref (void * _userdata_) {
	Block29Data* _data29_;
	_data29_ = (Block29Data*) _userdata_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data29_->_ref_count_)) {
#line 1613 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data29_->_data28_->self;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data29_->chooser);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block28_data_unref (_data29_->_data28_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_data28_ = NULL;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block29Data, _data29_);
#line 1625 "libvirt-machine-properties.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 1633 "libvirt-machine-properties.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1260 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1261 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1261 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1261 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1262 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1262 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1262 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1262 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 1677 "libvirt-machine-properties.c"
	}
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1263 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 1683 "libvirt-machine-properties.c"
}


static Block30Data* block30_data_ref (Block30Data* _data30_) {
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data30_->_ref_count_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data30_;
#line 1692 "libvirt-machine-properties.c"
}


static void block30_data_unref (void * _userdata_) {
	Block30Data* _data30_;
	_data30_ = (Block30Data*) _userdata_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data30_->_ref_count_)) {
#line 1701 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data30_->_data29_->_data28_->self;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data30_->m);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block29_data_unref (_data30_->_data29_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data30_->_data29_ = NULL;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block30Data, _data30_);
#line 1713 "libvirt-machine-properties.c"
	}
}


static void ____lambda135_ (Block30Data* _data30_) {
	Block29Data* _data29_;
	Block28Data* _data28_;
	BoxesLibvirtMachineProperties * self;
	GtkMessageDialog* _tmp0_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data29_ = _data30_->_data29_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = _data29_->_data28_;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data30_->m;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp0_);
#line 1733 "libvirt-machine-properties.c"
}


static void _____lambda135__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda135_ (self);
#line 1740 "libvirt-machine-properties.c"
}


static void ___lambda134_ (Block29Data* _data29_, gint response_id) {
	Block28Data* _data28_;
	BoxesLibvirtMachineProperties * self;
	gint _tmp0_;
	GError * _inner_error_ = NULL;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = _data29_->_data28_;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 1757 "libvirt-machine-properties.c"
		GFile* file = NULL;
		GtkFileChooserDialog* _tmp1_;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_;
		GtkFileChooserDialog* _tmp17_;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data29_->chooser;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_file ((GtkFileChooser*) _tmp1_);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		file = _tmp3_;
#line 1771 "libvirt-machine-properties.c"
		{
			GFile* _tmp4_;
			guint8* _tmp5_;
			gint _tmp5__length1;
			guint8* _tmp6_;
			gint _tmp6__length1;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp4_ = file;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = string_get_data (_data28_->log, &_tmp5__length1);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = _tmp5_;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6__length1 = _tmp5__length1;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_file_replace_contents (_tmp4_, _tmp6_, (gsize) _tmp6__length1, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION, NULL, NULL, &_inner_error_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 1790 "libvirt-machine-properties.c"
				goto __catch29_g_error;
			}
		}
		goto __finally29;
		__catch29_g_error:
		{
			GError* e = NULL;
			Block30Data* _data30_;
			GtkFileChooserDialog* _tmp7_;
			const gchar* _tmp8_ = NULL;
			GError* _tmp9_;
			const gchar* _tmp10_;
			gchar* _tmp11_ = NULL;
			gchar* _tmp12_;
			GtkMessageDialog* _tmp13_;
			GtkMessageDialog* _tmp14_;
			GtkMessageDialog* _tmp15_;
			GtkMessageDialog* _tmp16_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_ = g_slice_new0 (Block30Data);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->_ref_count_ = 1;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->_data29_ = block29_data_ref (_data29_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _data29_->chooser;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _ ("Error saving: %s");
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = e;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _tmp9_->message;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = g_strdup_printf (_tmp8_, _tmp10_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = _tmp11_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp7_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _tmp12_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp13_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp12_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->m = _tmp14_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = _data30_->m;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_show_all ((GtkWidget*) _tmp15_);
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data30_->m;
#line 173 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GtkDialog*) _tmp16_, "response", (GCallback) _____lambda135__gtk_dialog_response, block30_data_ref (_data30_), (GClosureNotify) block30_data_unref, 0);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block30_data_unref (_data30_);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_ = NULL;
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 174 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1859 "libvirt-machine-properties.c"
		}
		__finally29:
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1872 "libvirt-machine-properties.c"
		}
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data29_->chooser;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp17_);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (file);
#line 1880 "libvirt-machine-properties.c"
	} else {
		GtkFileChooserDialog* _tmp18_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _data29_->chooser;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp18_);
#line 1887 "libvirt-machine-properties.c"
	}
}


static void ____lambda134__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda134_ (self, response_id);
#line 1895 "libvirt-machine-properties.c"
}


static void __lambda133_ (Block28Data* _data28_, gint response_id) {
	BoxesLibvirtMachineProperties * self;
	gint _tmp0_;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == 100) {
#line 1908 "libvirt-machine-properties.c"
		Block29Data* _data29_;
		const gchar* _tmp1_ = NULL;
		BoxesApp* _tmp2_;
		GtkApplicationWindow* _tmp3_;
		GtkFileChooserDialog* _tmp4_;
		GtkFileChooserDialog* _tmp5_;
		GtkFileChooserDialog* _tmp6_;
		GtkFileChooserDialog* _tmp7_;
		GtkFileChooserDialog* _tmp8_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_ = g_slice_new0 (Block29Data);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_ref_count_ = 1;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_data28_ = block28_data_ref (_data28_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Save log");
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_app_app;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_->window;
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp3_, GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp4_);
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->chooser = _tmp4_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data29_->chooser;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp5_, FALSE);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data29_->chooser;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_do_overwrite_confirmation ((GtkFileChooser*) _tmp6_, TRUE);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data29_->chooser;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp7_, "response", (GCallback) ____lambda134__gtk_dialog_response, block29_data_ref (_data29_), (GClosureNotify) block29_data_unref, 0);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data29_->chooser;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp8_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block29_data_unref (_data29_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_ = NULL;
#line 1956 "libvirt-machine-properties.c"
	} else {
		gint _tmp9_;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = response_id;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ == 101) {
#line 1963 "libvirt-machine-properties.c"
			GdkDisplay* _tmp10_ = NULL;
			GtkClipboard* _tmp11_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = gtk_widget_get_display ((GtkWidget*) _data28_->dialog);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = gtk_clipboard_get_for_display (_tmp10_, GDK_SELECTION_CLIPBOARD);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_clipboard_set_text (_tmp11_, _data28_->log, -1);
#line 1972 "libvirt-machine-properties.c"
		} else {
#line 185 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_destroy ((GtkWidget*) _data28_->dialog);
#line 1976 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda133__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda133_ (self, response_id);
#line 1985 "libvirt-machine-properties.c"
}


static void ___lambda132_ (BoxesLibvirtMachineProperties* self) {
	Block28Data* _data28_;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesApp* _tmp2_;
	GtkApplicationWindow* _tmp3_;
	const gchar* _tmp4_ = NULL;
	GtkDialog* _tmp5_;
	GtkTextView* text = NULL;
	GtkTextView* _tmp6_;
	GtkScrolledWindow* scroll = NULL;
	GtkScrolledWindow* _tmp7_;
	GtkBox* _tmp8_ = NULL;
	GtkTextBuffer* _tmp9_;
	GtkTextBuffer* _tmp10_;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = g_slice_new0 (Block28Data);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->_ref_count_ = 1;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->self = g_object_ref (self);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_collect_logs (self);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->log = _tmp0_;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _ ("Troubleshooting log");
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_app_app;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_->window;
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _ ("Copy to clipboard");
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkDialog*) gtk_dialog_new_with_buttons (_tmp1_, (GtkWindow*) _tmp3_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_SAVE, 100, _tmp4_, 101, GTK_STOCK_CLOSE, GTK_RESPONSE_OK, NULL);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 136 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->dialog = _tmp5_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_window_set_default_size ((GtkWindow*) _data28_->dialog, 640, 480);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = (GtkTextView*) gtk_text_view_new ();
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp6_);
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	text = _tmp6_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_view_set_editable (text, FALSE);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp7_);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	scroll = _tmp7_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) scroll, (GtkWidget*) text);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_vexpand ((GtkWidget*) scroll, TRUE);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = (GtkBox*) gtk_dialog_get_content_area (_data28_->dialog);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp8_, (GtkWidget*) scroll);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = gtk_text_view_get_buffer (text);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_buffer_set_text (_tmp10_, _data28_->log, -1);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_show_all ((GtkWidget*) _data28_->dialog);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_data28_->dialog, "response", (GCallback) ___lambda133__gtk_dialog_response, block28_data_ref (_data28_), (GClosureNotify) block28_data_unref, 0);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (scroll);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (text);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block28_data_unref (_data28_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = NULL;
#line 2070 "libvirt-machine-properties.c"
}


static void ____lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda132_ (self);
#line 2077 "libvirt-machine-properties.c"
}


static Block31Data* block31_data_ref (Block31Data* _data31_) {
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data31_->_ref_count_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data31_;
#line 2086 "libvirt-machine-properties.c"
}


static void block31_data_unref (void * _userdata_) {
	Block31Data* _data31_;
	_data31_ = (Block31Data*) _userdata_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data31_->_ref_count_)) {
#line 2095 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data31_->self;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data31_->property);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block31Data, _data31_);
#line 2105 "libvirt-machine-properties.c"
	}
}


static void ____lambda138_ (Block31Data* _data31_) {
	BoxesLibvirtMachineProperties * self;
	GError * _inner_error_ = NULL;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data31_->self;
#line 2115 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_;
		BoxesProperty* _tmp1_;
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_usb_redir (self, &_inner_error_);
#line 235 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 2123 "libvirt-machine-properties.c"
			goto __catch31_g_error;
		}
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 236 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data31_->property;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 2134 "libvirt-machine-properties.c"
	}
	goto __finally31;
	__catch31_g_error:
	{
		GError* _error_ = NULL;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 239 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:239: Failed to enable usb");
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2148 "libvirt-machine-properties.c"
	}
	__finally31:
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2159 "libvirt-machine-properties.c"
	}
}


static void _____lambda138__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda138_ (self);
#line 2167 "libvirt-machine-properties.c"
}


static Block32Data* block32_data_ref (Block32Data* _data32_) {
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data32_->_ref_count_);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data32_;
#line 2176 "libvirt-machine-properties.c"
}


static void block32_data_unref (void * _userdata_) {
	Block32Data* _data32_;
	_data32_ = (Block32Data*) _userdata_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data32_->_ref_count_)) {
#line 2185 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data32_->self;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data32_->property);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block32Data, _data32_);
#line 2195 "libvirt-machine-properties.c"
	}
}


static void ____lambda139_ (Block32Data* _data32_) {
	BoxesLibvirtMachineProperties * self;
	GError * _inner_error_ = NULL;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data32_->self;
#line 2205 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_;
		BoxesProperty* _tmp1_;
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_smartcard (self, &_inner_error_);
#line 252 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 2213 "libvirt-machine-properties.c"
			goto __catch32_g_error;
		}
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data32_->property;
#line 254 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 2224 "libvirt-machine-properties.c"
	}
	goto __finally32;
	__catch32_g_error:
	{
		GError* _error_ = NULL;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 256 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:256: Failed to enable smartcard");
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2238 "libvirt-machine-properties.c"
	}
	__finally32:
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 251 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2249 "libvirt-machine-properties.c"
	}
}


static void _____lambda139__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda139_ (self);
#line 2257 "libvirt-machine-properties.c"
}


static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachineProperties * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesLibvirtMachine* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	BoxesPropertiesPage _tmp6_;
	GError * _inner_error_ = NULL;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) base;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	list = NULL;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_get_display ((BoxesMachine*) _tmp0_);
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 2282 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp3_;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp3_ = self->priv->machine;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_update_display (_tmp3_, &_inner_error_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 2291 "libvirt-machine-properties.c"
				goto __catch28_g_error;
			}
		}
		goto __finally28;
		__catch28_g_error:
		{
			GError* e = NULL;
			GError* _tmp4_;
			const gchar* _tmp5_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp4_ = e;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = _tmp4_->message;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_warning ("libvirt-machine-properties.vala:111: %s", _tmp5_);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 2313 "libvirt-machine-properties.c"
		}
		__finally28:
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__g_list_free__g_object_unref0_0 (list);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return NULL;
#line 2326 "libvirt-machine-properties.c"
		}
	}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = page;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_tmp6_) {
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 2335 "libvirt-machine-properties.c"
		{
			BoxesStringProperty* property = NULL;
			const gchar* _tmp7_ = NULL;
			BoxesLibvirtMachine* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			BoxesStringProperty* _tmp11_ = NULL;
			BoxesStringProperty* _tmp12_;
			BoxesStringProperty* _tmp13_;
			const gchar* _tmp14_ = NULL;
			BoxesLibvirtMachine* _tmp15_;
			BoxesCollectionSource* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			BoxesStringProperty* _tmp20_ = NULL;
			BoxesStringProperty* _tmp21_;
			BoxesLibvirtMachine* _tmp22_;
			BoxesDisplay* _tmp23_;
			BoxesDisplay* _tmp24_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _ ("Name");
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = self->priv->machine;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp8_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _tmp9_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp7_, _tmp10_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			property = _tmp11_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = property;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_string_property_set_editable (_tmp12_, TRUE);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = property;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp13_, "changed", (GCallback) ____lambda128__boxes_string_property_changed, self, 0);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _ ("Virtualizer");
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = self->priv->machine;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = ((BoxesMachine*) _tmp15_)->source;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = boxes_collection_source_get_uri (_tmp16_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = _tmp17_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = _tmp18_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp14_, _tmp19_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = _tmp20_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp21_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp19_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = self->priv->machine;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_machine_get_display ((BoxesMachine*) _tmp22_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp24_ != NULL) {
#line 2404 "libvirt-machine-properties.c"
				const gchar* _tmp25_ = NULL;
				BoxesLibvirtMachine* _tmp26_;
				BoxesDisplay* _tmp27_;
				BoxesDisplay* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				BoxesStringProperty* _tmp32_ = NULL;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp25_ = _ ("URI");
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp26_ = self->priv->machine;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp27_ = boxes_machine_get_display ((BoxesMachine*) _tmp26_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp28_ = _tmp27_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp29_ = boxes_display_get_uri (_tmp28_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp30_ = _tmp29_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp31_ = _tmp30_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp32_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp25_, _tmp31_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (property);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				property = _tmp32_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_free0 (_tmp31_);
#line 2435 "libvirt-machine-properties.c"
			}
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (property);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2441 "libvirt-machine-properties.c"
		}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2445 "libvirt-machine-properties.c"
		{
			BoxesSizeProperty* ram_property = NULL;
			BoxesSizeProperty* _tmp33_ = NULL;
			BoxesSizeProperty* storage_property = NULL;
			BoxesSizeProperty* _tmp34_ = NULL;
			BoxesSizeProperty* _tmp35_;
			BoxesSizeProperty* _tmp36_;
			GtkButton* button = NULL;
			const gchar* _tmp37_ = NULL;
			GtkButton* _tmp38_;
			GtkButton* _tmp39_;
			GtkButton* _tmp40_;
			BoxesProperty* _tmp41_ = NULL;
			BoxesProperty* _tmp42_;
			GtkButton* _tmp43_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = boxes_libvirt_machine_properties_add_ram_property (self, &list);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			ram_property = _tmp33_;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = boxes_libvirt_machine_properties_add_storage_property (self, &list);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			storage_property = _tmp34_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = ram_property;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = storage_property;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_mark_recommended_resources (self, _tmp35_, _tmp36_, NULL, NULL);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _ ("Troubleshooting log");
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = (GtkButton*) gtk_button_new_with_label (_tmp37_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp38_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			button = _tmp38_;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = button;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp39_, GTK_ALIGN_START);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = button;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, NULL, (GtkWidget*) _tmp40_, NULL);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = _tmp41_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp42_);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = button;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp43_, "clicked", (GCallback) ____lambda132__gtk_button_clicked, self, 0);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (button);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (storage_property);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (ram_property);
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2507 "libvirt-machine-properties.c"
		}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2511 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp44_;
			BoxesDisplay* _tmp45_;
			BoxesDisplay* _tmp46_;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = self->priv->machine;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = boxes_machine_get_display ((BoxesMachine*) _tmp44_);
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = _tmp45_;
#line 192 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp46_ != NULL) {
#line 2524 "libvirt-machine-properties.c"
				const gchar* _tmp47_ = NULL;
				BoxesLibvirtMachine* _tmp48_;
				BoxesDisplay* _tmp49_;
				BoxesDisplay* _tmp50_;
				const gchar* _tmp51_;
				const gchar* _tmp52_;
				BoxesStringProperty* _tmp53_ = NULL;
				BoxesStringProperty* _tmp54_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp47_ = _ ("Protocol");
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp48_ = self->priv->machine;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp49_ = boxes_machine_get_display ((BoxesMachine*) _tmp48_);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp50_ = _tmp49_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp51_ = boxes_display_get_protocol (_tmp50_);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp52_ = _tmp51_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp53_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp47_, _tmp52_);
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp54_ = _tmp53_;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp54_);
#line 2551 "libvirt-machine-properties.c"
			}
#line 194 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2555 "libvirt-machine-properties.c"
		}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2559 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp55_;
			GVirConfigDomain* _tmp56_;
			GVirConfigDomain* _tmp57_;
			GList* _tmp58_ = NULL;
			gboolean has_usb_redir = FALSE;
			gboolean has_smartcard = FALSE;
			gboolean _tmp82_;
			gboolean _tmp84_ = FALSE;
			gboolean _tmp85_;
			gboolean _tmp86_;
			gboolean _tmp94_ = FALSE;
			gboolean _tmp95_;
			gboolean _tmp96_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp55_ = self->priv->machine;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp56_ = boxes_libvirt_machine_get_domain_config (_tmp55_);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp57_ = _tmp56_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp58_ = gvir_config_domain_get_devices (_tmp57_);
#line 2582 "libvirt-machine-properties.c"
			{
				GList* device_config_collection = NULL;
				GList* device_config_it = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				device_config_collection = _tmp58_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 2590 "libvirt-machine-properties.c"
					GVirConfigDomainDevice* _tmp59_;
					GVirConfigDomainDevice* device_config = NULL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp59_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_config = _tmp59_;
#line 2597 "libvirt-machine-properties.c"
					{
						GVirConfigDomainDevice* _tmp60_;
						GVirConfigDomainDisk* disk_config = NULL;
						GVirConfigDomainDevice* _tmp61_;
						GVirConfigDomainDisk* _tmp62_;
						GVirConfigDomainDiskGuestDeviceType disk_type = 0;
						GVirConfigDomainDisk* _tmp63_;
						GVirConfigDomainDiskGuestDeviceType _tmp64_ = 0;
						GVirConfigDomainDiskGuestDeviceType _tmp65_;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp60_ = device_config;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, gvir_config_domain_disk_get_type ())) {
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device_config);
#line 199 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							continue;
#line 2615 "libvirt-machine-properties.c"
						}
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp61_ = device_config;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp61_) : NULL);
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_config = _tmp62_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp63_ = disk_config;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp64_ = gvir_config_domain_disk_get_guest_device_type (_tmp63_);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_type = _tmp64_;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp65_ = disk_type;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (_tmp65_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 2633 "libvirt-machine-properties.c"
							GVirConfigDomainDisk* _tmp66_;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp66_ = disk_config;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							boxes_libvirt_machine_properties_add_cdrom_property (self, _tmp66_, &list);
#line 2639 "libvirt-machine-properties.c"
						}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (disk_config);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (device_config);
#line 2645 "libvirt-machine-properties.c"
					}
				}
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (device_config_collection);
#line 2650 "libvirt-machine-properties.c"
			}
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_usb_redir = FALSE;
#line 207 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_smartcard = FALSE;
#line 2656 "libvirt-machine-properties.c"
			{
				GVirConfigDomain* inactive_config = NULL;
				BoxesLibvirtMachine* _tmp67_;
				GVirDomain* _tmp68_;
				GVirDomain* _tmp69_;
				GVirConfigDomain* _tmp70_ = NULL;
				GVirConfigDomain* _tmp71_;
				GList* _tmp72_ = NULL;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp67_ = self->priv->machine;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp68_ = boxes_libvirt_machine_get_domain (_tmp67_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp69_ = _tmp68_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp70_ = gvir_domain_get_config (_tmp69_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				inactive_config = _tmp70_;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_inner_error_ != NULL) {
#line 2677 "libvirt-machine-properties.c"
					goto __catch30_g_error;
				}
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp71_ = inactive_config;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp72_ = gvir_config_domain_get_devices (_tmp71_);
#line 2684 "libvirt-machine-properties.c"
				{
					GList* device_collection = NULL;
					GList* device_it = NULL;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_collection = _tmp72_;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 2692 "libvirt-machine-properties.c"
						GVirConfigDomainDevice* _tmp73_;
						GVirConfigDomainDevice* device = NULL;
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp73_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						device = _tmp73_;
#line 2699 "libvirt-machine-properties.c"
						{
							GVirConfigDomainDevice* _tmp74_;
							GVirConfigDomainDevice* _tmp75_;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp74_ = device;
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp74_, gvir_config_domain_redirdev_get_type ())) {
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_usb_redir = TRUE;
#line 2709 "libvirt-machine-properties.c"
							}
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp75_ = device;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, gvir_config_domain_smartcard_get_type ())) {
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_smartcard = TRUE;
#line 2717 "libvirt-machine-properties.c"
							}
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device);
#line 2721 "libvirt-machine-properties.c"
						}
					}
#line 212 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					__g_list_free__g_object_unref0_0 (device_collection);
#line 2726 "libvirt-machine-properties.c"
				}
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (inactive_config);
#line 2730 "libvirt-machine-properties.c"
			}
			goto __finally30;
			__catch30_g_error:
			{
				GError* _error_ = NULL;
				BoxesLibvirtMachine* _tmp76_;
				GVirDomain* _tmp77_;
				GVirDomain* _tmp78_;
				const gchar* _tmp79_ = NULL;
				GError* _tmp80_;
				const gchar* _tmp81_;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_error_ = _inner_error_;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp76_ = self->priv->machine;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp77_ = boxes_libvirt_machine_get_domain (_tmp76_);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp78_ = _tmp77_;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp79_ = gvir_domain_get_name (_tmp78_);
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp80_ = _error_;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp81_ = _tmp80_->message;
#line 221 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:221: Failed to fetch configuration for" \
" domain '%s': %s", _tmp79_, _tmp81_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (_error_);
#line 2762 "libvirt-machine-properties.c"
			}
			__finally30:
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2775 "libvirt-machine-properties.c"
			}
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp82_ = has_usb_redir;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp82_) {
#line 2781 "libvirt-machine-properties.c"
				PropertyCreationFlag _tmp83_;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp83_ = *flags;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				*flags = _tmp83_ | PROPERTY_CREATION_FLAG_NO_USB;
#line 2787 "libvirt-machine-properties.c"
			}
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp85_ = has_usb_redir;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp85_) {
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = HAVE_USBREDIR;
#line 2795 "libvirt-machine-properties.c"
			} else {
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = FALSE;
#line 2799 "libvirt-machine-properties.c"
			}
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp86_ = _tmp84_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp86_) {
#line 2805 "libvirt-machine-properties.c"
				Block31Data* _data31_;
				GtkButton* button = NULL;
				const gchar* _tmp87_ = NULL;
				GtkButton* _tmp88_;
				GtkButton* _tmp89_;
				const gchar* _tmp90_ = NULL;
				GtkButton* _tmp91_;
				BoxesProperty* _tmp92_ = NULL;
				GtkButton* _tmp93_;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_ = g_slice_new0 (Block31Data);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->_ref_count_ = 1;
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->self = g_object_ref (self);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp87_ = _ ("Add support to guest");
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp88_ = (GtkButton*) gtk_button_new_with_label (_tmp87_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp88_);
#line 230 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp88_;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp89_ = button;
#line 231 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp89_, GTK_ALIGN_START);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp90_ = _ ("USB device support");
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp91_ = button;
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp92_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp90_, (GtkWidget*) _tmp91_, NULL);
#line 232 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->property = _tmp92_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp93_ = button;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp93_, "clicked", (GCallback) _____lambda138__gtk_button_clicked, block31_data_ref (_data31_), (GClosureNotify) block31_data_unref, 0);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block31_data_unref (_data31_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_ = NULL;
#line 2851 "libvirt-machine-properties.c"
			}
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp95_ = has_smartcard;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp95_) {
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp94_ = HAVE_SMARTCARD;
#line 2859 "libvirt-machine-properties.c"
			} else {
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp94_ = FALSE;
#line 2863 "libvirt-machine-properties.c"
			}
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp96_ = _tmp94_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp96_) {
#line 2869 "libvirt-machine-properties.c"
				Block32Data* _data32_;
				GtkButton* button = NULL;
				const gchar* _tmp97_ = NULL;
				GtkButton* _tmp98_;
				GtkButton* _tmp99_;
				const gchar* _tmp100_ = NULL;
				GtkButton* _tmp101_;
				BoxesProperty* _tmp102_ = NULL;
				GtkButton* _tmp103_;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_ = g_slice_new0 (Block32Data);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->_ref_count_ = 1;
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->self = g_object_ref (self);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp97_ = _ ("Add support to guest");
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp98_ = (GtkButton*) gtk_button_new_with_label (_tmp97_);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp98_);
#line 247 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp98_;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp99_ = button;
#line 248 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp99_, GTK_ALIGN_START);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp100_ = _ ("Smartcard support");
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp101_ = button;
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp102_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp100_, (GtkWidget*) _tmp101_, NULL);
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->property = _tmp102_;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp103_ = button;
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp103_, "clicked", (GCallback) _____lambda139__gtk_button_clicked, block32_data_ref (_data32_), (GClosureNotify) block32_data_unref, 0);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block32_data_unref (_data32_);
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_ = NULL;
#line 2915 "libvirt-machine-properties.c"
			}
#line 261 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2919 "libvirt-machine-properties.c"
		}
		default:
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		break;
#line 2924 "libvirt-machine-properties.c"
	}
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = list;
#line 264 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 2930 "libvirt-machine-properties.c"
}


static Block33Data* block33_data_ref (Block33Data* _data33_) {
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data33_->_ref_count_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data33_;
#line 2939 "libvirt-machine-properties.c"
}


static void block33_data_unref (void * _userdata_) {
	Block33Data* _data33_;
	_data33_ = (Block33Data*) _userdata_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data33_->_ref_count_)) {
#line 2948 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data33_->self;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->button_label);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->label);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->disk_config);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block33Data, _data33_);
#line 2962 "libvirt-machine-properties.c"
	}
}


static Block34Data* block34_data_ref (Block34Data* _data34_) {
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data34_->_ref_count_);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data34_;
#line 2972 "libvirt-machine-properties.c"
}


static void block34_data_unref (void * _userdata_) {
	Block34Data* _data34_;
	_data34_ = (Block34Data*) _userdata_;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data34_->_ref_count_)) {
#line 2981 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data34_->_data33_->self;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data34_->dialog);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block33_data_unref (_data34_->_data33_);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_data33_ = NULL;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block34Data, _data34_);
#line 2993 "libvirt-machine-properties.c"
	}
}


static void ___lambda137_ (Block34Data* _data34_, gint response) {
	Block33Data* _data33_;
	BoxesLibvirtMachineProperties * self;
	gint _tmp0_;
	GtkFileChooserDialog* _tmp33_;
	GError * _inner_error_ = NULL;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = _data34_->_data33_;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data33_->self;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response;
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 3012 "libvirt-machine-properties.c"
		gchar* path = NULL;
		GtkFileChooserDialog* _tmp1_;
		gchar* _tmp2_ = NULL;
		GVirConfigDomainDisk* _tmp3_;
		const gchar* _tmp4_;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data34_->dialog;
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp1_);
#line 319 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		path = _tmp2_;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data33_->disk_config;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = path;
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp3_, _tmp4_);
#line 3030 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp5_;
			GVirDomain* _tmp6_;
			GVirDomain* _tmp7_;
			GVirConfigDomainDisk* _tmp8_;
			GtkLabel* _tmp9_;
			const gchar* _tmp10_ = NULL;
			GtkLabel* _tmp11_;
			const gchar* _tmp12_;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _tmp6_;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _data33_->disk_config;
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp7_, (GVirConfigDomainDevice*) _tmp8_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 322 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 3054 "libvirt-machine-properties.c"
				goto __catch33_g_error;
			}
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _data33_->button_label;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Remove");
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp9_, _tmp10_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = _data33_->label;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = path;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = boxes_get_utf8_basename (_tmp12_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp11_, _tmp14_);
#line 324 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp14_);
#line 325 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data33_->empty = FALSE;
#line 3077 "libvirt-machine-properties.c"
		}
		goto __finally33;
		__catch33_g_error:
		{
			GError* e = NULL;
			gchar* path_basename = NULL;
			const gchar* _tmp15_;
			gchar* _tmp16_ = NULL;
			gchar* msg = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_;
			BoxesLibvirtMachine* _tmp19_;
			const gchar* _tmp20_;
			const gchar* _tmp21_;
			BoxesLibvirtMachine* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			gchar* _tmp25_ = NULL;
			gchar* _tmp26_;
			const gchar* _tmp27_;
			BoxesLibvirtMachine* _tmp28_;
			const gchar* _tmp29_;
			const gchar* _tmp30_;
			GError* _tmp31_;
			const gchar* _tmp32_;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = path;
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = boxes_get_utf8_basename (_tmp15_);
#line 327 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			path_basename = _tmp16_;
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _ ("Insertion of '%s' as a CD/DVD into '%s' failed");
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = g_strdup (_tmp17_);
#line 330 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp18_;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = self->priv->machine;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = msg;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = path_basename;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = self->priv->machine;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp22_);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = g_strdup_printf (_tmp20_, _tmp21_, _tmp24_);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp19_, "got-error", _tmp26_);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp26_);
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = path_basename;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp28_);
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = e;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_->message;
#line 332 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:332: Error inserting '%s' as CD into '" \
"%s': %s", _tmp27_, _tmp30_, _tmp32_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path_basename);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3159 "libvirt-machine-properties.c"
		}
		__finally33:
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 321 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3172 "libvirt-machine-properties.c"
		}
#line 318 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (path);
#line 3176 "libvirt-machine-properties.c"
	}
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp33_ = _data34_->dialog;
#line 335 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp33_);
#line 3182 "libvirt-machine-properties.c"
}


static void ____lambda137__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda137_ (self, response_id);
#line 3189 "libvirt-machine-properties.c"
}


static void __lambda136_ (Block33Data* _data33_) {
	BoxesLibvirtMachineProperties * self;
	gboolean _tmp0_;
	GError * _inner_error_ = NULL;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data33_->self;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data33_->empty;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 3203 "libvirt-machine-properties.c"
		Block34Data* _data34_;
		const gchar* _tmp1_ = NULL;
		BoxesApp* _tmp2_;
		GtkApplicationWindow* _tmp3_;
		GtkFileChooserDialog* _tmp4_;
		GtkFileChooserDialog* _tmp5_;
		GtkFileChooserDialog* _tmp6_;
		GtkFileChooserDialog* _tmp7_;
		GtkFileChooserDialog* _tmp8_;
		GtkFileFilter* _tmp9_;
		GtkFileFilter* _tmp10_;
		GtkFileChooserDialog* _tmp11_;
		GtkFileFilter* _tmp12_;
		GtkFileFilter* _tmp13_;
		GtkFileChooserDialog* _tmp14_;
		GtkFileChooserDialog* _tmp15_;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_ = g_slice_new0 (Block34Data);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_ref_count_ = 1;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_data33_ = block33_data_ref (_data33_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Select a device or ISO file");
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_app_app;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_->window;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp3_, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp4_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->dialog = _tmp4_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data34_->dialog;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_window_set_modal ((GtkWindow*) _tmp5_, TRUE);
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data34_->dialog;
#line 313 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp6_, FALSE);
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data34_->dialog;
#line 314 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp7_, TRUE);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data34_->dialog;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gtk_file_filter_new ();
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp9_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp8_, _tmp10_);
#line 315 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp10_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = _data34_->dialog;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp11_);
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 316 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_filter_add_mime_type (_tmp13_, "application/x-cd-image");
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _data34_->dialog;
#line 317 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp14_, "response", (GCallback) ____lambda137__gtk_dialog_response, block34_data_ref (_data34_), (GClosureNotify) block34_data_unref, 0);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = _data34_->dialog;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp15_);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block34_data_unref (_data34_);
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_ = NULL;
#line 3282 "libvirt-machine-properties.c"
	} else {
		GVirConfigDomainDisk* _tmp16_;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data33_->disk_config;
#line 339 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp16_, "");
#line 3289 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp17_;
			GVirDomain* _tmp18_;
			GVirDomain* _tmp19_;
			GVirConfigDomainDisk* _tmp20_;
			GtkLabel* _tmp21_;
			const gchar* _tmp22_ = NULL;
			GtkLabel* _tmp23_;
			const gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			gchar* _tmp26_;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = self->priv->machine;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = _tmp18_;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = _data33_->disk_config;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp19_, (GVirConfigDomainDevice*) _tmp20_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 3313 "libvirt-machine-properties.c"
				goto __catch34_g_error;
			}
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data33_->empty = TRUE;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = _data33_->button_label;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _ ("Select");
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp21_, _tmp22_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = _data33_->label;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _ ("empty");
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = g_markup_printf_escaped ("<i>%s</i>", _tmp24_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp23_, _tmp26_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp26_);
#line 3336 "libvirt-machine-properties.c"
		}
		goto __finally34;
		__catch34_g_error:
		{
			GError* e = NULL;
			BoxesLibvirtMachine* _tmp27_;
			const gchar* _tmp28_ = NULL;
			BoxesLibvirtMachine* _tmp29_;
			const gchar* _tmp30_;
			const gchar* _tmp31_;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_;
			BoxesLibvirtMachine* _tmp34_;
			const gchar* _tmp35_;
			const gchar* _tmp36_;
			GError* _tmp37_;
			const gchar* _tmp38_;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = self->priv->machine;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = _ ("Removal of CD/DVD from '%s' failed");
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = self->priv->machine;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp29_);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _tmp30_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = g_strdup_printf (_tmp28_, _tmp31_);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _tmp32_;
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp27_, "got-error", _tmp33_);
#line 347 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp33_);
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = self->priv->machine;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp34_);
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = _tmp35_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = e;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = _tmp37_->message;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:348: Error ejecting CD from '%s': %s", _tmp36_, _tmp38_);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3390 "libvirt-machine-properties.c"
		}
		__finally34:
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3401 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda136__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda136_ (self);
#line 3410 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list) {
	Block33Data* _data33_;
	GVirConfigDomainDisk* _tmp0_;
	GVirConfigDomainDisk* _tmp1_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp2_;
	GtkGrid* _tmp3_;
	GtkGrid* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	GtkGrid* _tmp7_;
	GtkLabel* _tmp8_;
	gchar* source = NULL;
	GVirConfigDomainDisk* _tmp9_;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_;
	gboolean _tmp15_;
	gboolean _tmp16_;
	gboolean _tmp25_ = FALSE;
	BoxesLibvirtMachine* _tmp26_;
	GVirConfigDomain* _tmp27_;
	GVirConfigDomain* _tmp28_;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp34_;
	GtkLabel* _tmp39_;
	GtkButton* button = NULL;
	GtkButton* _tmp40_;
	GtkButton* _tmp41_;
	GtkLabel* _tmp42_;
	GtkGrid* _tmp43_;
	GtkButton* _tmp44_;
	gboolean _tmp45_;
	GtkButton* _tmp50_;
	const gchar* _tmp51_ = NULL;
	GtkGrid* _tmp52_;
	BoxesProperty* _tmp53_ = NULL;
	BoxesProperty* _tmp54_;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (disk_config != NULL);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = g_slice_new0 (Block33Data);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->_ref_count_ = 1;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->self = g_object_ref (self);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = disk_config;
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data33_->disk_config);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->disk_config = _tmp1_;
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp2_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = grid;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp3_, GTK_ORIENTATION_HORIZONTAL);
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = grid;
#line 270 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (_tmp4_, (guint) 12);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->label = _tmp5_;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _data33_->label;
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_ellipsize (_tmp6_, PANGO_ELLIPSIZE_END);
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = grid;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data33_->label;
#line 274 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data33_->disk_config;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_config_domain_disk_get_source (_tmp9_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	source = _tmp11_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = source;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp13_ == NULL) {
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = TRUE;
#line 3515 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp14_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = source;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = g_strcmp0 (_tmp14_, "") == 0;
#line 3522 "libvirt-machine-properties.c"
	}
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _tmp12_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->empty = _tmp15_;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = _data33_->empty;
#line 279 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp16_) {
#line 3532 "libvirt-machine-properties.c"
		GtkLabel* _tmp17_;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data33_->label;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _ ("empty");
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = g_markup_printf_escaped ("<i>%s</i>", _tmp18_);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_markup (_tmp17_, _tmp20_);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp20_);
#line 3549 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp21_;
		const gchar* _tmp22_;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _data33_->label;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = source;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_get_utf8_basename (_tmp22_);
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp21_, _tmp24_);
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp24_);
#line 3567 "libvirt-machine-properties.c"
	}
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp26_ = self->priv->machine;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp27_ = boxes_libvirt_machine_get_domain_config (_tmp26_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp28_ = _tmp27_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp29_ = boxes_vm_configurator_is_install_config (_tmp28_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp29_) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = TRUE;
#line 3581 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp30_;
		GVirConfigDomain* _tmp31_;
		GVirConfigDomain* _tmp32_;
		gboolean _tmp33_ = FALSE;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = self->priv->machine;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = boxes_libvirt_machine_get_domain_config (_tmp30_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _tmp31_;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = boxes_vm_configurator_is_live_config (_tmp32_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp33_;
#line 3597 "libvirt-machine-properties.c"
	}
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp34_ = _tmp25_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp34_) {
#line 3603 "libvirt-machine-properties.c"
		const gchar* _tmp35_ = NULL;
		GtkGrid* _tmp36_;
		BoxesProperty* _tmp37_ = NULL;
		BoxesProperty* _tmp38_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _ ("CD/DVD");
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = grid;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp35_, (GtkWidget*) _tmp36_, NULL);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp38_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (source);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (grid);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block33_data_unref (_data33_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data33_ = NULL;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 3628 "libvirt-machine-properties.c"
	}
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp39_ = (GtkLabel*) gtk_label_new ("");
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp39_);
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->button_label = _tmp39_;
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp40_ = (GtkButton*) gtk_button_new ();
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp40_);
#line 293 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	button = _tmp40_;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp41_ = button;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp42_ = _data33_->button_label;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp41_, (GtkWidget*) _tmp42_);
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp43_ = grid;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp44_ = button;
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp43_, (GtkWidget*) _tmp44_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp45_ = _data33_->empty;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp45_) {
#line 3658 "libvirt-machine-properties.c"
		GtkLabel* _tmp46_;
		const gchar* _tmp47_ = NULL;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = _data33_->button_label;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = _ ("Select");
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp46_, _tmp47_);
#line 3667 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp48_;
		const gchar* _tmp49_ = NULL;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = _data33_->button_label;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp49_ = _ ("Remove");
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp48_, _tmp49_);
#line 3677 "libvirt-machine-properties.c"
	}
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp50_ = button;
#line 305 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_tmp50_, "clicked", (GCallback) ___lambda136__gtk_button_clicked, block33_data_ref (_data33_), (GClosureNotify) block33_data_unref, 0);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = _ ("CD/DVD");
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp52_ = grid;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp53_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp51_, (GtkWidget*) _tmp52_, NULL);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp54_ = _tmp53_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp54_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (button);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (source);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block33_data_unref (_data33_);
#line 267 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = NULL;
#line 3703 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property) {
	GError * _inner_error_ = NULL;
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 356 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 3713 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_;
		GVirDomain* _tmp1_;
		GVirDomain* _tmp2_;
		GVirConfigDomain* _tmp3_ = NULL;
		guint64 actual = 0ULL;
		BoxesLibvirtMachine* _tmp4_;
		GVirConfigDomain* _tmp5_;
		GVirConfigDomain* _tmp6_;
		guint64 _tmp7_;
		guint64 _tmp8_;
		guint64 pending = 0ULL;
		guint64 _tmp9_;
		guint64 _tmp10_;
		guint64 _tmp11_;
		guint64 _tmp12_;
		BoxesProperty* _tmp13_;
		guint64 _tmp14_;
		guint64 _tmp15_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 358 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 3746 "libvirt-machine-properties.c"
			goto __catch35_g_error;
		}
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain_config (_tmp4_);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_config_domain_get_memory (_tmp6_);
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 361 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		actual = _tmp8_ / 1024;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (config);
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 362 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pending = _tmp10_ / 1024;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = actual;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = pending;
#line 364 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:364: RAM actual: %llu, pending: %llu", _tmp11_, _tmp12_);
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = property;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = actual;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pending;
#line 366 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp13_, (_tmp14_ - _tmp15_) > ((guint64) 1));
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 3783 "libvirt-machine-properties.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
		GError* e = NULL;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 3795 "libvirt-machine-properties.c"
	}
	__finally35:
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 357 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 3806 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	_data_ = _data;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData, _data_);
#line 3822 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	BoxesSizeProperty* _tmp3_;
	BoxesSizeProperty* _tmp4_;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_mark_recommended_resources);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_mark_recommended_resources_data_free);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = ram_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->ram_property = _tmp2_;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = storage_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->storage_property = _tmp4_;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3861 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3869 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3883 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_) {
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3892 "libvirt-machine-properties.c"
		goto _state_0;
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3896 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3901 "libvirt-machine-properties.c"
	}
	_state_0:
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->ram_property;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp1_ == NULL) {
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = _data_->storage_property;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = _data_->_tmp2_ == NULL;
#line 3912 "libvirt-machine-properties.c"
	} else {
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = FALSE;
#line 3916 "libvirt-machine-properties.c"
	}
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->_tmp0_;
#line 372 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp3_) {
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3926 "libvirt-machine-properties.c"
		} else {
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3930 "libvirt-machine-properties.c"
		}
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 373 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3936 "libvirt-machine-properties.c"
	}
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->self->priv->machine;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp4_);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_vm_configurator_get_os_id (_data_->_tmp6_);
#line 375 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_id = _data_->_tmp7_;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->os_id;
#line 376 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp8_ == NULL) {
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3960 "libvirt-machine-properties.c"
		} else {
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3964 "libvirt-machine-properties.c"
		}
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 377 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3970 "libvirt-machine-properties.c"
	}
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = boxes_media_manager_get_instance ();
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = boxes_media_manager_get_os_db (_data_->_tmp10_);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _g_object_ref0 (_data_->_tmp12_);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 379 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_db = _data_->_tmp14_;
#line 3990 "libvirt-machine-properties.c"
	{
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->os_db;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->os_id;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp16_, _data_->_tmp17_, boxes_libvirt_machine_properties_mark_recommended_resources_ready, _data_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4002 "libvirt-machine-properties.c"
		_state_1:
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = _data_->_tmp18_;
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_inner_error_ != NULL) {
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 4014 "libvirt-machine-properties.c"
				goto __catch36_boxes_os_database_error;
			}
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os_db);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_data_->os_id);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return FALSE;
#line 4029 "libvirt-machine-properties.c"
		}
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 382 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->os = _data_->_tmp15_;
#line 4035 "libvirt-machine-properties.c"
	}
	goto __finally36;
	__catch36_boxes_os_database_error:
	{
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp19_ = _data_->os_id;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp20_ = _data_->_error_;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp21_ = _data_->_tmp20_->message;
#line 384 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:384: Failed to find OS with ID '%s': %" \
"s", _data_->_tmp19_, _data_->_tmp21_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_error_);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4064 "libvirt-machine-properties.c"
		} else {
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4068 "libvirt-machine-properties.c"
		}
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 385 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4074 "libvirt-machine-properties.c"
	}
	__finally36:
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_inner_error_ != NULL) {
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 381 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4091 "libvirt-machine-properties.c"
	}
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp22_ = _data_->self->priv->machine;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp23_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp22_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp25_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp25_ = gvir_config_domain_get_os (_data_->_tmp24_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp27_ = NULL;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp27_ = gvir_config_domain_os_get_arch (_data_->_tmp26_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp28_ = g_strdup (_data_->_tmp27_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp26_);
#line 388 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->architecture = _data_->_tmp29_;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp30_ = _data_->os_db;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp31_ = _data_->os;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp32_ = _data_->architecture;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp33_ = NULL;
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp33_ = boxes_os_database_get_recommended_resources_for_os (_data_->_tmp30_, _data_->_tmp31_, _data_->_tmp32_);
#line 389 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->resources = _data_->_tmp33_;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp34_ = _data_->resources;
#line 390 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp34_ != NULL) {
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp35_ = _data_->ram_property;
#line 391 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp35_ != NULL) {
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp36_ = _data_->ram_property;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp37_ = _data_->resources;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp38_ = osinfo_resources_get_ram (_data_->_tmp37_);
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp39_ = _data_->_tmp38_;
#line 392 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp36_, (guint64) _data_->_tmp39_);
#line 4147 "libvirt-machine-properties.c"
		}
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp40_ = _data_->storage_property;
#line 393 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp40_ != NULL) {
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp41_ = _data_->storage_property;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp42_ = _data_->resources;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp43_ = osinfo_resources_get_storage (_data_->_tmp42_);
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp44_ = _data_->_tmp43_;
#line 394 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp41_, (guint64) _data_->_tmp44_);
#line 4163 "libvirt-machine-properties.c"
		}
	}
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->resources);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->architecture);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4180 "libvirt-machine-properties.c"
	} else {
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4184 "libvirt-machine-properties.c"
	}
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 371 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4190 "libvirt-machine-properties.c"
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data35_->_ref_count_);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data35_;
#line 4199 "libvirt-machine-properties.c"
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
#line 4208 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data35_->self;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data35_->property);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block35Data, _data35_);
#line 4218 "libvirt-machine-properties.c"
	}
}


static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_ram_changed (self, _sender, value);
#line 4226 "libvirt-machine-properties.c"
}


static void ___lambda130_ (Block35Data* _data35_) {
	BoxesLibvirtMachineProperties * self;
	BoxesLibvirtMachine* _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data35_->self;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_is_on ((BoxesMachine*) _tmp0_);
#line 417 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp1_) {
#line 4242 "libvirt-machine-properties.c"
		BoxesSizeProperty* _tmp2_;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data35_->property;
#line 418 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required ((BoxesProperty*) _tmp2_, FALSE);
#line 4248 "libvirt-machine-properties.c"
	}
}


static void ____lambda130__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda130_ (self);
#line 4256 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	GError * _inner_error_ = NULL;
#line 398 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4265 "libvirt-machine-properties.c"
	{
		Block35Data* _data35_;
		GVirNodeInfo* _tmp0_ = NULL;
		BoxesLibvirtMachine* _tmp1_;
		GVirConnection* _tmp2_;
		GVirConnection* _tmp3_;
		GVirNodeInfo* _tmp4_ = NULL;
		gulong max_ram = 0UL;
		GVirNodeInfo* _tmp5_;
		gulong _tmp6_;
		gulong _tmp7_;
		const gchar* _tmp8_ = NULL;
		BoxesLibvirtMachine* _tmp9_;
		GVirConfigDomain* _tmp10_;
		GVirConfigDomain* _tmp11_;
		guint64 _tmp12_;
		guint64 _tmp13_;
		gulong _tmp14_;
		BoxesSizeProperty* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
		gboolean _tmp17_ = FALSE;
		BoxesLibvirtMachine* _tmp18_;
		GVirConfigDomain* _tmp19_;
		GVirConfigDomain* _tmp20_;
		gboolean _tmp21_ = FALSE;
		gboolean _tmp26_;
		gboolean _tmp30_;
		BoxesLibvirtMachine* _tmp33_;
		BoxesSizeProperty* _tmp34_;
		BoxesSizeProperty* _tmp35_;
		BoxesSizeProperty* _tmp36_;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_ = g_slice_new0 (Block35Data);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->_ref_count_ = 1;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->self = g_object_ref (self);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_connection (_tmp1_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_connection_get_node_info (_tmp3_, &_inner_error_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp4_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block35_data_unref (_data35_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data35_ = NULL;
#line 4319 "libvirt-machine-properties.c"
			goto __catch37_g_error;
		}
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp0_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_->memory;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_;
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp5_);
#line 400 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_ram = _tmp7_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _ ("Memory");
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = self->priv->machine;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = boxes_libvirt_machine_get_domain_config (_tmp9_);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = _tmp10_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = gvir_config_domain_get_memory (_tmp11_);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = max_ram;
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp8_, _tmp13_ * OSINFO_KIBIBYTES, (guint64) (64 * OSINFO_MEBIBYTES), (guint64) (_tmp14_ * OSINFO_KIBIBYTES), (guint64) (64 * OSINFO_MEBIBYTES), G_FORMAT_SIZE_IEC_UNITS);
#line 402 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->property = _tmp15_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = self->priv->machine;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_libvirt_machine_get_domain_config (_tmp18_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_vm_configurator_is_install_config (_tmp20_);
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp21_) {
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = TRUE;
#line 4362 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp22_;
			GVirConfigDomain* _tmp23_;
			GVirConfigDomain* _tmp24_;
			gboolean _tmp25_ = FALSE;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = self->priv->machine;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_libvirt_machine_get_domain_config (_tmp22_);
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = boxes_vm_configurator_is_live_config (_tmp24_);
#line 410 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _tmp25_;
#line 4378 "libvirt-machine-properties.c"
		}
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp17_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp26_) {
#line 4384 "libvirt-machine-properties.c"
			BoxesApp* _tmp27_;
			BoxesUIState _tmp28_;
			BoxesUIState _tmp29_;
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = boxes_app_app;
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp27_);
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 411 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _tmp29_ != BOXES_UI_STATE_WIZARD;
#line 4396 "libvirt-machine-properties.c"
		} else {
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = FALSE;
#line 4400 "libvirt-machine-properties.c"
		}
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp16_;
#line 409 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp30_) {
#line 4406 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp31_;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _data35_->property;
#line 412 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp31_, FALSE);
#line 4412 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp32_;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _data35_->property;
#line 414 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp32_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed, self, 0);
#line 4419 "libvirt-machine-properties.c"
		}
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = self->priv->machine;
#line 416 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GObject*) _tmp33_, "notify::state", (GCallback) ____lambda130__g_object_notify, block35_data_ref (_data35_), (GClosureNotify) block35_data_unref, 0);
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _data35_->property;
#line 421 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, (BoxesProperty*) _tmp34_);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _data35_->property;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _g_object_ref0 (_tmp35_);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp36_;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block35_data_unref (_data35_);
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_ = NULL;
#line 423 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4441 "libvirt-machine-properties.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
		GError* _error_ = NULL;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 425 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4457 "libvirt-machine-properties.c"
	}
	__finally37:
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 399 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 4466 "libvirt-machine-properties.c"
}


static Block36Data* block36_data_ref (Block36Data* _data36_) {
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data36_->_ref_count_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data36_;
#line 4475 "libvirt-machine-properties.c"
}


static void block36_data_unref (void * _userdata_) {
	Block36Data* _data36_;
	_data36_ = (Block36Data*) _userdata_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data36_->_ref_count_)) {
#line 4484 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data36_->self;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data36_->property);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block36Data, _data36_);
#line 4494 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda129_ (Block36Data* _data36_) {
	BoxesLibvirtMachineProperties * self;
	gboolean result = FALSE;
	guint64 ram = 0ULL;
	guint64 _tmp0_;
	BoxesLibvirtMachine* _tmp24_;
	gboolean _tmp25_ = FALSE;
	GError * _inner_error_ = NULL;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data36_->self;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data36_->value;
#line 432 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	ram = ((_tmp0_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 4513 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_;
		GVirDomain* _tmp2_;
		GVirDomain* _tmp3_;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_;
		guint64 _tmp6_;
		GVirConfigDomain* _tmp7_;
		GObjectClass* _tmp8_ = NULL;
		GParamSpec* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp12_;
		GVirDomain* _tmp13_;
		GVirDomain* _tmp14_;
		GVirConfigDomain* _tmp15_;
		guint64 _tmp16_;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp4_;
#line 434 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 4542 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = config;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = ram;
#line 435 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_memory (_tmp5_, _tmp6_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = config;
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = G_OBJECT_GET_CLASS ((GObject*) _tmp7_);
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = g_object_class_find_property (_tmp8_, "current-memory");
#line 436 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ != NULL) {
#line 4559 "libvirt-machine-properties.c"
			GVirConfigDomain* _tmp10_;
			guint64 _tmp11_;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = config;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = ram;
#line 437 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set ((GObject*) _tmp10_, "current-memory", _tmp11_, NULL);
#line 4568 "libvirt-machine-properties.c"
		}
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp14_, _tmp15_, &_inner_error_);
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 438 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 4584 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = ram;
#line 439 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:439: RAM changed to %llu KiB", _tmp16_);
#line 440 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_notify_reboot_required (self);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 4595 "libvirt-machine-properties.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp17_;
		GVirDomain* _tmp18_;
		GVirDomain* _tmp19_;
		const gchar* _tmp20_ = NULL;
		guint64 _tmp21_;
		GError* _tmp22_;
		const gchar* _tmp23_;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_name (_tmp19_);
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = ram;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _error_;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->message;
#line 442 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:442: Failed to change RAM of box '%s' " \
"to %llu KiB: %s", _tmp20_, _tmp21_, _tmp23_);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 4630 "libvirt-machine-properties.c"
	}
	__finally38:
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 433 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4641 "libvirt-machine-properties.c"
	}
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = self->priv->machine;
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = boxes_machine_is_on ((BoxesMachine*) _tmp24_);
#line 448 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp25_) {
#line 4649 "libvirt-machine-properties.c"
		BoxesProperty* _tmp26_;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _data36_->property;
#line 449 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, _tmp26_);
#line 4655 "libvirt-machine-properties.c"
	}
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 451 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4661 "libvirt-machine-properties.c"
}


static gboolean ___lambda129__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda129_ (self);
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4670 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block36Data* _data36_;
	BoxesProperty* _tmp0_;
	BoxesProperty* _tmp1_;
	guint64 _tmp2_;
	BoxesProperty* _tmp3_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_ = g_slice_new0 (Block36Data);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->_ref_count_ = 1;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->self = g_object_ref (self);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data36_->property);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->property = _tmp1_;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->value = _tmp2_;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data36_->property;
#line 431 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda129__gsource_func, block36_data_ref (_data36_), block36_data_unref);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block36_data_unref (_data36_);
#line 429 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_ = NULL;
#line 4710 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_reboot_boxes_notificationbar_ok_func (gpointer self) {
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_reboot (self);
#line 4717 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_notify_reboot_required (BoxesLibvirtMachineProperties* self) {
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp6_;
	gchar* message = NULL;
	const gchar* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_ = NULL;
	BoxesApp* _tmp12_;
	BoxesNotificationbar* _tmp13_;
	const gchar* _tmp14_;
	GdNotification* _tmp15_ = NULL;
	GdNotification* _tmp16_;
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_is_on ((BoxesMachine*) _tmp1_);
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp2_) {
#line 4745 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp3_;
		BoxesMachineMachineState _tmp4_;
		BoxesMachineMachineState _tmp5_;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_get_state ((BoxesMachine*) _tmp3_);
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp5_ != BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 4757 "libvirt-machine-properties.c"
	} else {
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = FALSE;
#line 4761 "libvirt-machine-properties.c"
	}
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp0_;
#line 456 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp6_) {
#line 457 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 4769 "libvirt-machine-properties.c"
	}
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _ ("Changes require restart of '%s'. Attempt restart?");
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = self->priv->machine;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp8_);
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup_printf (_tmp7_, _tmp10_);
#line 459 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	message = _tmp11_;
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = boxes_app_app;
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _tmp12_->notificationbar;
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = message;
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = boxes_notificationbar_display_for_action (_tmp13_, _tmp14_, GTK_STOCK_YES, _boxes_libvirt_machine_properties_reboot_boxes_notificationbar_ok_func, g_object_ref (self), g_object_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = _tmp15_;
#line 460 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp16_);
#line 455 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (message);
#line 4797 "libvirt-machine-properties.c"
}


static Block37Data* block37_data_ref (Block37Data* _data37_) {
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data37_->_ref_count_);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data37_;
#line 4806 "libvirt-machine-properties.c"
}


static void block37_data_unref (void * _userdata_) {
	Block37Data* _data37_;
	_data37_ = (Block37Data*) _userdata_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data37_->_ref_count_)) {
#line 4815 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data37_->self;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data37_->notification);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block37Data, _data37_);
#line 4825 "libvirt-machine-properties.c"
	}
}


static void ___lambda103_ (BoxesLibvirtMachineProperties* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (res != NULL);
#line 4834 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_;
		GAsyncResult* _tmp1_;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = res;
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_start_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 468 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 4846 "libvirt-machine-properties.c"
			goto __catch39_g_error;
		}
#line 469 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_reboot (self);
#line 4851 "libvirt-machine-properties.c"
	}
	goto __finally39;
	__catch39_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp2_;
		GVirDomain* _tmp3_;
		GVirDomain* _tmp4_;
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _error_;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_->message;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:471: Failed to start '%s': %s", _tmp5_, _tmp7_);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 4883 "libvirt-machine-properties.c"
	}
	__finally39:
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 467 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 4894 "libvirt-machine-properties.c"
	}
}


static void ____lambda103__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda103_ (self, source_object, res);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (self);
#line 4904 "libvirt-machine-properties.c"
}


static void ___lambda105_ (BoxesLibvirtMachineProperties* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (res != NULL);
#line 4912 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_;
		GAsyncResult* _tmp1_;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = res;
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_start_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 489 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 4924 "libvirt-machine-properties.c"
			goto __catch40_g_error;
		}
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp2_;
		GVirDomain* _tmp3_;
		GVirDomain* _tmp4_;
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _error_;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_->message;
#line 491 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:491: Failed to start '%s': %s", _tmp5_, _tmp7_);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 4958 "libvirt-machine-properties.c"
	}
	__finally40:
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 488 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 4969 "libvirt-machine-properties.c"
	}
}


static void ____lambda105__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda105_ (self, source_object, res);
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (self);
#line 4979 "libvirt-machine-properties.c"
}


static void __lambda104_ (Block37Data* _data37_) {
	BoxesLibvirtMachineProperties * self;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesMachineMachineState _tmp3_;
	gboolean _tmp7_;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_state ((BoxesMachine*) _tmp1_);
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = TRUE;
#line 5002 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp4_;
		BoxesMachineMachineState _tmp5_;
		BoxesMachineMachineState _tmp6_;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_machine_get_state ((BoxesMachine*) _tmp4_);
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 485 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 5015 "libvirt-machine-properties.c"
	}
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp0_;
#line 484 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_) {
#line 5021 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		BoxesLibvirtMachine* _tmp11_;
		BoxesLibvirtMachine* _tmp12_;
		gulong _tmp13_;
		guint _tmp14_;
		GdNotification* _tmp16_;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = self->priv->machine;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp8_);
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 486 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:486: '%s' stopped.", _tmp10_);
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 487 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_start (_tmp11_, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda105__gasync_ready_callback, g_object_ref (self));
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _data37_->state_id;
#line 495 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_handler_disconnect ((GObject*) _tmp12_, _tmp13_);
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = self->priv->shutdown_timeout;
#line 496 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp14_ != ((guint) 0)) {
#line 5052 "libvirt-machine-properties.c"
			guint _tmp15_;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = self->priv->shutdown_timeout;
#line 497 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_source_remove (_tmp15_);
#line 498 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			self->priv->shutdown_timeout = (guint) 0;
#line 5060 "libvirt-machine-properties.c"
		}
#line 500 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data37_->notification;
#line 500 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp16_ != NULL) {
#line 5066 "libvirt-machine-properties.c"
			GdNotification* _tmp17_;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _data37_->notification;
#line 501 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gd_notification_dismiss (_tmp17_);
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data37_->notification);
#line 502 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data37_->notification = NULL;
#line 5076 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda104__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda104_ (self);
#line 5085 "libvirt-machine-properties.c"
}


static void __lambda107_ (Block37Data* _data37_) {
	BoxesLibvirtMachineProperties * self;
	BoxesLibvirtMachine* _tmp0_;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data37_->notification);
#line 510 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->notification = NULL;
#line 511 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 511 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_force_shutdown (_tmp0_, FALSE);
#line 5102 "libvirt-machine-properties.c"
}


static void ___lambda107__boxes_notificationbar_ok_func (gpointer self) {
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda107_ (self);
#line 5109 "libvirt-machine-properties.c"
}


static gboolean __lambda106_ (Block37Data* _data37_) {
	BoxesLibvirtMachineProperties * self;
	gboolean result = FALSE;
	BoxesNotificationbarOKFunc really_force_shutdown = NULL;
	void* really_force_shutdown_target;
	GDestroyNotify really_force_shutdown_target_destroy_notify;
	gchar* message = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_ = NULL;
	BoxesApp* _tmp5_;
	BoxesNotificationbar* _tmp6_;
	BoxesNotificationbarOKFunc _tmp7_;
	void* _tmp7__target;
	GDestroyNotify _tmp7__target_destroy_notify;
	GdNotification* _tmp8_ = NULL;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown = ___lambda107__boxes_notificationbar_ok_func;
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown_target = block37_data_ref (_data37_);
#line 509 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown_target_destroy_notify = block37_data_unref;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _ ("Restart of '%s' is taking too long. Force it to shutdown?");
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp1_);
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = g_strdup_printf (_tmp0_, _tmp3_);
#line 514 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	message = _tmp4_;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_app_app;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_->notificationbar;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = really_force_shutdown;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7__target = really_force_shutdown_target;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7__target_destroy_notify = really_force_shutdown_target_destroy_notify;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = boxes_notificationbar_display_for_action (_tmp6_, message, GTK_STOCK_YES, _tmp7_, _tmp7__target, _tmp7__target_destroy_notify, NULL, NULL, NULL, -1);
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data37_->notification);
#line 515 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->notification = _tmp8_;
#line 520 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->shutdown_timeout = (guint) 0;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (message);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	(really_force_shutdown_target_destroy_notify == NULL) ? NULL : (really_force_shutdown_target_destroy_notify (really_force_shutdown_target), NULL);
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown = NULL;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown_target = NULL;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 522 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5185 "libvirt-machine-properties.c"
}


static gboolean ___lambda106__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda106_ (self);
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5194 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_reboot (BoxesLibvirtMachineProperties* self) {
	Block37Data* _data37_;
	BoxesLibvirtMachine* _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesLibvirtMachine* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	gulong _tmp12_ = 0UL;
	guint _tmp13_ = 0U;
	BoxesLibvirtMachine* _tmp14_;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = g_slice_new0 (Block37Data);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->_ref_count_ = 1;
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->self = g_object_ref (self);
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_get_state ((BoxesMachine*) _tmp0_);
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 464 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 5227 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		BoxesLibvirtMachine* _tmp6_;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp3_);
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 465 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:465: '%s' is in saved state. Resuming " \
"it..", _tmp5_);
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = self->priv->machine;
#line 466 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_start (_tmp6_, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda103__gasync_ready_callback, g_object_ref (self));
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block37_data_unref (_data37_);
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data37_ = NULL;
#line 475 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 5250 "libvirt-machine-properties.c"
	}
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = self->priv->machine;
#line 478 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	((BoxesMachine*) _tmp7_)->stay_on_display = TRUE;
#line 479 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->state_id = (gulong) 0;
#line 480 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->notification = NULL;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = self->priv->machine;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp8_);
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 481 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_debug ("libvirt-machine-properties.vala:481: Rebooting '%s'..", _tmp10_);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = self->priv->machine;
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = g_signal_connect_data ((GObject*) _tmp11_, "notify::state", (GCallback) ___lambda104__g_object_notify, block37_data_ref (_data37_), (GClosureNotify) block37_data_unref, 0);
#line 483 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->state_id = _tmp12_;
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda106__gsource_func, block37_data_ref (_data37_), block37_data_unref);
#line 507 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->shutdown_timeout = _tmp13_;
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = self->priv->machine;
#line 525 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_try_shutdown (_tmp14_);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block37_data_unref (_data37_);
#line 463 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = NULL;
#line 5286 "libvirt-machine-properties.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 5293 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_storage_changed (self, _sender, value);
#line 5300 "libvirt-machine-properties.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 5307 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirStorageVol* _tmp1_;
	GVirStorageVol* _tmp2_;
	GError * _inner_error_ = NULL;
#line 528 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 529 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 530 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5331 "libvirt-machine-properties.c"
	}
	{
		GVirStorageVolInfo* volume_info = NULL;
		BoxesLibvirtMachine* _tmp3_;
		GVirStorageVol* _tmp4_;
		GVirStorageVol* _tmp5_;
		GVirStorageVolInfo* _tmp6_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp7_;
		GVirConnection* _tmp8_;
		GVirConnection* _tmp9_;
		GVirStoragePool* _tmp10_ = NULL;
		GVirStoragePoolInfo* pool_info = NULL;
		GVirStoragePool* _tmp11_;
		GVirStoragePoolInfo* _tmp12_ = NULL;
		guint64 max_storage = 0ULL;
		GVirStorageVolInfo* _tmp13_;
		guint64 _tmp14_;
		GVirStoragePoolInfo* _tmp15_;
		guint64 _tmp16_;
		BoxesSizeProperty* property = NULL;
		const gchar* _tmp17_ = NULL;
		GVirStorageVolInfo* _tmp18_;
		guint64 _tmp19_;
		GVirStorageVolInfo* _tmp20_;
		guint64 _tmp21_;
		guint64 _tmp22_;
		BoxesSizeProperty* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		gboolean _tmp25_ = FALSE;
		BoxesLibvirtMachine* _tmp26_;
		GVirConfigDomain* _tmp27_;
		GVirConfigDomain* _tmp28_;
		gboolean _tmp29_ = FALSE;
		gboolean _tmp34_;
		gboolean _tmp38_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_libvirt_machine_get_storage_volume (_tmp3_);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = gvir_storage_vol_get_info (_tmp5_, &_inner_error_);
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		volume_info = _tmp6_;
#line 533 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 5380 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = self->priv->machine;
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = boxes_libvirt_machine_get_connection (_tmp7_);
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_;
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = boxes_get_storage_pool (_tmp9_);
#line 534 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp10_;
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = pool;
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = gvir_storage_pool_get_info (_tmp11_, &_inner_error_);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool_info = _tmp12_;
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_inner_error_ != NULL) {
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 535 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5405 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = volume_info;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_->capacity;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pool_info;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _tmp15_->available;
#line 536 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_storage = _tmp14_ + _tmp16_;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _ ("Maximum Disk Size");
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = volume_info;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_->capacity;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = volume_info;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->capacity;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = max_storage;
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp17_, _tmp19_, _tmp21_, _tmp22_, 256 * BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES, G_FORMAT_SIZE_DEFAULT);
#line 538 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		property = _tmp23_;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = self->priv->machine;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = boxes_libvirt_machine_get_domain_config (_tmp26_);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = _tmp27_;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = boxes_vm_configurator_is_install_config (_tmp28_);
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp29_) {
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = TRUE;
#line 5446 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp30_;
			GVirConfigDomain* _tmp31_;
			GVirConfigDomain* _tmp32_;
			gboolean _tmp33_ = FALSE;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = self->priv->machine;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = boxes_libvirt_machine_get_domain_config (_tmp30_);
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_;
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = boxes_vm_configurator_is_live_config (_tmp32_);
#line 545 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _tmp33_;
#line 5462 "libvirt-machine-properties.c"
		}
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _tmp25_;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp34_) {
#line 5468 "libvirt-machine-properties.c"
			BoxesApp* _tmp35_;
			BoxesUIState _tmp36_;
			BoxesUIState _tmp37_;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = boxes_app_app;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp35_);
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _tmp36_;
#line 546 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp37_ != BOXES_UI_STATE_WIZARD;
#line 5480 "libvirt-machine-properties.c"
		} else {
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = FALSE;
#line 5484 "libvirt-machine-properties.c"
		}
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp24_;
#line 544 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp38_) {
#line 5490 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp39_;
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = property;
#line 547 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp39_, FALSE);
#line 5496 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp40_;
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = property;
#line 549 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp40_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed, self, 0);
#line 5503 "libvirt-machine-properties.c"
		}
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = property;
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 551 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5515 "libvirt-machine-properties.c"
	}
	goto __finally41;
	__catch41_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp41_;
		GVirStorageVol* _tmp42_;
		GVirStorageVol* _tmp43_;
		const gchar* _tmp44_ = NULL;
		GError* _tmp45_;
		const gchar* _tmp46_;
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = self->priv->machine;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = boxes_libvirt_machine_get_storage_volume (_tmp41_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = _tmp42_;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = gvir_storage_vol_get_name (_tmp43_);
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = _error_;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = _tmp45_->message;
#line 553 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:553: Failed to get information on volu" \
"me '%s' or it's parent pool: %s", _tmp44_, _tmp46_);
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 556 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5551 "libvirt-machine-properties.c"
	}
	__finally41:
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 532 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5560 "libvirt-machine-properties.c"
}


static Block38Data* block38_data_ref (Block38Data* _data38_) {
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data38_->_ref_count_);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data38_;
#line 5569 "libvirt-machine-properties.c"
}


static void block38_data_unref (void * _userdata_) {
	Block38Data* _data38_;
	_data38_ = (Block38Data*) _userdata_;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data38_->_ref_count_)) {
#line 5578 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties * self;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data38_->self;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block38Data, _data38_);
#line 5586 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda131_ (Block38Data* _data38_) {
	BoxesLibvirtMachineProperties * self;
	gboolean result = FALSE;
	BoxesLibvirtMachine* _tmp0_;
	GVirStorageVol* _tmp1_;
	GVirStorageVol* _tmp2_;
	GError * _inner_error_ = NULL;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data38_->self;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 563 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 564 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5612 "libvirt-machine-properties.c"
	}
	{
		BoxesLibvirtMachine* _tmp3_;
		gboolean _tmp4_ = FALSE;
		guint64 _tmp14_;
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_is_running ((BoxesMachine*) _tmp3_);
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp4_) {
#line 5624 "libvirt-machine-properties.c"
			GVirDomainDisk* disk = NULL;
			BoxesLibvirtMachine* _tmp5_;
			GVirDomainDisk* _tmp6_ = NULL;
			GVirDomainDisk* _tmp7_;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain_disk (_tmp5_, &_inner_error_);
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			disk = _tmp6_;
#line 568 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 5637 "libvirt-machine-properties.c"
				goto __catch42_g_error;
			}
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = disk;
#line 569 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp7_ != NULL) {
#line 5644 "libvirt-machine-properties.c"
				GVirDomainDisk* _tmp8_;
				guint64 _tmp9_;
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp8_ = disk;
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp9_ = _data38_->value;
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_domain_disk_resize (_tmp8_, _tmp9_, (guint) 0, &_inner_error_);
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_inner_error_ != NULL) {
#line 570 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (disk);
#line 5657 "libvirt-machine-properties.c"
					goto __catch42_g_error;
				}
			}
#line 567 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (disk);
#line 5663 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp10_;
			GVirStorageVol* _tmp11_;
			GVirStorageVol* _tmp12_;
			guint64 _tmp13_;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = self->priv->machine;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = boxes_libvirt_machine_get_storage_volume (_tmp10_);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = _tmp11_;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _data38_->value;
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_storage_vol_resize (_tmp12_, _tmp13_, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 573 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_inner_error_ != NULL) {
#line 5681 "libvirt-machine-properties.c"
				goto __catch42_g_error;
			}
		}
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _data38_->value;
#line 574 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:574: Storage changed to %llu", _tmp14_);
#line 5689 "libvirt-machine-properties.c"
	}
	goto __finally42;
	__catch42_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp15_;
		GVirStorageVol* _tmp16_;
		GVirStorageVol* _tmp17_;
		const gchar* _tmp18_ = NULL;
		guint64 _tmp19_;
		GError* _tmp20_;
		const gchar* _tmp21_;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = self->priv->machine;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_libvirt_machine_get_storage_volume (_tmp15_);
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _tmp16_;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = gvir_storage_vol_get_name (_tmp17_);
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _data38_->value;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _error_;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->message;
#line 576 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:576: Failed to change storage capacity" \
" of volume '%s' to %llu: %s", _tmp18_, _tmp19_, _tmp21_);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5724 "libvirt-machine-properties.c"
	}
	__finally42:
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_inner_error_ != NULL) {
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 566 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5735 "libvirt-machine-properties.c"
	}
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 582 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5741 "libvirt-machine-properties.c"
}


static gboolean ___lambda131__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda131_ (self);
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5750 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block38Data* _data38_;
	guint64 _tmp0_;
	BoxesProperty* _tmp1_;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data38_ = g_slice_new0 (Block38Data);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data38_->_ref_count_ = 1;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data38_->self = g_object_ref (self);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = value;
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data38_->value = _tmp0_;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 562 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp1_, ___lambda131__gsource_func, block38_data_ref (_data38_), block38_data_unref);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block38_data_unref (_data38_);
#line 560 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data38_ = NULL;
#line 5780 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_class_init (BoxesLibvirtMachinePropertiesClass * klass) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_parent_class = g_type_class_peek_parent (klass);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePropertiesPrivate));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_properties_finalize;
#line 5791 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_libvirt_machine_properties_real_get_properties;
#line 5800 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_instance_init (BoxesLibvirtMachineProperties * self) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE (self);
#line 5807 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_finalize (GObject* obj) {
	BoxesLibvirtMachineProperties * self;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_properties_parent_class)->finalize (obj);
#line 5817 "libvirt-machine-properties.c"
}


GType boxes_libvirt_machine_properties_get_type (void) {
	static volatile gsize boxes_libvirt_machine_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachinePropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachineProperties), 0, (GInstanceInitFunc) boxes_libvirt_machine_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_libvirt_machine_properties_type_id;
		boxes_libvirt_machine_properties_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesLibvirtMachineProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_libvirt_machine_properties_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_libvirt_machine_properties_type_id__volatile, boxes_libvirt_machine_properties_type_id);
	}
	return boxes_libvirt_machine_properties_type_id__volatile;
}



